@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -23,11 +23,11 @@
 class ElementsLocation;
 
 /**
- * @brief The ElementsTreeView class
- * This class just reimplement startDrag from QTreeView, for set a custom pixmap.
- * This class must be used when the tree view have an ElementsCollectionModel as model.
- * The pixmap used is the pixmap of the dragged element or a directory pixmap.
- */
+	@brief The ElementsTreeView class
+	This class just reimplement startDrag from QTreeView, for set a custom pixmap.
+	This class must be used when the tree view have an ElementsCollectionModel as model.
+	The pixmap used is the pixmap of the dragged element or a directory pixmap.
+*/
 class ElementsTreeView : public QTreeView
 {
 	public:
