@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -16,22 +16,25 @@
 	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "xmlelementcollection.h"
-#include "nameslist.h"
-#include "qetxml.h"
+
+#include "../NameList/nameslist.h"
+#include "../qetproject.h"
+#include "../qetxml.h"
 #include "elementslocation.h"
-#include "qetproject.h"
 
 /**
- * @brief XmlElementCollection::XmlElementCollection
- * Build an empty collection.
- * The collection start by :
- *		<collection>
- *			<category name="import>
- *			</category>
- *		</collection>
- * All elements and category are stored as child of <category name="import>
- * @param project : the project of this collection
- */
+	@brief XmlElementCollection::XmlElementCollection
+	Build an empty collection.
+	The collection start by :
+	@code{xml}
+		<collection>
+			<category name="import>
+			</category>
+		</collection>
+	@endcode
+	All elements and category are stored as child of <category name="import>
+	@param project : the project of this collection
+*/
 XmlElementCollection::XmlElementCollection(QETProject *project) :
 	QObject(project),
 	m_project(project)
@@ -43,10 +46,44 @@ XmlElementCollection::XmlElementCollection(QETProject *project) :
 	collection.appendChild(import);
 
 	NamesList names;
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0) // ### Qt 6: remove
 
-	const QChar russian_data[24] = { 0x0418, 0x043C, 0x043F, 0x043E, 0x0440, 0x0442, 0x0438, 0x0440, 0x043E, 0x0432, 0x0430, 0x043D, 0x043D, 0x044B, 0x0435, 0x0020, 0x044D, 0x043B, 0x0435, 0x043C, 0x0435, 0x043D, 0x0442, 0x044B };
-	const QChar greek_data[18] = { 0x0395, 0x03b9, 0x03c3, 0x03b7, 0x03b3, 0x03bc, 0x03ad, 0x03bd, 0x03b1, 0x0020, 0x03c3, 0x03c4, 0x03bf, 0x03b9, 0x03c7, 0x03b5, 0x03af, 0x03b1 };
-	const QChar turkish_data[12] ={ 0x0130, 0x0074, 0x0068, 0x0061, 0x006C, 0x0020, 0x00F6, 0x011F, 0x0065, 0x006C, 0x0065, 0x0072 };
+	const QChar russian_data[24] = {
+		0x0418, 0x043C, 0x043F, 0x043E, 0x0440, 0x0442, 0x0438, 0x0440,
+		0x043E, 0x0432, 0x0430, 0x043D, 0x043D, 0x044B, 0x0435, 0x0020,
+		0x044D, 0x043B, 0x0435, 0x043C, 0x0435, 0x043D, 0x0442, 0x044B};
+	const QChar greek_data[18] = {
+		0x0395,
+		0x03b9,
+		0x03c3,
+		0x03b7,
+		0x03b3,
+		0x03bc,
+		0x03ad,
+		0x03bd,
+		0x03b1,
+		0x0020,
+		0x03c3,
+		0x03c4,
+		0x03bf,
+		0x03b9,
+		0x03c7,
+		0x03b5,
+		0x03af,
+		0x03b1};
+	const QChar turkish_data[12] = {
+		0x0130,
+		0x0074,
+		0x0068,
+		0x0061,
+		0x006C,
+		0x0020,
+		0x00F6,
+		0x011F,
+		0x0065,
+		0x006C,
+		0x0065,
+		0x0072};
 	names.addName("fr", "Éléments importés");
 	names.addName("en", "Imported elements");
 	names.addName("de", "Importierte elemente");
@@ -65,69 +102,102 @@ XmlElementCollection::XmlElementCollection(QETProject *project) :
 	names.addName("da", "Importerede elementer");
 	names.addName("hr", "Uvezeni elementi");
 	names.addName("sl", "Uvoženi elementi");
-	
+#else
+#	if TODO_LIST
+#		pragma message("@TODO remove code for QT 6 or later")
+#	endif
+	qDebug() << "Help code for QT 6 or later";
+	names.addName("fr", "Éléments importés");
+	names.addName("en", "Imported elements");
+	names.addName("de", "Importierte elemente");
+	names.addName("es", "Elementos importados");
+	names.addName("cs", "Zavedené prvky");
+	names.addName("pl", "Elementy importowane");
+	names.addName("pt", "elementos importados");
+	names.addName("it", "Elementi importati");
+	names.addName("nl", "Elementen geïmporteerd");
+	names.addName("hr", "Uvezeni elementi");
+	names.addName("ca", "Elements importats");
+	names.addName("ro", "Elemente importate");
+	names.addName("da", "Importerede elementer");
+	names.addName("hr", "Uvezeni elementi");
+	names.addName("sl", "Uvoženi elementi");
+#endif
 
 	import.appendChild(names.toXml(m_dom_document));
 }
 
 /**
- * @brief XmlElementCollection::XmlElementCollection
- * Constructor with an collection. The tagName of @dom_element must be "collection"
- * @param dom_element -the collection in a dom_element (the dom element in cloned)
- * @param project : the project of this collection
- */
-XmlElementCollection::XmlElementCollection(const QDomElement &dom_element, QETProject *project) :
+	@brief XmlElementCollection::XmlElementCollection
+	Constructor with an collection.
+	The tagName of dom_element must be "collection"
+	@param dom_element :
+	-the collection in a dom_element (the dom element in cloned)
+	@param project : the project of this collection
+*/
+XmlElementCollection::XmlElementCollection(const QDomElement &dom_element,
+					   QETProject *project) :
 	QObject(project),
 	m_project(project)
 {
 	if (dom_element.tagName() == "collection")
-		m_dom_document.appendChild(m_dom_document.importNode(dom_element, true));
+		m_dom_document.appendChild(m_dom_document.importNode(
+						   dom_element, true));
 	else
 		qDebug() << "XmlElementCollection : tagName of dom_element is not collection";
 }
 
 /**
- * @brief XmlElementCollection::root
- * The root is the first DOM-Element the xml collection, the tag name
- * of the dom element is : collection
- * @return The root QDomElement of the collection
- */
-QDomElement XmlElementCollection::root() const {
+	@brief XmlElementCollection::root
+	The root is the first DOM-Element the xml collection, the tag name
+	of the dom element is : collection
+	@return The root QDomElement of the collection
+*/
+QDomElement XmlElementCollection::root() const
+{
 	return m_dom_document.documentElement();
 }
 
 /**
- * @brief XmlElementCollection::importCategory
- * @return The QDomElement import (the begining of a xml collection) or
- * a null QDomElement if doesn't exist.
- */
-QDomElement XmlElementCollection::importCategory() const {
+	@brief XmlElementCollection::importCategory
+	@return The QDomElement import (the begining of a xml collection) or
+	a null QDomElement if doesn't exist.
+*/
+QDomElement XmlElementCollection::importCategory() const
+{
 	return root().firstChildElement("category");
 }
 
 /**
- * @brief XmlElementCollection::childs
- * @param parent_element
- * @return All childs element in the @parent_element tree
- */
-QDomNodeList XmlElementCollection::childs(const QDomElement &parent_element) const
+	@brief XmlElementCollection::childs
+	@param parent_element
+	@return All childs element in the parent_element tree
+*/
+QDomNodeList XmlElementCollection::childs(
+		const QDomElement &parent_element) const
 {
-	if (parent_element.ownerDocument() != m_dom_document) return QDomNodeList();
+	if (parent_element.ownerDocument() != m_dom_document)
+		return QDomNodeList();
 	return parent_element.childNodes();
 }
 
 /**
- * @brief XmlElementCollection::child
- * If parent_element have child element with an attribute name = @child_name, return it, else return a null QDomElement.
- * Only search for element with tag-name "category" and "element" (if child_name end with ".elmt")
- * @param parent_element : the parent DomElement where we search for child.
- * @parent_element must be a child node of this XmlElementCollection.
- * @param child_name : name of child to search.
- * @return The child QDomElement or a null QDomElement if not found
- */
-QDomElement XmlElementCollection::child(const QDomElement &parent_element, const QString &child_name) const
+	@brief XmlElementCollection::child
+	If parent_element have child element
+	with an attribute name = child_name, return it,
+	else return a null QDomElement.
+	Only search for element with tag-name "category" and "element"
+	(if child_name end with ".elmt")
+	@param parent_element : the parent DomElement where we search for child.
+	parent_element must be a child node of this XmlElementCollection.
+	@param child_name : name of child to search.
+	@return The child QDomElement or a null QDomElement if not found
+*/
+QDomElement XmlElementCollection::child(const QDomElement &parent_element,
+					const QString &child_name) const
 {
-	if (parent_element.ownerDocument() != m_dom_document) return QDomElement();
+	if (parent_element.ownerDocument() != m_dom_document)
+		return QDomElement();
 
 		//Get all childs element of parent_element
 	QDomNodeList child_list = parent_element.childNodes();
@@ -136,7 +206,8 @@ QDomElement XmlElementCollection::child(const QDomElement &parent_element, const
 	for (int i=0 ; i<child_list.length() ; i++)
 	{
 		QDomElement child_element = child_list.item(i).toElement();
-		if (child_element.tagName() == tag_name) found_dom_element << child_element;
+		if (child_element.tagName() == tag_name)
+			found_dom_element << child_element;
 	}
 
 	if (found_dom_element.isEmpty()) return QDomElement();
@@ -149,10 +220,10 @@ QDomElement XmlElementCollection::child(const QDomElement &parent_element, const
 }
 
 /**
- * @brief XmlElementCollection::child
- * @param path
- * @return the DomElement at path if exist, else return a null QDomElement
- */
+	@brief XmlElementCollection::child
+	@param path
+	@return the DomElement at path if exist, else return a null QDomElement
+*/
 QDomElement XmlElementCollection::child(const QString &path) const
 {
 	QStringList path_list = path.split("/");
@@ -173,11 +244,12 @@ QDomElement XmlElementCollection::child(const QString &path) const
 }
 
 /**
- * @brief XmlElementCollection::directories
- * @param parent_element
- * @return A list of directory stored in @parent_element
- */
-QList<QDomElement> XmlElementCollection::directories(const QDomElement &parent_element) const
+	@brief XmlElementCollection::directories
+	@param parent_element
+	@return A list of directory stored in parent_element
+*/
+QList<QDomElement> XmlElementCollection::directories(
+		const QDomElement &parent_element) const
 {
 	QList <QDomElement> directory_list;
 	QDomNodeList node_list = childs(parent_element);
@@ -186,7 +258,8 @@ QList<QDomElement> XmlElementCollection::directories(const QDomElement &parent_e
 	for (int i=0 ; i < node_list.count() ; i++)
 	{
 		QDomNode node = node_list.at(i);
-		if (node.isElement() &&  node.toElement().tagName() == "category")
+		if (node.isElement()
+				&& node.toElement().tagName() == "category")
 			directory_list << node.toElement();
 	}
 
@@ -194,11 +267,12 @@ QList<QDomElement> XmlElementCollection::directories(const QDomElement &parent_e
 }
 
 /**
- * @brief XmlElementCollection::directoriesNames
- * @param parent_element
- * @return a list of names for every child directories of @parent_element
- */
-QStringList XmlElementCollection::directoriesNames(const QDomElement &parent_element) const
+	@brief XmlElementCollection::directoriesNames
+	@param parent_element
+	@return a list of names for every child directories of parent_element
+*/
+QStringList XmlElementCollection::directoriesNames(
+		const QDomElement &parent_element) const
 {
 	QList <QDomElement> childs = directories(parent_element);
 	QStringList names;
@@ -214,11 +288,12 @@ QStringList XmlElementCollection::directoriesNames(const QDomElement &parent_ele
 }
 
 /**
- * @brief XmlElementCollection::elements
- * @param parent_element
- * @return A list of element stored in @parent_element
- */
-QList<QDomElement> XmlElementCollection::elements(const QDomElement &parent_element) const
+	@brief XmlElementCollection::elements
+	@param parent_element
+	@return A list of element stored in parent_element
+*/
+QList<QDomElement> XmlElementCollection::elements(
+		const QDomElement &parent_element) const
 {
 	QList <QDomElement> element_list;
 	QDomNodeList node_list = childs(parent_element);
@@ -227,7 +302,7 @@ QList<QDomElement> XmlElementCollection::elements(const QDomElement &parent_elem
 	for (int i=0 ; i < node_list.count() ; i++)
 	{
 		QDomNode node = node_list.at(i);
-		if (node.isElement() &&  node.toElement().tagName() == "element")
+		if (node.isElement() && node.toElement().tagName() == "element")
 			element_list << node.toElement();
 	}
 
@@ -235,11 +310,12 @@ QList<QDomElement> XmlElementCollection::elements(const QDomElement &parent_elem
 }
 
 /**
- * @brief XmlElementCollection::elementsNames
- * @param parent_element
- * @return A list of names fr every childs element of @parent_element
- */
-QStringList XmlElementCollection::elementsNames(const QDomElement &parent_element) const
+	@brief XmlElementCollection::elementsNames
+	@param parent_element
+	@return A list of names fr every childs element of parent_element
+*/
+QStringList XmlElementCollection::elementsNames(
+		const QDomElement &parent_element) const
 {
 	QList <QDomElement> childs = elements(parent_element);
 	QStringList names;
@@ -255,11 +331,11 @@ QStringList XmlElementCollection::elementsNames(const QDomElement &parent_elemen
 }
 
 /**
- * @brief XmlElementCollection::element
- * @param path : path of the element in this collection
- * @return the QDomElement that represent the element at path @path
- * or a null QDomElement if not found or doesn't represent an element
- */
+	@brief XmlElementCollection::element
+	@param path : path of the element in this collection
+	@return the QDomElement that represent the element at path path
+	or a null QDomElement if not found or doesn't represent an element
+*/
 QDomElement XmlElementCollection::element(const QString &path) const
 {
 	if (!path.endsWith(".elmt")) return QDomElement();
@@ -273,11 +349,11 @@ QDomElement XmlElementCollection::element(const QString &path) const
 }
 
 /**
- * @brief XmlElementCollection::directory
- * @param path : path of the directory in this collection
- * @return the QDomElement that represent the directory at path @path
- * or a null QDomElement if not found.
- */
+	@brief XmlElementCollection::directory
+	@param path : path of the directory in this collection
+	@return the QDomElement that represent the directory at path path
+	or a null QDomElement if not found.
+*/
 QDomElement XmlElementCollection::directory(const QString &path) const
 {
 	QDomElement directory = child(path);
@@ -289,70 +365,81 @@ QDomElement XmlElementCollection::directory(const QString &path) const
 }
 
 /**
- * @brief XmlElementCollection::addElement
- * Add the element at location to this collection.
- * The element is copied in this collection in "import" dir with the same path, in other word
- * if the path is dir1/dir2/dir3/myElement.elmt, myElement is copied to this collection at the path : import/dir1/dir2/dir3/myElement.elmt
- * If the path doesn't exist, he was created.
- * If the element already exist, do nothing.
- * @param location, location of the element
- * @return the collection path of the added item or a null QString if element can't be added.
- */
+	@brief XmlElementCollection::addElement
+	Add the element at location to this collection.
+	The element is copied in this collection
+	in "import" dir with the same path, in other word
+	if the path is dir1/dir2/dir3/myElement.elmt,
+	myElement is copied to this collection at the
+	path : import/dir1/dir2/dir3/myElement.elmt
+	If the path doesn't exist, he was created.
+	If the element already exist, do nothing.
+	@param location : location of the element
+	@return the collection path of the added item
+	or a null QString if element can't be added.
+*/
 QString XmlElementCollection::addElement(ElementsLocation &location)
 {
-		//location must be an element and exist
+	//location must be an element and exist
 	if (!(location.exist() && location.isElement()))
 		return QString();
 
-		//Add an element from this collection to this collection have no sense
+	//Add an element from this collection to this collection have no sense
 	if (location.isProject() && location.projectCollection() == this)
 		return QString();
 
-		//First we check if this location exist in this collection if so, we do nothing
+	//First we check if this location exist in this collection if so, we do nothing
 	if ( exist("import/" + location.collectionPath(false)) )
 		return QString();
 
-		//Get the import dir of this collection
+	//Get the import dir of this collection
 	QDomElement parent_element = importCategory();
 	if (parent_element.isNull())
 		return QString();
 
 	QString integrated_path = parent_element.attribute("name");
 
-		//Split the path
+	//Split the path
 	QStringList splitted_path = location.collectionPath(false).split("/");
 	if (splitted_path.isEmpty())
 		return QString();
 
 	if (location.isFileSystem()) {
-			//Get the root dir of the filesystem collection
-		QDir dir(location.fileSystemPath().remove(location.collectionPath(false)));
+		//Get the root dir of the filesystem collection
+		QDir dir(location.fileSystemPath().remove(
+				 location.collectionPath(false)));
 		if (!dir.exists())
 			return QString();
 
 		foreach(QString str, splitted_path) {
 			QDomElement child_element = child(parent_element, str);
 
-				//Child doesn't exist, we create it
+			//Child doesn't exist, we create it
 			if (child_element.isNull()) {
 				QDomElement created_child;
 
-					//str is the path of an element, we integrate an element
+				//str is the path of an element, we integrate an element
 				if (str.endsWith(".elmt")) {
 					QFile element_file(dir.filePath(str));
 					if (!element_file.exists())
 						return QString();
 
-					created_child = QETXML::fileSystemElementToXmlCollectionElement(m_dom_document, element_file);
+					created_child = QETXML::
+							fileSystemElementToXmlCollectionElement(
+								m_dom_document,
+								element_file);
 				}
 
-					//str is the path of a directory, we integrate a directory.
+				//str is the path of a directory, we integrate a directory.
 				else {
-						//Dir doesn't exist.
+					//Dir doesn't exist.
 					if (!dir.cd(str))
 						return QString();
 
-					created_child = QETXML::fileSystemDirToXmlCollectionDir(m_dom_document, dir);
+					created_child = QETXML::
+							fileSystemDirToXmlCollectionDir(
+								m_dom_document,
+								dir);
 				}
 
 				if(created_child.isNull())
@@ -361,7 +448,7 @@ QString XmlElementCollection::addElement(ElementsLocation &location)
 				parent_element.appendChild(created_child);
 				parent_element = created_child;
 			}
-				//Child exist
+			//Child exist
 			else {
 				if (!dir.cd(str))
 					return QString();
@@ -382,11 +469,11 @@ QString XmlElementCollection::addElement(ElementsLocation &location)
 
 			QDomElement child_element = child(parent_element, str);
 
-				//Child doesn't exist, we create it
+			//Child doesn't exist, we create it
 			if (child_element.isNull()) {
 				QDomElement created_child;
 
-					//str is the path of an element, we integrate an element
+				//str is the path of an element, we integrate an element
 				if (str.endsWith(".elmt")) {
 					created_child = m_dom_document.createElement("element");
 					created_child.setAttribute("name", str);
@@ -394,7 +481,7 @@ QString XmlElementCollection::addElement(ElementsLocation &location)
 					created_child.appendChild(location.xml().cloneNode(true));
 				}
 
-					//str is the path of a directory, we integrate a directory.
+				//str is the path of a directory, we integrate a directory.
 				else {
 					created_child = m_dom_document.createElement("category");
 					created_child.setAttribute("name", str);
@@ -410,7 +497,7 @@ QString XmlElementCollection::addElement(ElementsLocation &location)
 				parent_element.appendChild(created_child);
 				parent_element = created_child;
 			}
-				//Child exist
+			//Child exist
 			else
 				parent_element = child_element;
 
@@ -423,20 +510,27 @@ QString XmlElementCollection::addElement(ElementsLocation &location)
 }
 
 /**
- * @brief XmlElementCollection::addElementDefinition
- * Add the élément defintion @xml_definition in the directory at path @dir_path with the name @elmt_name.
- * @param dir_path : the path of the directory where we must add the element.
- * The path must be an existing directory of this collection.
- * @param elmt_name : The name used to store the element (the name must end with .elmt, if not, .elmt will be append to @elmt_name)
- * @param xml_definition : The xml definition of the element.
- * The tag name of @xml_definition must be "definition".
- * @return True if the element is added with success.
- */
-bool XmlElementCollection::addElementDefinition(const QString &dir_path, const QString &elmt_name, const QDomElement &xml_definition)
+	@brief XmlElementCollection::addElementDefinition
+	Add the élément defintion xml_definition
+	in the directory at path dir_path with the name elmt_name.
+	@param dir_path :
+	the path of the directory where we must add the element.
+	The path must be an existing directory of this collection.
+	@param elmt_name : The name used to store the element
+	(the name must end with .elmt, if not, .elmt will be append to elmt_name)
+	@param xml_definition : The xml definition of the element.
+	The tag name of xml_definition must be "definition".
+	@return True if the element is added with success.
+*/
+bool XmlElementCollection::addElementDefinition(
+		const QString &dir_path,
+		const QString &elmt_name,
+		const QDomElement &xml_definition)
 {
 	QDomElement dom_dir = directory(dir_path);
 	if (dom_dir.isNull()) {
-		qDebug() << "XmlElementCollection::addElementDefinition : No directory at path : " << dir_path;
+		qDebug() << "XmlElementCollection::addElementDefinition : No directory at path : "
+			 << dir_path;
 		return false;
 	}
 
@@ -461,12 +555,12 @@ bool XmlElementCollection::addElementDefinition(const QString &dir_path, const Q
 }
 
 /**
- * @brief XmlElementCollection::removeElement
- * Remove the element at path @path.
- * @param path
- * @return True if element is removed and emit the signal elementRemoved.
- * else false.
- */
+	@brief XmlElementCollection::removeElement
+	Remove the element at path path.
+	@param path
+	@return True if element is removed and emit the signal elementRemoved.
+	else false.
+*/
 bool XmlElementCollection::removeElement(const QString& path)
 {
 	QDomElement elmt = element(path);
@@ -481,19 +575,31 @@ bool XmlElementCollection::removeElement(const QString& path)
 }
 
 /**
- * @brief XmlElementCollection::copy
- * Copy the content represented by source (an element or a directory) to destination.
- * Destination must be a directory of this collection.
- * If the destination already have an item at the same path of source, he will be replaced by source.
- * @param source : content to copy
- * @param destination : destination of the copy, must be a directory of this collection
- * @param rename : rename the copy with @rename else use the name of source
- * @param deep_copy : if true copy all childs of source (only if source is directory)
- * @return the ElementLocation that represent the copy, if copy failed return a null ElementLocation
- */
-ElementsLocation XmlElementCollection::copy(ElementsLocation &source, ElementsLocation &destination, const QString& rename, bool deep_copy)
+	@brief XmlElementCollection::copy
+	Copy the content represented by source (an element or a directory)
+	to destination.
+	Destination must be a directory of this collection.
+	If the destination already have an item at the same path of source,
+	he will be replaced by source.
+	@param source : content to copy
+	@param destination : destination of the copy, must be a directory
+	of this collection
+	@param rename : rename the copy with rename else use the name of source
+	@param deep_copy : if true copy all childs of source
+	(only if source is directory)
+	@return the ElementLocation that represent the copy,
+	if copy failed return a null ElementLocation
+*/
+ElementsLocation XmlElementCollection::copy(
+		ElementsLocation &source,
+		ElementsLocation &destination,
+		const QString& rename,
+		bool deep_copy)
 {
-	if (!(source.exist() && destination.isDirectory() && destination.isProject() && destination.projectCollection() == this))
+	if (!(source.exist()
+	      && destination.isDirectory()
+	      && destination.isProject()
+	      && destination.projectCollection() == this))
 		return ElementsLocation();
 
 	if (source.isElement())
@@ -503,11 +609,11 @@ ElementsLocation XmlElementCollection::copy(ElementsLocation &source, ElementsLo
 }
 
 /**
- * @brief XmlElementCollection::exist
- * Return true if the path @path exist in this collection
- * @param path
- * @return
- */
+	@brief XmlElementCollection::exist
+	Return true if the path path exist in this collection
+	@param path
+	@return
+*/
 bool XmlElementCollection::exist(const QString &path) const
 {
 	if (child(path).isNull())
@@ -517,15 +623,18 @@ bool XmlElementCollection::exist(const QString &path) const
 }
 
 /**
- * @brief XmlElementCollection::createDir
- * Create a child directorie at path @path with the name @name.
- * Emit directorieAdded if success.
- * @param path : path of parent diectorie
- * @param name : name of the directori to create.
- * @param name_list : translation of the directorie name.
- * @return true if creation success, if directorie already exist return true.
- */
-bool XmlElementCollection::createDir(const QString& path, const QString& name, const NamesList &name_list)
+	@brief XmlElementCollection::createDir
+	Create a child directorie at path path with the name name.
+	Emit directorieAdded if success.
+	@param path : path of parent diectorie
+	@param name : name of the directori to create.
+	@param name_list : translation of the directorie name.
+	@return true if creation success,
+	if directorie already exist return true.
+*/
+bool XmlElementCollection::createDir(const QString& path,
+				     const QString& name,
+				     const NamesList &name_list)
 {
 	QString new_dir_path = path + "/" + name;
 
@@ -551,12 +660,12 @@ bool XmlElementCollection::createDir(const QString& path, const QString& name, c
 }
 
 /**
- * @brief XmlElementCollection::removeDir
- * Remove the directory at path @path.
- * @param path
- * @return true if successfuly removed and emit directoryRemoved(QString),
- * else false.
- */
+	@brief XmlElementCollection::removeDir
+	Remove the directory at path path.
+	@param path
+	@return true if successfuly removed and emit directoryRemoved(QString),
+	else false.
+*/
 bool XmlElementCollection::removeDir(const QString& path)
 {
 	QDomElement dir = directory(path);
@@ -569,15 +678,18 @@ bool XmlElementCollection::removeDir(const QString& path)
 }
 
 /**
- * @brief XmlElementCollection::elementsLocation
- * Return all locations stored in dom_element (element and directory).
- * If dom_element is null, return all location owned by this collection
- * dom_element must be a child of this collection.
- * @param dom_element : dom_element where we must to search location.
- * @param childs = if true return all childs location of dom_element, if false, only return the direct childs location of dom_element.
- * @return
- */
-QList<ElementsLocation> XmlElementCollection::elementsLocation(QDomElement dom_element, bool childs) const
+	@brief XmlElementCollection::elementsLocation
+	Return all locations stored in dom_element (element and directory).
+	If dom_element is null, return all location owned by this collection
+	dom_element must be a child of this collection.
+	@param dom_element : dom_element where we must to search location.
+	@param childs = if true return all childs location of dom_element,
+	if false, only return the direct childs location of dom_element.
+	@return
+*/
+QList<ElementsLocation> XmlElementCollection::elementsLocation(
+		QDomElement dom_element,
+		bool childs) const
 {
 	QList <ElementsLocation> location_list;
 
@@ -612,19 +724,22 @@ QList<ElementsLocation> XmlElementCollection::elementsLocation(QDomElement dom_e
 }
 
 /**
- * @brief XmlElementCollection::domToLocation
- * Return the element location who represent the xml element : dom_element
- * dom_element must be owned by this collection
- * @param dom_element : the dom_element of this collection that represent an element.
- * The tag name of dom_element must be "element"
- * @return the element location, location can be null if fail.
- */
-ElementsLocation XmlElementCollection::domToLocation(QDomElement dom_element) const
+	@brief XmlElementCollection::domToLocation
+	Return the element location who represent the xml element : dom_element
+	dom_element must be owned by this collection
+	@param dom_element :
+	the dom_element of this collection that represent an element.
+	The tag name of dom_element must be "element"
+	@return the element location, location can be null if fail.
+*/
+ElementsLocation XmlElementCollection::domToLocation(
+		QDomElement dom_element) const
 {
 	if (dom_element.ownerDocument() == m_dom_document) {
 		QString path = dom_element.attribute("name");
 
-		while (!dom_element.parentNode().isNull() && dom_element.parentNode().isElement()) {
+		while (!dom_element.parentNode().isNull()
+				&& dom_element.parentNode().isElement()) {
 			dom_element = dom_element.parentNode().toElement();
 
 			if (dom_element.tagName() == "category")
@@ -638,9 +753,9 @@ ElementsLocation XmlElementCollection::domToLocation(QDomElement dom_element) co
 }
 
 /**
- * @brief XmlElementCollection::cleanUnusedElement
- * Remove elements in this collection which is not used in the owner project
- */
+	@brief XmlElementCollection::cleanUnusedElement
+	Remove elements in this collection which is not used in the owner project
+*/
 void XmlElementCollection::cleanUnusedElement()
 {
 	foreach (ElementsLocation loc, m_project->unusedElements())
@@ -648,17 +763,19 @@ void XmlElementCollection::cleanUnusedElement()
 }
 
 /**
- * @brief XmlElementCollection::cleanUnusedDirectory
- * Remove the empty directories of this collection
- */
+	@brief XmlElementCollection::cleanUnusedDirectory
+	Remove the empty directories of this collection
+*/
 void XmlElementCollection::cleanUnusedDirectory()
 {
 	QDomNodeList lst = importCategory().elementsByTagName("category");
 
 	for(int i=0 ; i<lst.size() ; i++) {
 		QDomElement dir = lst.item(i).toElement();
-			//elmt haven't got child node "element" or "category", so he is emty, we can remove it
-		if (dir.elementsByTagName("element").isEmpty() && dir.elementsByTagName("category").isEmpty()) {
+		//elmt haven't got child node "element" or "category",
+		//so he is emty, we can remove it
+		if (dir.elementsByTagName("element").isEmpty()
+				&& dir.elementsByTagName("category").isEmpty()) {
 			if (removeDir(domToLocation(dir).collectionPath(false)))
 				i=-1;
 		}
@@ -666,33 +783,41 @@ void XmlElementCollection::cleanUnusedDirectory()
 }
 
 /**
- * @brief XmlElementCollection::copyDirectory
- * Copy the directory represented by source to destination.
- * if destination have a directory with the same name as source, then this directory is removed
- * @param source : directory to copy
- * @param destination : destination of the copy
- * @param rename : rename the copy with @rename else use the name of source
- * @param deep_copy :if true copy all childs of source
- * @return the ElementLocation that represent the copy, if copy failed return a null ElementLocation
- */
-ElementsLocation XmlElementCollection::copyDirectory(ElementsLocation &source, ElementsLocation &destination, const QString& rename, bool deep_copy)
+	@brief XmlElementCollection::copyDirectory
+	Copy the directory represented by source to destination.
+	if destination have a directory with the same name as source,
+	then this directory is removed
+	@param source : directory to copy
+	@param destination : destination of the copy
+	@param rename : rename the copy with rename else use the name of source
+	@param deep_copy :if true copy all childs of source
+	@return the ElementLocation that represent the copy,
+	if copy failed return a null ElementLocation
+*/
+ElementsLocation XmlElementCollection::copyDirectory(
+		ElementsLocation &source,
+		ElementsLocation &destination,
+		const QString& rename,
+		bool deep_copy)
 {
 	QString new_dir_name = rename.isEmpty() ? source.fileName() : rename;
 
-			//Get the xml directory where the new directory must be added
+	//Get the xml directory where the new directory must be added
 	QDomElement parent_dir_dom = directory(destination.collectionPath(false));
 	if (parent_dir_dom.isNull()) return ElementsLocation();
 
-		//Remove the previous directory with the same path
-	QDomElement element = child(destination.collectionPath(false) + "/" + new_dir_name);
+	//Remove the previous directory with the same path
+	QDomElement element = child(destination.collectionPath(false)
+				    + "/" + new_dir_name);
 	if (!element.isNull()) {
 		element.parentNode().removeChild(element);
-		emit directoryRemoved(destination.collectionPath(false) + "/" + new_dir_name);
+		emit directoryRemoved(destination.collectionPath(false)
+				      + "/" + new_dir_name);
 	}
 
 	ElementsLocation created_location;
 
-		//Copy with a file system collection source
+	//Copy with a file system collection source
 	if (source.isFileSystem())
 	{
 		QDir source_dir(source.fileSystemPath());
@@ -700,40 +825,49 @@ ElementsLocation XmlElementCollection::copyDirectory(ElementsLocation &source, E
 
 
 		QDir dir(source.fileSystemPath());
-		QDomElement elmt_dom = QETXML::fileSystemDirToXmlCollectionDir(m_dom_document, dir, new_dir_name);
+		QDomElement elmt_dom = QETXML::fileSystemDirToXmlCollectionDir(
+					m_dom_document, dir, new_dir_name);
 		if (elmt_dom.isNull()) return ElementsLocation();
 
 		parent_dir_dom.appendChild(elmt_dom);
 
-		created_location.setPath(destination.projectCollectionPath() + "/" + new_dir_name);
+		created_location.setPath(destination.projectCollectionPath()
+					 + "/" + new_dir_name);
 
 		if (deep_copy)
 		{
-				//Append all directories of source to the new created directory
-			foreach(QString str, source_dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot, QDir::Name))
+			//Append all directories of source to the new created directory
+			foreach(QString str, source_dir.entryList(
+						QDir::Dirs | QDir::NoDotAndDotDot,
+						QDir::Name))
 			{
-				ElementsLocation sub_source(source.fileSystemPath() + "/" + str);
+				ElementsLocation sub_source(source.fileSystemPath()
+							    + "/" + str);
 				copyDirectory(sub_source, created_location);
 			}
 
-				//Append all elements of source to the new created directory
+			//Append all elements of source to the new created directory
 			source_dir.setNameFilters(QStringList() << "*.elmt");
-			foreach(QString str, source_dir.entryList(QDir::Files | QDir::NoDotAndDotDot, QDir::Name))
+			foreach(QString str, source_dir.entryList(
+						QDir::Files | QDir::NoDotAndDotDot,
+						QDir::Name))
 			{
-				ElementsLocation sub_source(source.fileSystemPath() + "/" + str);
+				ElementsLocation sub_source(source.fileSystemPath()
+							    + "/" + str);
 				copyElement(sub_source, created_location);
 			}
 		}
 	}
 
-		//Copy with a xml collection source
+	//Copy with a xml collection source
 	else
 	{
 		if (!source.projectCollection()) return ElementsLocation();
 
 		QDomNode other_collection_node = source.projectCollection()->child(source.collectionPath(false)).cloneNode(deep_copy);
 
-			//We don't make a deep copy, but we must to get the local names of the copied directory
+		//We don't make a deep copy,
+		// but we must to get the local names of the copied directory
 		if (!deep_copy) {
 			QDomNode names = source.projectCollection()->child(source.collectionPath(false)).namedItem("names");
 			if (!names.isNull() && names.isElement())
@@ -754,28 +888,32 @@ ElementsLocation XmlElementCollection::copyDirectory(ElementsLocation &source, E
 }
 
 /**
- * @brief XmlElementCollection::copyElement
- * Copy the element represented by source to destination (must be a directory)
- * If element already exist in destination he will be replaced by the new.
- * @param source : element to copy
- * @param destination : destination of the copy
- * @param rename : rename the copy with @rename else use the name of source
- * @return The ElementsLocation of the copy
- */
-ElementsLocation XmlElementCollection::copyElement(ElementsLocation &source, ElementsLocation &destination, const QString& rename)
+	@brief XmlElementCollection::copyElement
+	Copy the element represented by source to destination (must be a directory)
+	If element already exist in destination he will be replaced by the new.
+	@param source : element to copy
+	@param destination : destination of the copy
+	@param rename : rename the copy with rename else use the name of source
+	@return The ElementsLocation of the copy
+*/
+ElementsLocation XmlElementCollection::copyElement(
+		ElementsLocation &source,
+		ElementsLocation &destination,
+		const QString& rename)
 {
 	QString new_elmt_name = rename.isEmpty() ? source.fileName() : rename;
 
 	QDomElement elmt_dom;
 
-		//Copy with a file system collection source
+	//Copy with a file system collection source
 	if (source.isFileSystem())
 	{
 		QFile file(source.fileSystemPath());
-		elmt_dom = QETXML::fileSystemElementToXmlCollectionElement(m_dom_document, file, new_elmt_name);
+		elmt_dom = QETXML::fileSystemElementToXmlCollectionElement(
+					m_dom_document, file, new_elmt_name);
 		if (elmt_dom.isNull()) return ElementsLocation();
 	}
-		//Copy with a xml collection source
+	//Copy with a xml collection source
 	else
 	{
 		QDomElement other_collection = source.xml();
@@ -785,20 +923,22 @@ ElementsLocation XmlElementCollection::copyElement(ElementsLocation &source, Ele
 	}
 
 
-		//Remove the previous element with the same path
-	QDomElement element = child(destination.collectionPath(false) + "/" + new_elmt_name);
+	//Remove the previous element with the same path
+	QDomElement element = child(destination.collectionPath(false)
+				    + "/" + new_elmt_name);
 	bool removed = false;
 	if (!element.isNull()) {
 		element.parentNode().removeChild(element);
 		removed = true;
 	}
 
-		//Get the xml directory where the new element must be added
+	//Get the xml directory where the new element must be added
 	QDomElement dir_dom = directory(destination.collectionPath(false));
 	if (dir_dom.isNull()) return ElementsLocation();
 	dir_dom.appendChild(elmt_dom);
 
-	ElementsLocation copy_loc(destination.projectCollectionPath() + "/" + new_elmt_name);
+	ElementsLocation copy_loc(destination.projectCollectionPath()
+				  + "/" + new_elmt_name);
 
 	if (removed) {
 		emit elementChanged(copy_loc.collectionPath(false));
