@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 #ifndef REPLACEADVANCEDDIALOG_H
 #define REPLACEADVANCEDDIALOG_H
 
-#include "searchandreplaceworker.h"
+#include "../searchandreplaceworker.h"
 
 #include <QDialog>
 
