@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -18,8 +18,9 @@
 #ifndef REPLACEELEMENTDIALOG_H
 #define REPLACEELEMENTDIALOG_H
 
+#include "../../diagramcontext.h"
+
 #include <QDialog>
-#include "diagramcontext.h"
 
 class ElementInfoPartWidget;
 
