@@ -1,24 +1,25 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
-	
+
 	QElectroTech is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
 	the Free Software Foundation, either version 2 of the License, or
 	(at your option) any later version.
-	
+
 	QElectroTech is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU General Public License for more details.
-	
+
 	You should have received a copy of the GNU General Public License
 	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "conductorproperties.h"
 #include <QPainter>
-#include <utility>
-
+#include <QMetaEnum>
+#include <QRegularExpression>
+#include <QtDebug>
 /**
 	Constructeur par defaut
 */
@@ -31,7 +32,8 @@ SingleLineProperties::SingleLineProperties() :
 }
 
 /// Destructeur
-SingleLineProperties::~SingleLineProperties() {
+SingleLineProperties::~SingleLineProperties()
+{
 }
 
 /**
@@ -43,7 +45,8 @@ void SingleLineProperties::setPhasesCount(int n) {
 }
 
 /// @return le nombre de phases (0, 1, 2, ou 3)
-unsigned short int SingleLineProperties::phasesCount() {
+unsigned short int SingleLineProperties::phasesCount()
+{
 	return(phases);
 }
 
@@ -52,7 +55,8 @@ unsigned short int SingleLineProperties::phasesCount() {
 	(Protective Earth Neutral) representation and if it features the ground and
 	the neutral.
 */
-bool SingleLineProperties::isPen() const {
+bool SingleLineProperties::isPen() const
+{
 	return(hasNeutral && hasGround && is_pen);
 }
 
@@ -62,10 +66,12 @@ bool SingleLineProperties::isPen() const {
 	@param direction direction du segment sur lequel les symboles apparaitront
 	@param rect rectangle englobant le dessin ; utilise pour specifier a la fois la position et la taille du dessin
 */
-void SingleLineProperties::draw(QPainter *painter, QET::ConductorSegmentType direction, const QRectF &rect) {
+void SingleLineProperties::draw(QPainter *painter,
+				QET::ConductorSegmentType direction,
+				const QRectF &rect) {
 	// s'il n'y a rien a dessiner, on retourne immediatement
 	if (!hasNeutral && !hasGround && !phases) return;
-	
+
 	// prepare le QPainter
 	painter -> save();
 	QPen pen(painter -> pen());
@@ -75,12 +81,12 @@ void SingleLineProperties::draw(QPainter *painter, QET::ConductorSegmentType dir
 	pen.setWidthF(1);
 	painter -> setPen(pen);
 	painter -> setRenderHint(QPainter::Antialiasing, true);
-	
+
 	uint symbols_count = (hasNeutral ? 1 : 0) + (hasGround ? 1 : 0) - (isPen() ? 1 : 0) + phases;
 	qreal interleave_base = (direction == QET::Horizontal ? rect.width() : rect.height());
 	qreal interleave = interleave_base / (symbols_count + 1);;
 	qreal symbol_width = interleave_base / 12;
-	
+
 	for (uint i = 1 ; i <= symbols_count ; ++ i) {
 		// dessine le tronc du symbole
 		QPointF symbol_p1, symbol_p2;
@@ -92,7 +98,7 @@ void SingleLineProperties::draw(QPainter *painter, QET::ConductorSegmentType dir
 			symbol_p1 = QPointF(rect.x() + rect.width() * 0.25, rect.y() + (i * interleave) + symbol_width);
 		}
 		painter -> drawLine(QLineF(symbol_p1, symbol_p2));
-		
+
 		// dessine le reste des symboles terre et neutre
 		if (isPen()) {
 			if (i == 1) {
@@ -102,7 +108,7 @@ void SingleLineProperties::draw(QPainter *painter, QET::ConductorSegmentType dir
 			if (hasGround && i == 1) {
 				drawGround(painter, direction, symbol_p2, symbol_width * 2.0);
 			} else if (hasNeutral && ((i == 1 && !hasGround) || (i == 2 && hasGround))) {
-				drawNeutral(painter, direction, symbol_p2, symbol_width * 1.5);
+				drawNeutral(painter, symbol_p2, symbol_width * 1.5);
 			}
 		}
 	}
@@ -116,15 +122,18 @@ void SingleLineProperties::draw(QPainter *painter, QET::ConductorSegmentType dir
 	@param center centre du segment
 	@param size taille du segment
 */
-void SingleLineProperties::drawGround(QPainter *painter, QET::ConductorSegmentType direction, QPointF center, qreal size) {
+void SingleLineProperties::drawGround(QPainter *painter,
+				      QET::ConductorSegmentType direction,
+				      QPointF center,
+				      qreal size) {
 	painter -> save();
-	
+
 	// prepare le QPainter
 	painter -> setRenderHint(QPainter::Antialiasing, false);
 	QPen pen2(painter -> pen());
 	pen2.setCapStyle(Qt::SquareCap);
 	painter -> setPen(pen2);
-	
+
 	// dessine le segment representant la terre
 	qreal half_size = size / 2.0;
 	QPointF offset_point(
@@ -137,25 +146,27 @@ void SingleLineProperties::drawGround(QPainter *painter, QET::ConductorSegmentTy
 			center - offset_point
 		)
 	);
-	
+
 	painter -> restore();
 }
 
 /**
 	Dessine le cercle correspondant au symbole du neutre sur un conducteur unifilaire
 	@param painter QPainter a utiliser pour dessiner le segment
-	@param direction direction du segment sur lequel le symbole apparaitra
 	@param center centre du cercle
 	@param size diametre du cercle
 */
-void SingleLineProperties::drawNeutral(QPainter *painter, QET::ConductorSegmentType direction, QPointF center, qreal size) {
-	Q_UNUSED(direction);
+void SingleLineProperties::drawNeutral(
+		QPainter *painter,
+		QPointF center,
+		qreal size)
+{
 	painter -> save();
-	
+
 	// prepare le QPainter
 	if (painter -> brush() == Qt::NoBrush) painter -> setBrush(Qt::black);
 	painter -> setPen(Qt::NoPen);
-	
+
 	// desine le cercle representant le neutre
 	painter -> drawEllipse(
 		QRectF(
@@ -163,18 +174,26 @@ void SingleLineProperties::drawNeutral(QPainter *painter, QET::ConductorSegmentT
 			QSizeF(size, size)
 		)
 	);
-	
+
 	painter -> restore();
 }
 
 /**
-	Draw the PEN (Protective Earth Neutral) symbol using \a painter at position \a
-	center, using a size hint of \a size.
-	@param direction Indicate the direction of the underlying conductor segment
+	@brief SingleLineProperties::drawPen
+	Draw the PEN (Protective Earth Neutral) symbol using
+	\a painter at position \a center, using a size hint of \a size.
+	@param painter
+	@param direction :
+	Indicate the direction of the underlying conductor segment
+	@param center
+	@param size
 */
-void SingleLineProperties::drawPen(QPainter *painter, QET::ConductorSegmentType direction, QPointF center, qreal size) {
+void SingleLineProperties::drawPen(QPainter *painter,
+				   QET::ConductorSegmentType direction,
+				   QPointF center,
+				   qreal size) {
 	painter -> save();
-	
+
 	//painter -> setBrush(Qt::white);
 	// desine le cercle representant le neutre
 	//painter -> drawEllipse(
@@ -183,8 +202,8 @@ void SingleLineProperties::drawPen(QPainter *painter, QET::ConductorSegmentType
 	//		QSizeF(size * 1.5, size * 1.5)
 	//	)
 	//);
-	drawNeutral(painter, direction, center, size * 1.5);
-	
+	drawNeutral(painter, center, size * 1.5);
+
 	int offset = (size * 1.5 / 2.0);
 	QPointF pos = center + (direction == QET::Horizontal ? QPointF(0.0, -offset - 0.5) : QPointF(offset + 0.5, 0.0));
 	drawGround(painter, direction, pos, 2.0 * size);
@@ -196,7 +215,8 @@ void SingleLineProperties::drawPen(QPainter *painter, QET::ConductorSegmentType
 	ajoutes a l'element e.
 	@param e Element XML auquel seront ajoutes des attributs
 */
-void SingleLineProperties::toXml(QDomElement &e) const {
+void SingleLineProperties::toXml(QDomElement &e) const
+{
 	e.setAttribute("ground",  hasGround  ? "true" : "false");
 	e.setAttribute("neutral", hasNeutral ? "true" : "false");
 	e.setAttribute("phase",   phases);
@@ -222,6 +242,7 @@ void SingleLineProperties::fromXml(QDomElement &e) {
 ConductorProperties::ConductorProperties() :
 	type(Multi),
 	color(Qt::black),
+	text_color(Qt::black),
 	text("_"),
 	text_size(9),
 	cond_size(1),
@@ -235,44 +256,50 @@ ConductorProperties::ConductorProperties() :
 /**
 	Destructeur
 */
-ConductorProperties::~ConductorProperties() {
+ConductorProperties::~ConductorProperties()
+{
 }
 
 
 /**
- * @brief ConductorProperties::toXml
- * Export conductor propertie, in the XML element 'e'
- * @param e the xml element
- */
+	@brief ConductorProperties::toXml
+	Export conductor propertie, in the XML element 'e'
+	@param e the xml element
+*/
 void ConductorProperties::toXml(QDomElement &e) const
 {
 	e.setAttribute("type", typeToString(type));
 
 	if (color != QColor(Qt::black))
 		e.setAttribute("color", color.name());
-	
+
 	e.setAttribute("bicolor", m_bicolor? "true" : "false");
 	e.setAttribute("color2", m_color_2.name());
 	e.setAttribute("dash-size", QString::number(m_dash_size));
-	
+
 	if (type == Single)
 		singleLineProperties.toXml(e);
 
 	e.setAttribute("num", text);
+	e.setAttribute("text_color", text_color.name());
 	e.setAttribute("formula", m_formula);
+	e.setAttribute("cable", m_cable);
+	e.setAttribute("bus", m_bus);
 	e.setAttribute("function", m_function);
-	e.setAttribute("tension-protocol", m_tension_protocol);
+	e.setAttribute("tension_protocol", m_tension_protocol);
+	e.setAttribute("conductor_color", m_wire_color);
+	e.setAttribute("conductor_section", m_wire_section);
 	e.setAttribute("numsize", QString::number(text_size));
 	e.setAttribute("condsize", QString::number(cond_size));
 	e.setAttribute("displaytext", m_show_text);
 	e.setAttribute("onetextperfolio", m_one_text_per_folio);
 	e.setAttribute("vertirotatetext", QString::number(verti_rotate_text));
 	e.setAttribute("horizrotatetext", QString::number(horiz_rotate_text));
-	
+
 	QMetaEnum me = QMetaEnum::fromType<Qt::Alignment>();
 	e.setAttribute("horizontal-alignment", me.valueToKey(m_horizontal_alignment));
 	e.setAttribute("vertical-alignment", me.valueToKey(m_vertical_alignment));
-	
+
 	QString conductor_style = writeStyle();
 	if (!conductor_style.isEmpty())
 		e.setAttribute("style", conductor_style);
@@ -280,27 +307,27 @@ void ConductorProperties::toXml(QDomElement &e) const
 
 
 /**
- * @brief ConductorProperties::fromXml
- * Import conductor propertie, from the attribute of the xml element 'e'
- * @param e the xml document
- */
+	@brief ConductorProperties::fromXml
+	Import conductor propertie, from the attribute of the xml element 'e'
+	@param e the xml document
+*/
 void ConductorProperties::fromXml(QDomElement &e)
 {
 		// get conductor color
 	QColor xml_color= QColor(e.attribute("color"));
 	color = (xml_color.isValid()? xml_color : QColor(Qt::black));
-	
+
 	QString bicolor_str = e.attribute("bicolor", "false");
 	m_bicolor = bicolor_str == "true"? true : false;
-	
-    QColor xml_color_2 = QColor(e.attribute("color2"));
+
+	QColor xml_color_2 = QColor(e.attribute("color2"));
 	m_color_2 = xml_color_2.isValid()? xml_color_2 : QColor(Qt::black);
-	
+
 	m_dash_size = e.attribute("dash-size", QString::number(1)).toInt();
-	
+
 		// read style of conductor
 	readStyle(e.attribute("style"));
-	
+
 	if (e.attribute("type") == typeToString(Single))
 	{
 			// get specific properties for single conductor
@@ -311,23 +338,43 @@ void ConductorProperties::fromXml(QDomElement &e)
 		type = Multi;
 
 	text                 = e.attribute("num");
+	// get text color
+	QColor xml_text_color= QColor(e.attribute("text_color"));
+	text_color = (xml_text_color.isValid()? xml_text_color : QColor(Qt::black));
 	m_formula            = e.attribute("formula");
+	m_cable              = e.attribute("cable");
+	m_bus                = e.attribute("bus");
 	m_function           = e.attribute("function");
-	m_tension_protocol   = e.attribute("tension-protocol");
+	m_tension_protocol   = e.attribute("tension_protocol");
+	m_wire_color         = e.attribute("conductor_color");
+	m_wire_section       = e.attribute("conductor_section");
 	text_size            = e.attribute("numsize", QString::number(9)).toInt();
 	cond_size            = e.attribute("condsize", QString::number(1)).toDouble();
 	m_show_text          = e.attribute("displaytext", QString::number(1)).toInt();
 	m_one_text_per_folio = e.attribute("onetextperfolio", QString::number(0)).toInt();
 	verti_rotate_text    = e.attribute("vertirotatetext").toDouble();
 	horiz_rotate_text    = e.attribute("horizrotatetext").toDouble();
-	
-	QMetaEnum me = QMetaEnum::fromType<Qt::Alignment>();
-	m_horizontal_alignment = Qt::Alignment(me.keyToValue(e.attribute("horizontal-alignment", "AlignBottom").toStdString().data()));
-	m_vertical_alignment = Qt::Alignment(me.keyToValue(e.attribute("vertical-alignment", "AlignRight").toStdString().data()));
 
-		//Keep retrocompatible with version older than 0,4
-		//If the propertie @type is simple (removed since QET 0,4), we set text no visible.
-		//@TODO remove this code for qet 0.6 or later
+	QMetaEnum me = QMetaEnum::fromType<Qt::Alignment>();
+	m_horizontal_alignment = Qt::Alignment(
+				me.keyToValue(
+					e.attribute(
+						"horizontal-alignment",
+						"AlignBottom"
+						).toStdString().data()));
+	m_vertical_alignment = Qt::Alignment(
+				me.keyToValue(
+					e.attribute(
+						"vertical-alignment",
+						"AlignRight"
+						).toStdString().data()));
+
+	//Keep retrocompatible with version older than 0,4
+	//If the propertie @type is simple (removed since QET 0,4), we set text no visible.
+	//@TODO remove this code for qet 0.6 or later
+#if TODO_LIST
+#pragma message("@TODO remove this code for qet 0.6 or later")
+#endif
 	if (e.attribute("type") == "simple") m_show_text = false;
 }
 
@@ -344,16 +391,21 @@ void ConductorProperties::toSettings(QSettings &settings, const QString &prefix)
 	settings.setValue(prefix + "style", writeStyle());
 	settings.setValue(prefix + "type", typeToString(type));
 	settings.setValue(prefix + "text", text);
+	settings.setValue(prefix + "text_color", text_color.name());
 	settings.setValue(prefix + "formula", m_formula);
+	settings.setValue(prefix + "cable", m_cable);
+	settings.setValue(prefix + "bus", m_bus);
 	settings.setValue(prefix + "function", m_function);
-	settings.setValue(prefix + "tension-protocol", m_tension_protocol);
+	settings.setValue(prefix + "tension_protocol", m_tension_protocol);
+	settings.setValue(prefix + "conductor_color", m_wire_color);
+	settings.setValue(prefix + "conductor_section", m_wire_section);
 	settings.setValue(prefix + "textsize", QString::number(text_size));
 	settings.setValue(prefix + "size", QString::number(cond_size));
 	settings.setValue(prefix + "displaytext", m_show_text);
 	settings.setValue(prefix + "onetextperfolio", m_one_text_per_folio);
 	settings.setValue(prefix + "vertirotatetext", QString::number(verti_rotate_text));
 	settings.setValue(prefix + "horizrotatetext", QString::number(horiz_rotate_text));
-	
+
 	QMetaEnum me = QMetaEnum::fromType<Qt::Alignment>();
 	settings.setValue(prefix + "horizontal-alignment", me.valueToKey(m_horizontal_alignment));
 	settings.setValue(prefix + "vertical-alignment", me.valueToKey(m_vertical_alignment));
@@ -369,33 +421,39 @@ void ConductorProperties::fromSettings(QSettings &settings, const QString &prefi
 {
 	QColor settings_color = QColor(settings.value(prefix + "color").toString());
 	color = (settings_color.isValid()? settings_color : QColor(Qt::black));
-	
+
 	QColor settings_color_2 = QColor(settings.value(prefix + "color2").toString());
 	m_color_2 = (settings_color_2.isValid()? settings_color_2 : QColor(Qt::black));
-	
+
 	m_bicolor   = settings.value(prefix + "bicolor", false).toBool();
 	m_dash_size = settings.value(prefix + "dash-size", 1).toInt();
-	
+
 	QString setting_type = settings.value(prefix + "type", typeToString(Multi)).toString();
 	type = (setting_type == typeToString(Single)? Single : Multi);
 
 	singleLineProperties.fromSettings(settings, prefix);
 
 	text                 = settings.value(prefix + "text", "_").toString();
+	QColor settings_text_color = QColor(settings.value(prefix + "text_color").toString());
+	text_color = (settings_text_color.isValid()? settings_text_color : QColor(Qt::black));
 	m_formula            = settings.value(prefix + "formula", "").toString();
+	m_cable              = settings.value(prefix + "cable", "").toString();
+	m_bus                = settings.value(prefix + "bus", "").toString();
 	m_function           = settings.value(prefix + "function", "").toString();
-	m_tension_protocol   = settings.value(prefix + "tension-protocol", "").toString();
+	m_tension_protocol   = settings.value(prefix + "tension_protocol", "").toString();
+	m_wire_color         = settings.value(prefix + "conductor_color", "").toString();
+	m_wire_section       = settings.value(prefix + "conductor_section", "").toString();
 	text_size            = settings.value(prefix + "textsize", "7").toInt();
 	cond_size            = settings.value(prefix + "size", "1").toInt();
 	m_show_text          = settings.value(prefix + "displaytext", true).toBool();
 	m_one_text_per_folio = settings.value(prefix + "onetextperfolio", false).toBool();
 	verti_rotate_text    = settings.value((prefix + "vertirotatetext"), "270").toDouble();
 	horiz_rotate_text    = settings.value((prefix + "horizrotatetext"), "0").toDouble();
-	
+
 	QMetaEnum me = QMetaEnum::fromType<Qt::Alignment>();
 	m_horizontal_alignment = Qt::Alignment(me.keyToValue(settings.value(prefix + "horizontal-alignment", "AlignBottom").toString().toStdString().data()));
 	m_vertical_alignment = Qt::Alignment(me.keyToValue(settings.value(prefix + "vertical-alignment", "AlignRight").toString().toStdString().data()));
-	
+
 	readStyle(settings.value(prefix + "style").toString());
 }
 
@@ -413,15 +471,15 @@ QString ConductorProperties::typeToString(ConductorType t)
 }
 
 /**
- * @brief ConductorProperties::applyForEqualAttributes
- * Test each attribute of properties in the list separatly.
- * For each attributes, if is equal, the attribute is apply to this.
- * @param list
- */
+	@brief ConductorProperties::applyForEqualAttributes
+	Test each attribute of properties in the list separatly.
+	For each attributes, if is equal, the attribute is apply to this.
+	@param list
+*/
 void ConductorProperties::applyForEqualAttributes(QList<ConductorProperties> list)
 {
 	const QList<ConductorProperties> clist = std::move(list);
-	
+
 	if (clist.isEmpty())
 		return;
 
@@ -433,9 +491,14 @@ void ConductorProperties::applyForEqualAttributes(QList<ConductorProperties> lis
 		m_color_2            = cp.m_color_2;
 		m_dash_size          = cp.m_dash_size;
 		text                 = cp.text;
+		text_color           = cp.text_color;
 		m_formula            = cp.m_formula;
+		m_cable              = cp.m_cable;
+		m_bus                = cp.m_bus;
 		m_function           = cp.m_function;
 		m_tension_protocol   = cp.m_tension_protocol;
+		m_wire_color         = cp.m_wire_color;
+		m_wire_section       = cp.m_wire_section;
 		text_size            = cp.text_size;
 		cond_size            = cp.cond_size;
 		m_show_text          = cp.m_show_text;
@@ -455,7 +518,7 @@ void ConductorProperties::applyForEqualAttributes(QList<ConductorProperties> lis
 	int i_value;
 	double d_value;
 	Qt::Alignment align_value;
-	
+
 		//Color
 	c_value = clist.first().color;
 	for(ConductorProperties cp : clist)
@@ -466,7 +529,7 @@ void ConductorProperties::applyForEqualAttributes(QList<ConductorProperties> lis
 	if (equal)
 		color = c_value;
 	equal = true;
-	
+
 		//bicolor
 	b_value = clist.first().m_bicolor;
 	for(ConductorProperties cp : clist)
@@ -477,7 +540,7 @@ void ConductorProperties::applyForEqualAttributes(QList<ConductorProperties> lis
 	if (equal)
 		m_bicolor = b_value;
 	equal = true;
-	
+
 		//second color
 	c_value = clist.first().m_color_2;
 	for(ConductorProperties cp : clist)
@@ -488,7 +551,7 @@ void ConductorProperties::applyForEqualAttributes(QList<ConductorProperties> lis
 	if (equal)
 		m_color_2 = c_value;
 	equal = true;
-	
+
 		//Dash size
 	i_value = clist.first().m_dash_size;
 	for(ConductorProperties cp : clist)
@@ -511,6 +574,17 @@ void ConductorProperties::applyForEqualAttributes(QList<ConductorProperties> lis
 		text = s_value;
 	equal = true;
 
+		//text color
+	c_value = clist.first().text_color;
+	for(ConductorProperties cp : clist)
+	{
+		if (cp.text_color != c_value)
+			equal = false;
+	}
+	if (equal)
+		text_color = c_value;
+	equal = true;
+
 		//formula
 	s_value = clist.first().m_formula;
 	for(ConductorProperties cp : clist)
@@ -522,7 +596,29 @@ void ConductorProperties::applyForEqualAttributes(QList<ConductorProperties> lis
 		m_formula = s_value;
 	equal = true;
 
-		//function
+	//cable
+	s_value = clist.first().m_cable;
+	for(ConductorProperties cp : clist)
+	{
+		if (cp.m_cable != s_value)
+			equal = false;
+	}
+	if (equal)
+		m_cable = s_value;
+	equal = true;
+
+	//bus
+	s_value = clist.first().m_bus;
+	for(ConductorProperties cp : clist)
+	{
+		if (cp.m_bus != s_value)
+			equal = false;
+	}
+	if (equal)
+		m_bus = s_value;
+	equal = true;
+
+	//function
 	s_value = clist.first().m_function;
 	for(ConductorProperties cp : clist)
 	{
@@ -544,6 +640,29 @@ void ConductorProperties::applyForEqualAttributes(QList<ConductorProperties> lis
 		m_tension_protocol = s_value;
 	equal = true;
 
+		//conductor_color
+	s_value = clist.first().m_wire_color;
+	for(ConductorProperties cp : clist)
+	{
+		if (cp.m_wire_color != s_value)
+			equal = false;
+	}
+	if (equal)
+		m_wire_color = s_value;
+	equal = true;
+
+		//conductor_section
+	s_value = clist.first().m_wire_section;
+	for(ConductorProperties cp : clist)
+	{
+		if (cp.m_wire_section != s_value)
+			equal = false;
+	}
+	if (equal)
+		m_wire_section = s_value;
+	equal = true;
+
+
 		//text size
 	i_value = clist.first().text_size;
 	for(ConductorProperties cp : clist)
@@ -609,7 +728,7 @@ void ConductorProperties::applyForEqualAttributes(QList<ConductorProperties> lis
 	if (equal)
 		horiz_rotate_text = d_value;
 	equal = true;
-	
+
 		//Text alignment for horizontal conducor
 	align_value = clist.first().m_horizontal_alignment;
 	for(ConductorProperties cp : clist)
@@ -620,7 +739,7 @@ void ConductorProperties::applyForEqualAttributes(QList<ConductorProperties> lis
 	if (equal)
 		m_horizontal_alignment = align_value;
 	equal = true;
-	
+
 		//Text alignment for vertical conducor
 	align_value = clist.first().m_vertical_alignment;
 	for(ConductorProperties cp : clist)
@@ -634,9 +753,9 @@ void ConductorProperties::applyForEqualAttributes(QList<ConductorProperties> lis
 }
 
 /**
- * @brief ConductorProperties::defaultProperties
- * @return the default properties stored in the setting file
- */
+	@brief ConductorProperties::defaultProperties
+	@return the default properties stored in the setting file
+*/
 ConductorProperties ConductorProperties::defaultProperties()
 {
 	QSettings settings;
@@ -648,10 +767,10 @@ ConductorProperties ConductorProperties::defaultProperties()
 }
 
 /**
- * @brief ConductorProperties::operator ==
- * @param other
- * @return true if other == this
- */
+	@brief ConductorProperties::operator ==
+	@param other
+	@return true if other == this
+*/
 bool ConductorProperties::operator==(const ConductorProperties &other) const
 {
 	return(
@@ -662,9 +781,14 @@ bool ConductorProperties::operator==(const ConductorProperties &other) const
 		other.m_dash_size == m_dash_size &&\
 		other.style == style &&\
 		other.text == text &&\
+		other.text_color == text_color &&\
 		other.m_formula == m_formula &&\
+		other.m_cable == m_cable &&\
+		other.m_bus == m_bus &&\
 		other.m_function == m_function &&\
 		other.m_tension_protocol == m_tension_protocol &&\
+		other.m_wire_color == m_wire_color && \
+		other.m_wire_section == m_wire_section && \
 		other.m_show_text == m_show_text &&\
 		other.text_size == text_size &&\
 		other.cond_size == cond_size &&\
@@ -691,21 +815,45 @@ bool ConductorProperties::operator!=(const ConductorProperties &other) const{
 */
 void ConductorProperties::readStyle(const QString &style_string) {
 	style = Qt::SolidLine; // style par defaut
-	
+
 	if (style_string.isEmpty()) return;
-	
+
 	// recupere la liste des couples style / valeur
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)	// ### Qt 6: remove
 	QStringList styles = style_string.split(";", QString::SkipEmptyParts);
-	
-	QRegExp rx("^\\s*([a-z-]+)\\s*:\\s*([a-z-]+)\\s*$");
-	foreach (QString style_str, styles) {
-		if (rx.exactMatch(style_str)) {
-			QString style_name = rx.cap(1);
-			QString style_value = rx.cap(2);
+#else
+#if TODO_LIST
+#pragma message("@TODO remove code QString::SkipEmptyParts for QT 5.14 or later")
+#endif
+	QStringList styles = style_string.split(";", Qt::SkipEmptyParts);
+#endif
+
+	QRegularExpression Rx("^(?<name>[a-z-]+): (?<value>[a-z-]+)$");
+	if (!Rx.isValid())
+	{
+		qWarning() <<QObject::tr("this is an error in the code")
+			  << Rx.errorString()
+			  << Rx.patternErrorOffset();
+		return;
+	}
+	foreach (QString style_str, styles)
+	{
+		QRegularExpressionMatch match = Rx.match(style_str);
+		if (!match.hasMatch())
+		{
+			qDebug()<<"no Match"
+			       <<style_str;
+		} else {
+			QString style_name = match.captured("name");
+			QString style_value = match.captured("value");
 			if (style_name == "line-style") {
 				if (style_value == "dashed") style = Qt::DashLine;
 				else if (style_value == "dashdotted") style = Qt::DashDotLine;
 				else if (style_value == "normal") style = Qt::SolidLine;
+				else {
+					qWarning()<<"style_value not known"
+						 <<style_value;
+				}
 			}
 		}
 	}
@@ -715,7 +863,8 @@ void ConductorProperties::readStyle(const QString &style_string) {
 	Exporte le style du conducteur sous forme d'une chaine de caracteres
 	@return une chaine de caracteres decrivant le style du conducteur
 */
-QString ConductorProperties::writeStyle() const {
+QString ConductorProperties::writeStyle() const
+{
 	if (style == Qt::DashLine) {
 		return("line-style: dashed;");
 	} else if (style == Qt::DashDotLine) {
@@ -729,7 +878,8 @@ QString ConductorProperties::writeStyle() const {
 	@param other l'autre ensemble de proprietes avec lequel il faut effectuer la comparaison
 	@return true si les deux ensembles de proprietes sont identiques, false sinon
 */
-int SingleLineProperties::operator==(const SingleLineProperties &other) const {
+int SingleLineProperties::operator==(const SingleLineProperties &other) const
+{
 	return(
 		other.hasGround == hasGround &&\
 		other.hasNeutral == hasNeutral &&\
@@ -742,7 +892,8 @@ int SingleLineProperties::operator==(const SingleLineProperties &other) const {
 	@param other l'autre ensemble de proprietes avec lequel il faut effectuer la comparaison
 	@return true si les deux ensembles de proprietes sont differents, false sinon
 */
-int SingleLineProperties::operator!=(const SingleLineProperties &other) const {
+int SingleLineProperties::operator!=(const SingleLineProperties &other) const
+{
 	return(!(other == (*this)));
 }
 
@@ -750,7 +901,9 @@ int SingleLineProperties::operator!=(const SingleLineProperties &other) const {
 	@param settings Parametres a ecrire
 	@param prefix prefix a ajouter devant les noms des parametres
 */
-void SingleLineProperties::toSettings(QSettings &settings, const QString &prefix) const {
+void SingleLineProperties::toSettings(QSettings &settings,
+				      const QString &prefix) const
+{
 	settings.setValue(prefix + "hasGround",  hasGround);
 	settings.setValue(prefix + "hasNeutral", hasNeutral);
 	settings.setValue(prefix + "phases",     phases);
@@ -761,7 +914,8 @@ void SingleLineProperties::toSettings(QSettings &settings, const QString &prefix
 	@param settings Parametres a lire
 	@param prefix prefix a ajouter devant les noms des parametres
 */
-void SingleLineProperties::fromSettings(QSettings &settings, const QString &prefix) {
+void SingleLineProperties::fromSettings(QSettings &settings,
+					const QString &prefix) {
 	hasGround  = settings.value(prefix + "hasGround",  true).toBool();
 	hasNeutral = settings.value(prefix + "hasNeutral", true).toBool();
 	phases     = settings.value(prefix + "phases",     1).toInt();
