@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -26,9 +26,9 @@ class PartEllipse;
 class QGraphicsSceneMouseEvent;
 
 /**
- * @brief The ESEventAddEllipse class
- * This ESEvent manage creation of ellpise in an ElementScene
- */
+	@brief The ESEventAddEllipse class
+	This ESEvent manage creation of ellpise in an ElementScene
+*/
 class ESEventAddEllipse : public ESEventInterface
 {
 	public:
