@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -16,13 +16,15 @@
 	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "genericpanel.h"
-#include <QTreeWidgetItem>
-#include "qetproject.h"
+
 #include "diagram.h"
-#include "titleblock/templatescollection.h"
-#include "titleblock/templatelocation.h"
-#include "qeticons.h"
 #include "qetapp.h"
+#include "qeticons.h"
+#include "qetproject.h"
+#include "titleblock/templatelocation.h"
+#include "titleblock/templatescollection.h"
+
+#include <QTreeWidgetItem>
 
 /**
 	Constructor
@@ -39,19 +41,27 @@ GenericPanel::GenericPanel(QWidget *parent) :
 /**
 	Destructor
 */
-GenericPanel::~GenericPanel() {
+GenericPanel::~GenericPanel()
+{
 }
 
 /**
 	@return the type of the current item
 */
-int GenericPanel::currentItemType() {
+int GenericPanel::currentItemType()
+{
 	QTreeWidgetItem *current_qtwi = currentItem();
 	if (!current_qtwi) return(0);
 	return(current_qtwi -> type());
 }
 
-QETProject *GenericPanel::projectForItem(QTreeWidgetItem *item) const {
+/**
+	@brief GenericPanel::projectForItem
+	@param item
+	@return nullptr
+*/
+QETProject *GenericPanel::projectForItem(QTreeWidgetItem *item) const
+{
 	if (item && item -> type() == QET::Project) {
 		return(valueForItem<QETProject *>(item));
 	}
@@ -60,9 +70,12 @@ QETProject *GenericPanel::projectForItem(QTreeWidgetItem *item) const {
 }
 
 /**
-	
+	@brief GenericPanel::diagramForItem
+	@param item
+	@return nullptr
 */
-Diagram *GenericPanel::diagramForItem(QTreeWidgetItem *item) const {
+Diagram *GenericPanel::diagramForItem(QTreeWidgetItem *item) const
+{
 	if (item && item -> type() == QET::Diagram) {
 		return(valueForItem<Diagram *>(item));
 	}
@@ -70,9 +83,13 @@ Diagram *GenericPanel::diagramForItem(QTreeWidgetItem *item) const {
 }
 
 /**
-	
+	@brief GenericPanel::templateLocationForItem
+	@param item
+	@return TitleBlockTemplateLocation()
 */
-TitleBlockTemplateLocation GenericPanel::templateLocationForItem(QTreeWidgetItem *item) const {
+TitleBlockTemplateLocation GenericPanel::templateLocationForItem(
+		QTreeWidgetItem *item) const
+{
 	if (item && item -> type() & QET::TitleBlockTemplatesCollectionItem) {
 		return(valueForItem<TitleBlockTemplateLocation>(item));
 	}
@@ -80,34 +97,47 @@ TitleBlockTemplateLocation GenericPanel::templateLocationForItem(QTreeWidgetItem
 }
 
 /**
-	
+	@brief GenericPanel::selectedProject
+	@return projectForItem(currentItem())
 */
-QETProject *GenericPanel::selectedProject() const {
+QETProject *GenericPanel::selectedProject() const
+{
 	return(projectForItem(currentItem()));
 }
 
 /**
-	
+	@brief GenericPanel::selectedDiagram
+	@return diagramForItem(currentItem())
 */
-Diagram *GenericPanel::selectedDiagram() const {
+Diagram *GenericPanel::selectedDiagram() const
+{
 	return(diagramForItem(currentItem()));
 }
 
 /**
-	
+	@brief GenericPanel::selectedTemplateLocation
+	@return templateLocationForItem(currentItem())
 */
-TitleBlockTemplateLocation GenericPanel::selectedTemplateLocation() const {
+TitleBlockTemplateLocation GenericPanel::selectedTemplateLocation() const
+{
 	return(templateLocationForItem(currentItem()));
 }
 
 /**
-	
+	@brief GenericPanel::addProject
+	@param project
+	@param parent_item
+	@param options
+	@return project_qtwi
 */
-QTreeWidgetItem *GenericPanel::addProject(QETProject *project, QTreeWidgetItem *parent_item, PanelOptions options) {
+QTreeWidgetItem *GenericPanel::addProject(QETProject *project,
+					  QTreeWidgetItem *parent_item,
+					  PanelOptions options) {
 	if (!project) return(nullptr);
 	bool creation_required;
 	
-	QTreeWidgetItem *project_qtwi = getItemForProject(project, &creation_required);
+	QTreeWidgetItem *project_qtwi = getItemForProject(project,
+							  &creation_required);
 	updateProjectItem(project_qtwi, project, options, creation_required);
 	reparent(project_qtwi, parent_item);
 	fillProjectItem(project_qtwi, project, options, creation_required);
@@ -133,7 +163,8 @@ QTreeWidgetItem *GenericPanel::itemForProject(QETProject *project) {
 	@return the tree item representing the provided project. If it does not
 	appear within this panel, it is created.
 */
-QTreeWidgetItem *GenericPanel::getItemForProject(QETProject *project, bool *created) {
+QTreeWidgetItem *GenericPanel::getItemForProject(QETProject *project,
+						 bool *created) {
 	if (!project) return(nullptr);
 	
 	QTreeWidgetItem *project_qtwi = projects_.value(project, nullptr);
@@ -148,24 +179,31 @@ QTreeWidgetItem *GenericPanel::getItemForProject(QETProject *project, bool *crea
 }
 
 /**
-	
+	@brief GenericPanel::updateProjectItem
+	@param project_qtwi
+	@param project
+	@param options (unused)
+	@param freshly_created
+	@return updateItem(project_qtwi, options, freshly_created)
 */
-QTreeWidgetItem *GenericPanel::updateProjectItem(QTreeWidgetItem *project_qtwi, QETProject *project, PanelOptions options, bool freshly_created) {
+QTreeWidgetItem *GenericPanel::updateProjectItem(QTreeWidgetItem *project_qtwi,
+						 QETProject *project,
+						 PanelOptions options,
+						 bool freshly_created) {
 	Q_UNUSED(options)
 	if (!project_qtwi || !project) return(nullptr);
 	
 	if (freshly_created) {
-		project_qtwi -> setData(0, GenericPanel::Item, qVariantFromValue(project));
+		project_qtwi -> setData(0, GenericPanel::Item,
+					QVariant::fromValue(project));
 		projects_.insert(project, project_qtwi);
 		
 		connect(
-			project, SIGNAL(projectInformationsChanged(QETProject *)),
-			this,    SLOT  (projectInformationsChanged(QETProject *))
-		);
+			project,&QETProject::projectInformationsChanged,
+			this,&GenericPanel::projectInformationsChanged);
 		connect(
-			project, SIGNAL(readOnlyChanged(QETProject *, bool)),
-			this,    SLOT  (projectInformationsChanged(QETProject *))
-		);
+			project,&QETProject::readOnlyChanged,
+			this,&GenericPanel::projectInformationsChanged);
 	}
 	
 	// text
@@ -179,39 +217,51 @@ QTreeWidgetItem *GenericPanel::updateProjectItem(QTreeWidgetItem *project_qtwi,
 		);
 	}
 	project_qtwi -> setToolTip(0, final_tooltip);
-    QString project_whatsthis = tr("Ceci est un projet QElectroTech, c'est-à-dire un fichier d'extension .qet regroupant plusieurs folios. Il embarque également les éléments et modèles de cartouches utilisés dans ces folios.", "\"What's this\" tip");
+	QString project_whatsthis = tr("Ceci est un projet QElectroTech, "
+		"c'est-à-dire un fichier d'extension .qet regroupant "
+		"plusieurs folios. Il embarque également les éléments et "
+		"modèles de cartouches utilisés dans ces folios.",
+		"\"What's this\" tip");
 	project_qtwi -> setWhatsThis(0, project_whatsthis);
 	return(updateItem(project_qtwi, options, freshly_created));
 }
 
 /**
-	
+	@brief GenericPanel::fillProjectItem
+	@param project_qtwi
+	@param project
+	@param options
+	@param freshly_created
+	@return fillItem(project_qtwi, options, freshly_created)
 */
-QTreeWidgetItem *GenericPanel::fillProjectItem(QTreeWidgetItem *project_qtwi, QETProject *project, PanelOptions options, bool freshly_created) {
+QTreeWidgetItem *GenericPanel::fillProjectItem(QTreeWidgetItem *project_qtwi,
+					       QETProject *project,
+					       PanelOptions options,
+					       bool freshly_created) {
 	if (!project_qtwi || !project) return(nullptr);
 	
 	
 	if (options & AddChildDiagrams) {
 		if (freshly_created) {
 			connect(
-				project, SIGNAL(diagramAdded(QETProject *, Diagram *)),
-				this,    SLOT  (diagramAdded(QETProject *, Diagram *))
-			);
+				project,&QETProject::diagramAdded,
+				this,&GenericPanel::diagramAdded);
 			connect(
-				project, SIGNAL(diagramRemoved(QETProject *, Diagram *)),
-				this,    SLOT  (diagramRemoved(QETProject *, Diagram *))
-			);
+				project,&QETProject::diagramRemoved,
+				this,&GenericPanel::diagramRemoved);
 			connect(
-				project, SIGNAL(projectDiagramsOrderChanged(QETProject *, int, int)),
-				this,    SLOT  (projectDiagramsOrderChanged(QETProject *, int, int))
-			);
+				project,&QETProject::projectDiagramsOrderChanged,
+				this,&GenericPanel::projectDiagramsOrderChanged);
 		} else {
 			// remove diagrams unknown to the project (presumably removed)
-			removeObsoleteItems(project -> diagrams(), project_qtwi, QET::Diagram, false);
+			removeObsoleteItems(project -> diagrams(),
+					    project_qtwi, QET::Diagram, false);
 		}
 		int index = 0;
 		foreach (Diagram *diagram, project -> diagrams()) {
-			QTreeWidgetItem *diagram_qtwi = addDiagram(diagram, nullptr, options);
+			QTreeWidgetItem *diagram_qtwi = addDiagram(diagram,
+								   nullptr,
+								   options);
 			project_qtwi -> insertChild(index, diagram_qtwi);
 			++ index;
 		}
@@ -220,41 +270,50 @@ QTreeWidgetItem *GenericPanel::fillProjectItem(QTreeWidgetItem *project_qtwi, QE
 	if (options & AddChildTemplatesCollection) {
 		if (freshly_created) {
 			connect(
-				project, SIGNAL(diagramUsedTemplate(TitleBlockTemplatesCollection *, const QString &)),
-				this,    SLOT  (diagramUsedTemplate(TitleBlockTemplatesCollection *, const QString &))
-			);
+				project,&QETProject::diagramUsedTemplate,
+				this,&GenericPanel::diagramUsedTemplate);
 		}
 		addTemplatesCollection(
 			project -> embeddedTitleBlockTemplatesCollection(),
 			project_qtwi,
-			options
-		);
+			options);
 	}
 
 	return(fillItem(project_qtwi, options, freshly_created));
 }
 
 /**
-	
+	@brief GenericPanel::addDiagram
+	@param diagram
+	@param parent_item
+	@param options (unused)
+	@return diagram_qtwi
 */
-QTreeWidgetItem *GenericPanel::addDiagram(Diagram *diagram, QTreeWidgetItem *parent_item, PanelOptions options) {
+QTreeWidgetItem *GenericPanel::addDiagram(Diagram *diagram,
+					  QTreeWidgetItem *parent_item,
+					  PanelOptions options) {
 	Q_UNUSED(options)
 	if (!diagram) return(nullptr);
 	
 	bool creation_required;
 	
-	QTreeWidgetItem *diagram_qtwi = getItemForDiagram(diagram, &creation_required);
+	QTreeWidgetItem *diagram_qtwi = getItemForDiagram(diagram,
+							  &creation_required);
 	updateDiagramItem(diagram_qtwi, diagram, options, creation_required);
 	reparent(diagram_qtwi, parent_item);
-	fillDiagramItem(diagram_qtwi, diagram, options, creation_required);
+	fillDiagramItem(diagram_qtwi, options, creation_required);
 	
 	return(diagram_qtwi);
 }
 
 /**
-	
+	@brief GenericPanel::getItemForDiagram
+	@param diagram
+	@param created
+	@return diagram_qtwi
 */
-QTreeWidgetItem *GenericPanel::getItemForDiagram(Diagram *diagram, bool *created) {
+QTreeWidgetItem *GenericPanel::getItemForDiagram(Diagram *diagram,
+						 bool *created) {
 	if (!diagram) return(nullptr);
 	
 	QTreeWidgetItem *diagram_qtwi = diagrams_.value(diagram, nullptr);
@@ -269,31 +328,41 @@ QTreeWidgetItem *GenericPanel::getItemForDiagram(Diagram *diagram, bool *created
 }
 
 /**
-	
+	@brief GenericPanel::updateDiagramItem
+	@param diagram_qtwi
+	@param diagram
+	@param options
+	@param freshly_created
+	@return updateItem(diagram_qtwi, options, freshly_created)
 */
-QTreeWidgetItem *GenericPanel::updateDiagramItem(QTreeWidgetItem *diagram_qtwi, Diagram *diagram, PanelOptions options, bool freshly_created) {
-	Q_UNUSED(options)
+QTreeWidgetItem *GenericPanel::updateDiagramItem(QTreeWidgetItem *diagram_qtwi,
+						 Diagram *diagram,
+						 PanelOptions options,
+						 bool freshly_created) {
 	if (!diagram || !diagram_qtwi) return(nullptr);
 	QSettings settings;
 	
 	QString displayed_title = diagram -> title();
 	if (displayed_title.isEmpty())
 	{
-		displayed_title = tr("Folio sans titre", "Fallback label when a diagram has no title");
+		displayed_title = tr("Folio sans titre",
+				     "Fallback label when a diagram has no title");
 	}
 
 	if (settings.value("genericpanel/folio", true).toBool())
 	{
-		QString displayed_label = diagram ->border_and_titleblock.finalfolio();
+		QString displayed_label =
+				diagram ->border_and_titleblock.finalfolio();
 		int diagram_folio_idx = diagram -> folioIndex();
 		if (diagram_folio_idx != -1)
 		{
 			displayed_label = QString(
-						tr(
-							"%1 - %2",
-							"label displayed for a diagram in the panel ; %1 is the folio index, %2 is the diagram title"
-							)
-						).arg(displayed_label).arg(displayed_title);
+				tr(
+				   "%1 - %2",
+				   "label displayed for a diagram in the panel ;"
+				   " %1 is the folio index, %2 is the diagram title"
+				   )
+				).arg(displayed_label).arg(displayed_title);
 			diagram_qtwi -> setText(0, displayed_label);
 		}
 
@@ -305,11 +374,12 @@ QTreeWidgetItem *GenericPanel::updateDiagramItem(QTreeWidgetItem *diagram_qtwi,
 		if (diagram_folio_idx != -1)
 		{
 			displayed_label = QString(
-						tr(
-							"%1 - %2",
-							"label displayed for a diagram in the panel ; %1 is the folio index, %2 is the diagram title"
-							)
-						).arg(diagram_folio_idx + 1).arg(displayed_title);
+				tr(
+				   "%1 - %2",
+				   "label displayed for a diagram in the panel ;"
+				   " %1 is the folio index, %2 is the diagram title"
+				   )
+				).arg(diagram_folio_idx + 1).arg(displayed_title);
 		}
 
 		diagram_qtwi -> setText(0, displayed_label);
@@ -317,10 +387,13 @@ QTreeWidgetItem *GenericPanel::updateDiagramItem(QTreeWidgetItem *diagram_qtwi,
 	}
 	if (freshly_created)
 	{
-		diagram_qtwi -> setData(0, GenericPanel::Item, qVariantFromValue(diagram));
+		diagram_qtwi -> setData(0,
+					GenericPanel::Item,
+					QVariant::fromValue(diagram));
 		diagrams_.insert(diagram, diagram_qtwi);
 		
-		connect(diagram, &Diagram::diagramTitleChanged, this, &GenericPanel::diagramTitleChanged);
+		connect(diagram, &Diagram::diagramTitleChanged,
+			this, &GenericPanel::diagramTitleChanged);
 	}
 	
 	return(updateItem(diagram_qtwi, options, freshly_created));
@@ -329,44 +402,75 @@ QTreeWidgetItem *GenericPanel::updateDiagramItem(QTreeWidgetItem *diagram_qtwi,
 
 
 /**
-	
+	@brief GenericPanel::fillDiagramItem
+	@param diagram_qtwi
+	@param options
+	@param freshly_created
+	@return fillItem(diagram_qtwi, options, freshly_created)
 */
-QTreeWidgetItem *GenericPanel::fillDiagramItem(QTreeWidgetItem *diagram_qtwi, Diagram *diagram, PanelOptions options, bool freshly_created) {
-	Q_UNUSED(diagram)
-	Q_UNUSED(options)
-	Q_UNUSED(freshly_created)
+QTreeWidgetItem *GenericPanel::fillDiagramItem(
+		QTreeWidgetItem *diagram_qtwi,
+		PanelOptions options,
+		bool freshly_created)
+{
 	return(fillItem(diagram_qtwi, options, freshly_created));
 }
 
 /**
-	
+	@brief GenericPanel::addTemplatesCollection
+	@param tbt_collection
+	@param parent_item
+	@param options
+	@return tbt_collection_qtwi
 */
-QTreeWidgetItem *GenericPanel::addTemplatesCollection(TitleBlockTemplatesCollection *tbt_collection, QTreeWidgetItem *parent_item, PanelOptions options) {
+QTreeWidgetItem *GenericPanel::addTemplatesCollection(
+		TitleBlockTemplatesCollection *tbt_collection,
+		QTreeWidgetItem *parent_item,
+		PanelOptions options) {
 	if (!tbt_collection) return(nullptr);
 	bool creation_required;
 	
-	QTreeWidgetItem *tbt_collection_qtwi = getItemForTemplatesCollection(tbt_collection, &creation_required);
-	updateTemplatesCollectionItem(tbt_collection_qtwi, tbt_collection, options, creation_required);
+	QTreeWidgetItem *tbt_collection_qtwi =
+			getItemForTemplatesCollection(tbt_collection,
+						      &creation_required);
+	updateTemplatesCollectionItem(tbt_collection_qtwi,
+				      tbt_collection,
+				      options,
+				      creation_required);
 	reparent(tbt_collection_qtwi, parent_item);
-	fillTemplatesCollectionItem(tbt_collection_qtwi, tbt_collection, options, creation_required);
+	fillTemplatesCollectionItem(tbt_collection_qtwi,
+				    tbt_collection,
+				    options,
+				    creation_required);
 	
 	return(tbt_collection_qtwi);
 }
 
 /**
-	
+	@brief GenericPanel::itemForTemplatesCollection
+	@param tbt_collection
+	@return tb_templates_.value(tbt_collection -> location(), nullptr)
+	@return nullptr
 */
-QTreeWidgetItem *GenericPanel::itemForTemplatesCollection(TitleBlockTemplatesCollection *tbt_collection) {
+QTreeWidgetItem *GenericPanel::itemForTemplatesCollection(
+		TitleBlockTemplatesCollection *tbt_collection) {
 	if (!tbt_collection) return(nullptr);
 	return(tb_templates_.value(tbt_collection -> location(), nullptr));
 }
 
 /**
-	
+	@brief GenericPanel::getItemForTemplatesCollection
+	@param tbt_collection
+	@param created
+	@return tbt_collection_item
 */
-QTreeWidgetItem *GenericPanel::getItemForTemplatesCollection(TitleBlockTemplatesCollection *tbt_collection, bool *created) {
+QTreeWidgetItem *GenericPanel::getItemForTemplatesCollection(
+		TitleBlockTemplatesCollection *tbt_collection,
+		bool *created) {
 	if (!tbt_collection) return(nullptr);
-	QTreeWidgetItem *tbt_collection_item = tb_templates_.value(tbt_collection -> location(), nullptr);
+	QTreeWidgetItem *tbt_collection_item =
+			tb_templates_.value(tbt_collection -> location(),
+					    nullptr);
 	if (tbt_collection_item) {
 		if (created) *created = false;
 		return(tbt_collection_item);
@@ -378,51 +482,85 @@ QTreeWidgetItem *GenericPanel::getItemForTemplatesCollection(TitleBlockTemplates
 }
 
 /**
-	
+	@brief GenericPanel::updateTemplatesCollectionItem
+	@param tbt_collection_qtwi
+	@param tbt_collection
+	@param options
+	@param freshly_created
+	@return updateItem(tbt_collection_qtwi, options, freshly_created)
 */
-QTreeWidgetItem *GenericPanel::updateTemplatesCollectionItem(QTreeWidgetItem *tbt_collection_qtwi, TitleBlockTemplatesCollection *tbt_collection, PanelOptions options, bool freshly_created) {
-	Q_UNUSED(options)
+QTreeWidgetItem *GenericPanel::updateTemplatesCollectionItem(
+		QTreeWidgetItem *tbt_collection_qtwi,
+		TitleBlockTemplatesCollection *tbt_collection,
+		PanelOptions options,
+		bool freshly_created) {
 	QString label = tbt_collection -> title();
 	if (label.isEmpty()) label = tr("Modèles de cartouche");
 	
 	tbt_collection_qtwi -> setText(0, label);
-	tbt_collection_qtwi -> setToolTip(0, tbt_collection -> location().toString());
+	tbt_collection_qtwi -> setToolTip(0,
+					  tbt_collection->location().toString());
 	
 	if (freshly_created) {
-		tbt_collection_qtwi -> setData(0, GenericPanel::Item, qVariantFromValue(tbt_collection -> location()));
-		tb_templates_.insert(tbt_collection -> location(), tbt_collection_qtwi);
+		tbt_collection_qtwi -> setData(0,
+					       GenericPanel::Item,
+					       QVariant::fromValue(
+						   tbt_collection->location()));
+		tb_templates_.insert(tbt_collection -> location(),
+				     tbt_collection_qtwi);
 	}
 	
 	return(updateItem(tbt_collection_qtwi, options, freshly_created));
 }
 
 /**
-	
+	@brief GenericPanel::fillTemplatesCollectionItem
+	@param tbt_collection_qtwi
+	@param tbt_collection
+	@param options
+	@param freshly_created
+	@return fillItem(tbt_collection_qtwi, options, freshly_created)
 */
-QTreeWidgetItem *GenericPanel::fillTemplatesCollectionItem(QTreeWidgetItem *tbt_collection_qtwi, TitleBlockTemplatesCollection *tbt_collection, PanelOptions options, bool freshly_created) {
-	if (!tbt_collection_qtwi || !tbt_collection) return(tbt_collection_qtwi);
+QTreeWidgetItem *GenericPanel::fillTemplatesCollectionItem(
+		QTreeWidgetItem *tbt_collection_qtwi,
+		TitleBlockTemplatesCollection *tbt_collection,
+		PanelOptions options,
+		bool freshly_created) {
+	if (!tbt_collection_qtwi || !tbt_collection)
+		return(tbt_collection_qtwi);
 	
 	if (options & AddChildTemplates) {
 		if (freshly_created) {
 			connect(
-				tbt_collection, SIGNAL(changed(TitleBlockTemplatesCollection*,QString)),
-				this, SLOT(templatesCollectionChanged(TitleBlockTemplatesCollection*, const QString &))
-			);
+				tbt_collection,
+				&TitleBlockTemplatesCollection::changed,
+				this,
+				&GenericPanel::templatesCollectionChanged);
 			if (QETProject *project = tbt_collection -> parentProject()) {
 				connect(
-					project, SIGNAL(diagramUsedTemplate(TitleBlockTemplatesCollection *, const QString &)),
-					this,    SLOT  (templatesCollectionChanged(TitleBlockTemplatesCollection *, const QString &))
-				);
+					project, &QETProject::diagramUsedTemplate,
+					this,
+					&GenericPanel::templatesCollectionChanged);
 			}
 		} else {
-			// remove templates unknown to the collection (presumably removed)
-			removeObsoleteItems(tbt_collection -> templatesLocations(), tbt_collection_qtwi, QET::TitleBlockTemplate, false);
+		// remove templates unknown to the collection (presumably removed)
+			removeObsoleteItems(
+					tbt_collection -> templatesLocations(),
+					tbt_collection_qtwi,
+					QET::TitleBlockTemplate,
+					false);
 		}
 		
 		int index = 0;
 		foreach (QString template_name, tbt_collection -> templates()) {
-			QTreeWidgetItem *template_item = addTemplate(tbt_collection -> location(template_name), nullptr, options);
-			tbt_collection_qtwi -> insertChild(index ++, template_item);
+			QTreeWidgetItem *template_item =
+					addTemplate(
+						tbt_collection -> location(
+							template_name),
+						nullptr,
+						options);
+			tbt_collection_qtwi -> insertChild(index ++,
+							   template_item);
 		}
 	}
 	
@@ -430,27 +568,47 @@ QTreeWidgetItem *GenericPanel::fillTemplatesCollectionItem(QTreeWidgetItem *tbt_
 }
 
 /**
-	
+	@brief GenericPanel::addTemplate
+	@param tb_template
+	@param parent_item
+	@param options
+	@return tb_template_qtwi
 */
-QTreeWidgetItem *GenericPanel::addTemplate(const TitleBlockTemplateLocation &tb_template, QTreeWidgetItem *parent_item, PanelOptions options) {
+QTreeWidgetItem *GenericPanel::addTemplate(
+		const TitleBlockTemplateLocation &tb_template,
+		QTreeWidgetItem *parent_item,
+		PanelOptions options) {
 	if (!tb_template.isValid()) return(nullptr);
 	bool creation_required;
 	
-	QTreeWidgetItem *tb_template_qtwi = getItemForTemplate(tb_template, &creation_required);
-	updateTemplateItem(tb_template_qtwi, tb_template, options, creation_required);
+	QTreeWidgetItem *tb_template_qtwi = getItemForTemplate(tb_template,
+							       &creation_required);
+	updateTemplateItem(tb_template_qtwi,
+			   tb_template,
+			   options,
+			   creation_required);
 	reparent(tb_template_qtwi, parent_item);
-	fillTemplateItem(tb_template_qtwi, tb_template, options, creation_required);
+	fillTemplateItem(tb_template_qtwi,
+			 tb_template,
+			 options,
+			 creation_required);
 	
 	return(tb_template_qtwi);
 }
 
 /**
-	
+	@brief GenericPanel::getItemForTemplate
+	@param tb_template
+	@param created
+	@return tb_template_qtwi
 */
-QTreeWidgetItem *GenericPanel::getItemForTemplate(const TitleBlockTemplateLocation &tb_template, bool *created) {
+QTreeWidgetItem *GenericPanel::getItemForTemplate(
+		const TitleBlockTemplateLocation &tb_template,
+		bool *created) {
 	if (!tb_template.isValid()) return(nullptr);
 	
-	QTreeWidgetItem *tb_template_qtwi = tb_templates_.value(tb_template, nullptr);
+	QTreeWidgetItem *tb_template_qtwi = tb_templates_.value(tb_template,
+								nullptr);
 	if (tb_template_qtwi) {
 		if (created) *created = false;
 		return(tb_template_qtwi);
@@ -462,13 +620,24 @@ QTreeWidgetItem *GenericPanel::getItemForTemplate(const TitleBlockTemplateLocati
 }
 
 /**
-	
+	@brief GenericPanel::updateTemplateItem
+	@param tb_template_qtwi
+	@param tb_template
+	@param options
+	@param freshly_created
+	@return updateItem(tb_template_qtwi, options, freshly_created)
 */
-QTreeWidgetItem *GenericPanel::updateTemplateItem(QTreeWidgetItem *tb_template_qtwi, const TitleBlockTemplateLocation &tb_template, PanelOptions options, bool freshly_created) {
-	Q_UNUSED(options)
-	tb_template_qtwi -> setText(0, tr("Modèle \"%1\"", "used to display a title block template").arg(tb_template.name()));
+QTreeWidgetItem *GenericPanel::updateTemplateItem(
+		QTreeWidgetItem *tb_template_qtwi,
+		const TitleBlockTemplateLocation &tb_template,
+		PanelOptions options,
+		bool freshly_created) {
+	tb_template_qtwi -> setText(0,
+		tr("Modèle \"%1\"",
+		   "used to display a title block template").arg(
+					    tb_template.name()));
 	QString tbt_whatsthis = tr(
-        "Ceci est un modèle de cartouche, qui peut être appliqué à un folio.",
+		"Ceci est un modèle de cartouche, qui peut être appliqué à un folio.",
 		"\"What's this\" tip"
 	);
 	tb_template_qtwi -> setWhatsThis(0, tbt_whatsthis);
@@ -485,29 +654,44 @@ QTreeWidgetItem *GenericPanel::updateTemplateItem(QTreeWidgetItem *tb_template_q
 	}
 	
 	if (freshly_created) {
-		tb_template_qtwi -> setData(0, GenericPanel::Item, qVariantFromValue(tb_template));
+		tb_template_qtwi -> setData(0,
+					    GenericPanel::Item,
+					    QVariant::fromValue(tb_template));
 		tb_templates_.insert(tb_template, tb_template_qtwi);
 	}
 	return(updateItem(tb_template_qtwi, options, freshly_created));
 }
 
 /**
-	
+	@brief GenericPanel::fillTemplateItem
+	@param tb_template_qtwi
+	@param tb_template (unused)
+	@param options
+	@param freshly_created
+	@return fillItem(tb_template_qtwi, options, freshly_created)
 */
-QTreeWidgetItem *GenericPanel::fillTemplateItem(QTreeWidgetItem *tb_template_qtwi, const TitleBlockTemplateLocation &tb_template, PanelOptions options, bool freshly_created) {
+QTreeWidgetItem *GenericPanel::fillTemplateItem(
+		QTreeWidgetItem *tb_template_qtwi,
+		const TitleBlockTemplateLocation &tb_template,
+		PanelOptions options,
+		bool freshly_created) {
 	Q_UNUSED(tb_template)
-	Q_UNUSED(options)
-	Q_UNUSED(freshly_created)
 	return(fillItem(tb_template_qtwi, options, freshly_created));
 }
 
 /**
-	This generic method is called at the end of each update*Item method. Its
-	only purpose is being reimplemented in a subclass. The default
-	implementation does nothing.
+	@brief GenericPanel::updateItem
+	This generic method is called at the end of each update*Item method.
+	Its only purpose is being reimplemented in a subclass.
+	The default implementation does nothing.
+	@param qtwi
+	@param options (unused)
+	@param freshly_created (unused)
+	@return qtwi
 */
-QTreeWidgetItem *GenericPanel::updateItem(QTreeWidgetItem *qtwi, PanelOptions options, bool freshly_created) {
-	Q_UNUSED(qtwi);
+QTreeWidgetItem *GenericPanel::updateItem(QTreeWidgetItem *qtwi,
+					  PanelOptions options,
+					  bool freshly_created) {
 	Q_UNUSED(options);
 	Q_UNUSED(freshly_created);
 	QApplication::processEvents();
@@ -515,27 +699,36 @@ QTreeWidgetItem *GenericPanel::updateItem(QTreeWidgetItem *qtwi, PanelOptions op
 }
 
 /**
-	This generic method is called at the end of each fill*Item method. Its
-	only purpose is being reimplemented in a subclass. The default
-	implementation does nothing.
+	@brief GenericPanel::fillItem
+	This generic method is called at the end of each fill*Item method.
+	Its only purpose is being reimplemented in a subclass.
+	The default implementation does nothing.
+	@param qtwi
+	@param options (unused)
+	@param freshly_created (unused)
+	@return qtwi
 */
-QTreeWidgetItem *GenericPanel::fillItem(QTreeWidgetItem *qtwi, PanelOptions options, bool freshly_created) {
-	Q_UNUSED(qtwi);
+QTreeWidgetItem *GenericPanel::fillItem(QTreeWidgetItem *qtwi,
+					PanelOptions options,
+					bool freshly_created) {
 	Q_UNUSED(options);
 	Q_UNUSED(freshly_created);
 	return(qtwi);
 }
 
 /**
-	
+	@brief GenericPanel::projectInformationsChanged
+	@param project
 */
 void GenericPanel::projectInformationsChanged(QETProject *project) {
-	addProject(project, nullptr, nullptr);
+	addProject(project, nullptr, AddAllChild);
 	emit(panelContentChanged());
 }
 
 /**
-	
+	@brief GenericPanel::diagramAdded
+	@param project
+	@param diagram (unused)
 */
 void GenericPanel::diagramAdded(QETProject *project, Diagram *diagram) {
 	Q_UNUSED(diagram)
@@ -544,7 +737,9 @@ void GenericPanel::diagramAdded(QETProject *project, Diagram *diagram) {
 }
 
 /**
-	
+	@brief GenericPanel::diagramRemoved
+	@param project
+	@param diagram (unused)
 */
 void GenericPanel::diagramRemoved(QETProject *project, Diagram *diagram) {
 	Q_UNUSED(diagram)
@@ -553,27 +748,29 @@ void GenericPanel::diagramRemoved(QETProject *project, Diagram *diagram) {
 }
 
 /**
- * @brief GenericPanel::projectDiagramsOrderChanged
- * @param project project where diagram moved
- * @param from Index of diagram before move
- * @param to Index of diagram after move
- */
-void GenericPanel::projectDiagramsOrderChanged(QETProject *project, int from, int to)
+	@brief GenericPanel::projectDiagramsOrderChanged
+	@param project project where diagram moved
+	@param from Index of diagram before move
+	@param to Index of diagram after move
+*/
+void GenericPanel::projectDiagramsOrderChanged(QETProject *project,
+					       int from,
+					       int to)
 {
-		// get the item representing the provided project
+	// get the item representing the provided project
 	QTreeWidgetItem *qtwi_project = itemForProject(project);
 	if (!qtwi_project) return;
 	
-		// get the item representing the moved diagram
+	// get the item representing the moved diagram
 	QTreeWidgetItem *moved_qtwi_diagram = qtwi_project -> child(from);
 	if (!moved_qtwi_diagram) return;
 	
-		// remove the QTWI then insert it back at the adequate location
+	// remove the QTWI then insert it back at the adequate location
 	bool was_selected = moved_qtwi_diagram -> isSelected();
 	qtwi_project -> removeChild (moved_qtwi_diagram);
 	qtwi_project -> insertChild (to, moved_qtwi_diagram);
 	
-		// update the QTWI labels because they may display the folio index
+	// update the QTWI labels because they may display the folio index
 	for (int i = qMin(from, to); i < qMax(from, to) + 1; i++)
 	{
 		QTreeWidgetItem *qtwi_diagram = qtwi_project -> child(i);
@@ -591,7 +788,10 @@ void GenericPanel::projectDiagramsOrderChanged(QETProject *project, int from, in
 }
 
 /**
+	@brief GenericPanel::diagramTitleChanged
 	Inform this panel the diagram \a diagram has changed its title to \a title.
+	@param diagram
+	@param title (unused)
 */
 void GenericPanel::diagramTitleChanged(Diagram *diagram, const QString &title) {
 	Q_UNUSED(title)
@@ -600,27 +800,36 @@ void GenericPanel::diagramTitleChanged(Diagram *diagram, const QString &title) {
 }
 
 /**
-	@param collection Title block templates collection that changed and should be updated
-	@param template_name Name of the changed template (unused)
+	@brief GenericPanel::templatesCollectionChanged
+	@param collection :
+	Title block templates collection that changed and should be updated
+	@param template_name : Name of the changed template (unused)
 */
-void GenericPanel::templatesCollectionChanged(TitleBlockTemplatesCollection*collection, const QString &template_name) {
+void GenericPanel::templatesCollectionChanged(
+		TitleBlockTemplatesCollection*collection,
+		const QString &template_name) {
 	Q_UNUSED(template_name)
 	addTemplatesCollection(collection);
 	emit(panelContentChanged());
 }
 
 /**
-	
+	@brief GenericPanel::diagramUsedTemplate
+	@param collection
+	@param name : (unused)
 */
-void GenericPanel::diagramUsedTemplate(TitleBlockTemplatesCollection *collection, const QString &name) {
-	Q_UNUSED(collection)
+void GenericPanel::diagramUsedTemplate(
+		TitleBlockTemplatesCollection *collection,
+		const QString &name) {
 	Q_UNUSED(name)
 	addTemplatesCollection(collection);
 	emit(panelContentChanged());
 }
 
 /**
-	
+	@brief GenericPanel::defaultText
+	@param type
+	@return the default text for \a type
 */
 QString GenericPanel::defaultText(QET::ItemType type) {
 	switch(type) {
@@ -631,7 +840,8 @@ QString GenericPanel::defaultText(QET::ItemType type) {
 		case QET::ElementsCollection: return("elements collection");
 		case QET::TitleBlockTemplatesCollectionItem:
 		case QET::TitleBlockTemplate: return("title block template");
-		case QET::TitleBlockTemplatesCollection: return("title block templates collection");
+		case QET::TitleBlockTemplatesCollection:
+			return("title block templates collection");
 		case QET::Diagram: return("diagram");
 		case QET::Project: return("project");
 		default: return(QString());
@@ -640,6 +850,7 @@ QString GenericPanel::defaultText(QET::ItemType type) {
 }
 
 /**
+	@brief GenericPanel::defaultIcon
 	@param type Item type we want the default icon for
 	@return the default icon for \a type
 */
@@ -657,14 +868,18 @@ QIcon GenericPanel::defaultIcon(QET::ItemType type) {
 }
 
 /**
+	@brief GenericPanel::makeItem
 	Create a QTreeWidgetItem
-	@param parent Parent for the created item
 	@param type Item type (e.g QET::Diagram, QET::Project, ...)
+	@param parent Parent for the created item
 	@param label Label for the created item
 	@param icon Icon for the created item
 	@return the create QTreeWidgetItem
 */
-QTreeWidgetItem *GenericPanel::makeItem(QET::ItemType type, QTreeWidgetItem *parent, const QString &label, const QIcon &icon) {
+QTreeWidgetItem *GenericPanel::makeItem(QET::ItemType type,
+					QTreeWidgetItem *parent,
+					const QString &label,
+					const QIcon &icon) {
 	QTreeWidgetItem *qtwi = new QTreeWidgetItem(parent, type);
 	qtwi -> setText(0, label.isEmpty() ? defaultText(type) : label);
 	qtwi -> setIcon(0, icon.isNull() ? defaultIcon(type) : icon);
@@ -672,10 +887,11 @@ QTreeWidgetItem *GenericPanel::makeItem(QET::ItemType type, QTreeWidgetItem *par
 }
 
 /**
+	@brief GenericPanel::deleteItem
 	Delete and item and its children.
 	@param item item to delete
 	@param deleted_on_cascade true if the item is not being directly deleted
-	but is undergoing the deletion of its parent.
+	but is undergoing the deletion of its parent. (unused)
 */
 void GenericPanel::deleteItem(QTreeWidgetItem *item, bool deleted_on_cascade) {
 	Q_UNUSED(deleted_on_cascade)
@@ -690,6 +906,7 @@ void GenericPanel::deleteItem(QTreeWidgetItem *item, bool deleted_on_cascade) {
 }
 
 /**
+	@brief GenericPanel::markItemAsUnused
 	Mark the provided QTreeWidgetItem as unused in its parent project.
 	@param qtwi A QTreeWidgetItem
 */
@@ -698,11 +915,15 @@ void GenericPanel::markItemAsUnused(QTreeWidgetItem *qtwi) {
 	t.setColorAt(0, QColor("#ffc0c0"));
 	t.setColorAt(1, QColor("#ffffff"));
 	qtwi -> setBackground(0, QBrush(t));
-	qtwi -> setToolTip(0, QString(tr("%1 [non utilisé dans le projet]")).arg(qtwi -> toolTip(0)));
+	qtwi -> setToolTip(0,
+			   QString(tr("%1 [non utilisé dans le projet]")).arg(
+				   qtwi -> toolTip(0)));
 }
 
 /**
-	
+	@brief GenericPanel::reparent
+	@param item
+	@param parent
 */
 void GenericPanel::reparent(QTreeWidgetItem *item, QTreeWidgetItem *parent) {
 	if (parent && item -> parent() != parent) {
@@ -711,12 +932,17 @@ void GenericPanel::reparent(QTreeWidgetItem *item, QTreeWidgetItem *parent) {
 }
 
 /**
-	@return the child items of \a item of type \a type
+	@brief GenericPanel::childItems
 	@param item Parent item that will be searched.
 	@param type Type of items to look for.
 	@param recursive Whether to search recursively.
+	@return the child items of \a item of type \a type
 */
-QList<QTreeWidgetItem *> GenericPanel::childItems(QTreeWidgetItem *item, QET::ItemType type, bool recursive) const {
+QList<QTreeWidgetItem *> GenericPanel::childItems(
+		QTreeWidgetItem *item,
+		QET::ItemType type,
+		bool recursive) const
+{
 	QList<QTreeWidgetItem *> items;
 	if (!item) return(items);
 	for (int i = 0 ; i < item -> childCount() ; ++ i) {
@@ -742,9 +968,14 @@ QList<QTreeWidgetItem *> GenericPanel::childItems(QTreeWidgetItem *item, QET::It
 	@see GenericPanel::childItems()
 */
 template<typename T>
-void GenericPanel::removeObsoleteItems(const QList<T> &expected_items, QTreeWidgetItem *item, QET::ItemType type, bool recursive) {
+void GenericPanel::removeObsoleteItems(
+		const QList<T> &expected_items,
+		QTreeWidgetItem *item,
+		QET::ItemType type,
+		bool recursive) {
 	// remove items not found in expected_items
-	foreach (QTreeWidgetItem *child_item, childItems(item, type, recursive)) {
+	foreach (QTreeWidgetItem *child_item,
+		 childItems(item, type, recursive)) {
 		T child_value = valueForItem<T>(child_item);
 		if (!expected_items.contains(child_value)) {
 			deleteItem(child_item);
@@ -756,7 +987,8 @@ void GenericPanel::removeObsoleteItems(const QList<T> &expected_items, QTreeWidg
 	@return the value stored in \a item
 */
 template<typename T>
-T GenericPanel::valueForItem(QTreeWidgetItem *item) const {
+T GenericPanel::valueForItem(QTreeWidgetItem *item) const
+{
 	return item -> data(0, GenericPanel::Item).value<T>();
 }
 template TitleBlockTemplateLocation
@@ -767,8 +999,10 @@ template QETProject* GenericPanel::valueForItem(QTreeWidgetItem*)
 const;
 template Diagram* GenericPanel::valueForItem(QTreeWidgetItem*)
 const;
+
 /**
-	
+	@brief GenericPanel::unregisterItem
+	@param item
 */
 void GenericPanel::unregisterItem(QTreeWidgetItem *item) {
 	if (!item) return;
@@ -784,12 +1018,16 @@ void GenericPanel::unregisterItem(QTreeWidgetItem *item) {
 }
 
 /**
+	@brief GenericPanel::event
 	Handle various events; reimplemented here to emit the signal
 	firstActivated().
+	@param event
+	@return
 */
 bool GenericPanel::event(QEvent *event) {
 	if (first_activation_) {
-		if (event -> type() == QEvent::WindowActivate || event -> type() == QEvent::Show) {
+		if (event -> type() == QEvent::WindowActivate
+				|| event -> type() == QEvent::Show) {
 			QTimer::singleShot(250, this, SLOT(emitFirstActivated()));
 			first_activation_ = false;
 		}
@@ -798,8 +1036,10 @@ bool GenericPanel::event(QEvent *event) {
 }
 
 /**
+	@brief GenericPanel::emitFirstActivated
 	Emit the signal firstActivated().
 */
-void GenericPanel::emitFirstActivated() {
+void GenericPanel::emitFirstActivated()
+{
 	emit(firstActivated());
 }
