@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -16,24 +16,23 @@
 	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "projectview.h"
-#include "qetproject.h"
-#include "diagramview.h"
+
+#include "ElementsCollection/xmlelementcollection.h"
+#include "autoNum/assignvariables.h"
 #include "diagram.h"
-#include "diagramprintdialog.h"
+#include "diagramview.h"
+#include "editor/qetelementeditor.h"
 #include "exportdialog.h"
 #include "qetapp.h"
-#include "qetelementeditor.h"
-#include "borderpropertieswidget.h"
-#include "titleblockpropertieswidget.h"
-#include "conductorpropertieswidget.h"
 #include "qeticons.h"
 #include "qetmessagebox.h"
-#include "qettemplateeditor.h"
-#include "diagramfoliolist.h"
-#include "projectpropertiesdialog.h"
-#include "xmlelementcollection.h"
-#include "autoNum/assignvariables.h"
-#include "dialogwaiting.h"
+#include "qetproject.h"
+#include "titleblock/qettemplateeditor.h"
+#include "ui/borderpropertieswidget.h"
+#include "ui/conductorpropertieswidget.h"
+#include "ui/dialogwaiting.h"
+#include "ui/projectpropertiesdialog.h"
+#include "ui/titleblockpropertieswidget.h"
 
 /**
 	Constructeur
@@ -55,33 +54,40 @@ ProjectView::ProjectView(QETProject *project, QWidget *parent) :
 	Destructeur
 	Supprime les DiagramView embarquees
 */
-ProjectView::~ProjectView() {
-	// qDebug() << "Suppression du ProjectView" << ((void *)this);
-	foreach(int id, m_diagram_ids.keys()) {
-		DiagramView *diagram_view = m_diagram_ids.take(id);
-		delete diagram_view;
-	}
+ProjectView::~ProjectView()
+{
+	for (auto dv_ : m_diagram_ids.values())
+		dv_->deleteLater();
 }
 
 /**
 	@return le projet actuellement visualise par le ProjectView
 */
-QETProject *ProjectView::project() {
+QETProject *ProjectView::project()
+{
 	return(m_project);
 }
 
 /**
-	Definit le projet visualise par le ProjectView. Ne fait rien si le projet a
-	deja ete defini.
-	@param project projet a visualiser
+	@brief ProjectView::setProject
+	Set the project display by the project view
+	@param project
 */
-void ProjectView::setProject(QETProject *project) {
-	if (!m_project) {
+void ProjectView::setProject(QETProject *project)
+{
+	if (!m_project)
+	{
 		m_project = project;
-		connect(m_project, SIGNAL(projectTitleChanged(QETProject *, const QString &)),	this, SLOT(updateWindowTitle()));
-		connect(m_project, SIGNAL(projectModified	(QETProject *, bool)),				this, SLOT(updateWindowTitle()));
-		connect(m_project, SIGNAL(readOnlyChanged	(QETProject *, bool)),				this, SLOT(adjustReadOnlyState()));
-		connect(m_project, SIGNAL(addAutoNumDiagram()),									this, SLOT(addNewDiagram()));
+		connect(m_project, &QETProject::projectTitleChanged, this, &ProjectView::updateWindowTitle);
+		connect(m_project, &QETProject::projectModified, this, &ProjectView::updateWindowTitle);
+		connect(m_project, &QETProject::readOnlyChanged, this, &ProjectView::adjustReadOnlyState);
+		connect(m_project, &QETProject::addAutoNumDiagram, [this](){this->project()->addNewDiagram();});
+
+		connect(m_project, &QETProject::diagramAdded, [this](QETProject *project, Diagram *diagram) {
+			Q_UNUSED(project)
+			this->diagramAdded(diagram);
+		});
+
 		adjustReadOnlyState();
 		loadDiagrams();
 	}
@@ -90,15 +96,17 @@ void ProjectView::setProject(QETProject *project) {
 /**
 	@return la liste des schemas ouverts dans le projet
 */
-QList<DiagramView *> ProjectView::diagram_views() const {
+QList<DiagramView *> ProjectView::diagram_views() const
+{
 	return(m_diagram_view_list);
 }
 
 /**
- * @brief ProjectView::currentDiagram
- * @return The current active diagram view or nullptr if there isn't diagramView in this project view.
- */
-DiagramView *ProjectView::currentDiagram() const {
+	@brief ProjectView::currentDiagram
+	@return The current active diagram view or nullptr if there isn't diagramView in this project view.
+*/
+DiagramView *ProjectView::currentDiagram() const
+{
 	int current_tab_index = m_tab -> currentIndex();
 	if (current_tab_index == -1)
 		return nullptr;
@@ -122,7 +130,8 @@ void ProjectView::closeEvent(QCloseEvent *qce) {
 /**
 	@brief change current diagramview to next folio
 */
-void ProjectView::changeTabDown(){
+void ProjectView::changeTabDown()
+{
 	DiagramView *nextDiagramView = this->nextDiagram();
 	if (nextDiagramView!=nullptr){
 		rebuildDiagramsMap();
@@ -133,7 +142,8 @@ void ProjectView::changeTabDown(){
 /**
 	@return next folio of current diagramview
 */
-DiagramView *ProjectView::nextDiagram() {
+DiagramView *ProjectView::nextDiagram()
+{
 	int current_tab_index = m_tab -> currentIndex();
 	int next_tab_index = current_tab_index + 1;	//get next tab index
 	if (next_tab_index<m_diagram_ids.count()) //if next tab index >= greatest tab the last tab is activated so no need to change tab.
@@ -145,7 +155,8 @@ DiagramView *ProjectView::nextDiagram() {
 /**
 	@brief change current diagramview to previous tab
 */
-void ProjectView::changeTabUp(){
+void ProjectView::changeTabUp()
+{
 	DiagramView *previousDiagramView = this->previousDiagram();
 	if (previousDiagramView!=nullptr){
 		rebuildDiagramsMap();
@@ -156,7 +167,8 @@ void ProjectView::changeTabUp(){
 /**
 	@return previous folio of current diagramview
 */
-DiagramView *ProjectView::previousDiagram() {
+DiagramView *ProjectView::previousDiagram()
+{
 	int current_tab_index = m_tab -> currentIndex();
 	int previous_tab_index = current_tab_index - 1;	//get previous tab index
 	if (previous_tab_index>=0) //if previous tab index = 0 then the first tab is activated so no need to change tab.
@@ -168,7 +180,8 @@ DiagramView *ProjectView::previousDiagram() {
 /**
 	@brief change current diagramview to last tab
 */
-void ProjectView::changeLastTab(){
+void ProjectView::changeLastTab()
+{
 	DiagramView *lastDiagramView = this->lastDiagram();
 	m_tab->setCurrentWidget(lastDiagramView);
 }
@@ -176,14 +189,16 @@ void ProjectView::changeLastTab(){
 /**
 	@return last folio of current project
 */
-DiagramView *ProjectView::lastDiagram(){
+DiagramView *ProjectView::lastDiagram()
+{
 	return(m_diagram_ids.last());
 }
 
 /**
 	@brief change current diagramview to first tab
 */
-void ProjectView::changeFirstTab(){
+void ProjectView::changeFirstTab()
+{
 	DiagramView *firstDiagramView = this->firstDiagram();
 	m_tab->setCurrentWidget(firstDiagramView);
 }
@@ -191,7 +206,8 @@ void ProjectView::changeFirstTab(){
 /**
 	@return first folio of current project
 */
-DiagramView *ProjectView::firstDiagram(){
+DiagramView *ProjectView::firstDiagram()
+{
 	return(m_diagram_ids.first());
 }
 
@@ -204,7 +220,8 @@ DiagramView *ProjectView::firstDiagram(){
 	@see tryClosingElementEditors()
 	@see tryClosingDiagrams()
 */
-bool ProjectView::tryClosing() {
+bool ProjectView::tryClosing()
+{
 	if (!m_project) return(true);
 
 	// First step: require external editors closing -- users may either cancel
@@ -253,7 +270,8 @@ bool ProjectView::tryClosing() {
 	d'un editeur d'element.
 	@return true si tous les editeurs d'element ont pu etre fermes, false sinon
 */
-bool ProjectView::tryClosingElementEditors() {
+bool ProjectView::tryClosingElementEditors()
+{
 	if (!m_project) return(true);
 	/*
 		La QETApp permet d'acceder rapidement aux editeurs d'element
@@ -272,12 +290,13 @@ bool ProjectView::tryClosingElementEditors() {
 }
 
 /**
- * @brief ProjectView::tryClosingDiagrams
- * try to close this project, if diagram or project option are changed
- * a dialog ask if user want to save the modification.
- * @return the answer of dialog or discard if no change.
- */
-int ProjectView::tryClosingDiagrams() {
+	@brief ProjectView::tryClosingDiagrams
+	try to close this project, if diagram or project option are changed
+	a dialog ask if user want to save the modification.
+	@return the answer of dialog or discard if no change.
+*/
+int ProjectView::tryClosingDiagrams()
+{
 	if (!m_project) return(QMessageBox::Discard);
 
 	if (!project()->projectOptionsWereModified() &&
@@ -313,15 +332,15 @@ QString ProjectView::askUserForFilePath(bool assign) {
 	QString filepath = QFileDialog::getSaveFileName(
 		this,
 		tr("Enregistrer sous", "dialog title"),
-		m_project -> currentDir(),
+		m_project -> currentDir() + "/" + tr("sansnom") + ".qet",
 		tr("Projet QElectroTech (*.qet)", "filetypes allowed when saving a project file")
 	);
 
 	// if no filepath is provided, return an empty string
 	if (filepath.isEmpty()) return(filepath);
 
-	// if the name does not end with the .qet extension, append it
-	if (!filepath.endsWith(".qet", Qt::CaseInsensitive)) filepath += ".qet";
+//	// if the name does not end with the .qet extension, append it
+//	if (!filepath.endsWith(".qet", Qt::CaseInsensitive)) filepath += ".qet";
 
 	if (assign) {
 		// assign the provided filepath to the currently edited project
@@ -335,94 +354,28 @@ QString ProjectView::askUserForFilePath(bool assign) {
 	@return the QETResult object to be returned when it appears this project
 	view is not associated to any project.
 */
-QETResult ProjectView::noProjectResult() const {
+QETResult ProjectView::noProjectResult() const
+{
 	QETResult no_project(tr("aucun projet affiché", "error message"), false);
 	return(no_project);
 }
 
 /**
- * @brief ProjectView::addNewDiagram
- * Add new diagram to project view
- */
-void ProjectView::addNewDiagram() {
-	if (m_project -> isReadOnly()) return;
-
-	Diagram *new_diagram = m_project -> addNewDiagram();
-	DiagramView *new_diagram_view = new DiagramView(new_diagram);
-	addDiagram(new_diagram_view);
-
-	if (m_project -> diagrams().size() % 58 == 1 && m_project -> getFolioSheetsQuantity() != 0)
-		addNewDiagramFolioList();
-	showDiagram(new_diagram_view);
-}
-
-/**
- * @brief ProjectView::addNewDiagramFolioList
- * Add new diagram folio list to project
- */
-void ProjectView::addNewDiagramFolioList() {
-	if (m_project -> isReadOnly()) return;
-	int i = 1; //< Each new diagram is added  to the end of the project.
-			   //< We use @i to move the folio list at second position in the project
-	foreach (Diagram *d, m_project -> addNewDiagramFolioList()) {
-		DiagramView *new_diagram_view = new DiagramView(d);
-		addDiagram(new_diagram_view);
-		showDiagram(new_diagram_view);
-		m_tab->tabBar()->moveTab(diagram_views().size()-1, i);
-		i++;
-	}
-}
-
-/**
- * @brief ProjectView::addDiagram
- * Add diagram view to this project view
- * @param diagram_view
- */
-void ProjectView::addDiagram(DiagramView *diagram_view)
-{
-	if (!diagram_view) 
-		return;
-
-		//Check if diagram isn't present in the project
-	if (m_diagram_ids.values().contains(diagram_view))
-		return;
-
-		// Add new tab for the diagram
-    m_tab->addTab(diagram_view, QET::Icons::Diagram, diagram_view -> title());
-	diagram_view->setFrameStyle(QFrame::Plain | QFrame::NoFrame);
-
-	m_diagram_view_list << diagram_view;
-
-	rebuildDiagramsMap();
-	updateAllTabsTitle();
-	
-	connect(diagram_view, SIGNAL(showDiagram(Diagram*)), this, SLOT(showDiagram(Diagram*)));
-	connect(diagram_view, SIGNAL(titleChanged(DiagramView *, const QString &)), this, SLOT(updateTabTitle(DiagramView *)));
-	connect(diagram_view, SIGNAL(findElementRequired(const ElementsLocation &)), this, SIGNAL(findElementRequired(const ElementsLocation &)));
-	connect(diagram_view, SIGNAL(editElementRequired(const ElementsLocation &)), this, SIGNAL(editElementRequired(const ElementsLocation &)));
-	connect(&diagram_view->diagram()->border_and_titleblock , &BorderTitleBlock::titleBlockFolioChanged, [this, diagram_view]() {this->updateTabTitle(diagram_view);});
-
-		// signal diagram view was added
-	emit(diagramAdded(diagram_view));
-	m_project -> setModified(true);
-}
-
-/**
- * @brief ProjectView::removeDiagram
- * Remove a diagram (folio) of the project
- * @param diagram_view : diagram view to remove
- */
+	@brief ProjectView::removeDiagram
+	Remove a diagram (folio) of the project
+	@param diagram_view : diagram view to remove
+*/
 void ProjectView::removeDiagram(DiagramView *diagram_view)
 {
 	if (!diagram_view)
-        return;
+		return;
 	if (m_project -> isReadOnly())
-        return;
+		return;
 	if (!m_diagram_ids.values().contains(diagram_view))
-        return;
+		return;
 
 
-        //Ask confirmation to user.
+	//Ask confirmation to user.
 	int answer = QET::QetMessageBox::question(
 		this,
 		tr("Supprimer le folio ?", "message box title"),
@@ -434,22 +387,18 @@ void ProjectView::removeDiagram(DiagramView *diagram_view)
 		return;
 	}
 
-        //Remove the diagram view of the tabs widget
+	//Remove the diagram view of the tabs widget
 	int index_to_remove = m_diagram_ids.key(diagram_view);
 	m_tab->removeTab(index_to_remove);
 	m_diagram_view_list.removeAll(diagram_view);
 	rebuildDiagramsMap();
-    
+
 	m_project -> removeDiagram(diagram_view -> diagram());
 	delete diagram_view;
 
 	emit(diagramRemoved(diagram_view));
-	
-        //Make definitve the withdrawal
-	m_project -> write();
-    updateAllTabsTitle();
-    m_project -> setModified(true);
-
+	updateAllTabsTitle();
+	m_project -> setModified(true);
 }
 
 /**
@@ -488,7 +437,8 @@ void ProjectView::showDiagram(Diagram *diagram) {
 	Enable the user to edit properties of the current project through a
 	configuration dialog.
 */
-void ProjectView::editProjectProperties() {
+void ProjectView::editProjectProperties()
+{
 	if (!m_project) return;
 	ProjectPropertiesDialog dialog(m_project, parentWidget());
 	dialog.exec();
@@ -497,7 +447,8 @@ void ProjectView::editProjectProperties() {
 /**
 	Edite les proprietes du schema courant
 */
-void ProjectView::editCurrentDiagramProperties() {
+void ProjectView::editCurrentDiagramProperties()
+{
 	editDiagramProperties(currentDiagram());
 }
 
@@ -560,8 +511,8 @@ void ProjectView::moveDiagramDown(Diagram *diagram) {
 }
 
 /*
- * Deplace le schema diagram_view vers le haut / la gauche en position 0
- */
+	Deplace le schema diagram_view vers le haut / la gauche en position 0
+*/
 void ProjectView::moveDiagramUpTop(DiagramView *diagram_view)
 {
 	if (!diagram_view) return;
@@ -571,12 +522,12 @@ void ProjectView::moveDiagramUpTop(DiagramView *diagram_view)
 		// le schema est le premier du projet
 		return;
 	}
-	m_tab -> tabBar() -> moveTab(diagram_view_position, (diagram_views().size(), 0));
+	m_tab->tabBar()->moveTab(diagram_view_position, 0);
 }
 
 /*
- * Deplace le schema diagram vers le haut / la gauche en position 0
- */
+	Deplace le schema diagram vers le haut / la gauche en position 0
+*/
 void ProjectView::moveDiagramUpTop(Diagram *diagram)
 {
 	moveDiagramUpTop(findDiagram(diagram));
@@ -624,45 +575,15 @@ void ProjectView::moveDiagramDownx10(Diagram *diagram) {
 	moveDiagramDownx10(findDiagram(diagram));
 }
 
-/**
-	Ce slot demarre un dialogue permettant a l'utilisateur de parametrer et de
-	lancer l'impression de toute ou partie du projet.
-*/
-void ProjectView::printProject() {
-	if (!m_project) return;
-
-	// transforme le titre du projet en nom utilisable pour le document
-	QString doc_name;
-	if (!(m_project -> title().isEmpty())) {
-		doc_name = m_project -> title();
-	} else if (!m_project -> filePath().isEmpty()) {
-		doc_name = QFileInfo(m_project -> filePath()).baseName();
-	}
-	doc_name = QET::stringToFileName(doc_name);
-	if (doc_name.isEmpty()) {
-		doc_name = tr("projet", "string used to generate a filename");
-	}
-
-	// recupere le dossier contenant le fichier courant
-	QString dir_path = m_project -> currentDir();
-
-	// determine un chemin pour le pdf / ps
-	QString file_name = QDir::toNativeSeparators(QDir::cleanPath(dir_path + "/" + doc_name));
-
-	DiagramPrintDialog print_dialog(m_project, this);
-	print_dialog.setDocName(doc_name);
-	print_dialog.setFileName(file_name);
-	print_dialog.exec();
-}
-
 /**
 	Exporte le schema.
 */
-void ProjectView::exportProject() {
+void ProjectView::exportProject()
+{
 	if (!m_project) return;
 
 	ExportDialog ed(m_project, parentWidget());
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
 	ed.setWindowFlags(Qt::Sheet);
 #endif
 	ed.exec();
@@ -674,7 +595,8 @@ void ProjectView::exportProject() {
 	@see setFilePath()
 	@return a QETResult object reflecting the situation
 */
-QETResult ProjectView::save() {
+QETResult ProjectView::save()
+{
 	return(doSave());
 }
 
@@ -725,7 +647,8 @@ QETResult ProjectView::doSave()
 	@return an integer value above zero if elements and/or categories were
 	cleaned.
 */
-int ProjectView::cleanProject() {
+int ProjectView::cleanProject()
+{
 	if (!m_project) return(0);
 
 	// s'assure que le schema n'est pas en lecture seule
@@ -749,7 +672,7 @@ int ProjectView::cleanProject() {
 	clean_categories -> setChecked(true);
 
 	QDialog clean_dialog(parentWidget());
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
 	clean_dialog.setWindowFlags(Qt::Sheet);
 #endif
 
@@ -785,15 +708,23 @@ int ProjectView::cleanProject() {
 /**
 	Initialize actions for this widget.
 */
-void ProjectView::initActions() {
-	add_new_diagram_ = new QAction(QET::Icons::AddFolio, tr("Ajouter un folio"), this);
-	connect(add_new_diagram_, SIGNAL(triggered()), this, SLOT(addNewDiagram()));
+void ProjectView::initActions()
+{
+	m_add_new_diagram = new QAction(QET::Icons::AddFolio, tr("Ajouter un folio"), this);
+	connect(m_add_new_diagram, &QAction::triggered, [this](){this->m_project->addNewDiagram();});
+	
+	m_first_view = new QAction(QET::Icons::ArrowLeftDouble, tr("Revenir au debut du projet"),this);
+	connect(m_first_view, &QAction::triggered, [this](){this->m_tab->setCurrentWidget(firstDiagram());});
+	
+	m_end_view = new QAction(QET::Icons::ArrowRightDouble, tr("Aller à la fin du projet"),this);
+	connect(m_end_view, &QAction::triggered, [this](){this->m_tab->setCurrentWidget(lastDiagram());});
 }
 
 /**
 	Initialize child widgets for this widget.
 */
-void ProjectView::initWidgets() {
+void ProjectView::initWidgets()
+{
 	setObjectName("ProjectView");
 	setWindowIcon(QET::Icons::ProjectFileGP);
 
@@ -808,17 +739,40 @@ void ProjectView::initWidgets() {
 	fallback_label_ -> setAlignment(Qt::AlignVCenter | Qt::AlignHCenter);
 
 	// initialize tabs
+#ifdef Q_OS_MACOS
+	m_tab = new WheelEnabledTabBar(this);
+#else
 	m_tab = new QTabWidget(this);
+#endif
 	m_tab -> setMovable(true);
 
+	QHBoxLayout *TopRightCorner_Layout = new QHBoxLayout();
+	TopRightCorner_Layout->setContentsMargins(0,0,0,0);
+
 	QToolButton *add_new_diagram_button = new QToolButton;
-	add_new_diagram_button -> setDefaultAction(add_new_diagram_);
+	add_new_diagram_button -> setDefaultAction(m_add_new_diagram);
 	add_new_diagram_button -> setAutoRaise(true);
-	m_tab -> setCornerWidget(add_new_diagram_button, Qt::TopRightCorner);
+	TopRightCorner_Layout->addWidget(add_new_diagram_button);
 
 	connect(m_tab, SIGNAL(currentChanged(int)), this, SLOT(tabChanged(int)));
 	connect(m_tab, SIGNAL(tabBarDoubleClicked(int)), this, SLOT(tabDoubleClicked(int)));
-	connect(m_tab->tabBar(), SIGNAL(tabMoved(int, int)), this, SLOT(tabMoved(int, int)));
+	connect(m_tab->tabBar(), SIGNAL(tabMoved(int, int)), this, SLOT(tabMoved(int, int)), Qt::QueuedConnection);
+	
+	//arrows buttton to return on first view
+	QToolButton *m_first_view_button =new QToolButton;
+	m_first_view_button->setDefaultAction(m_first_view);
+	m_first_view_button->setAutoRaise(true);
+	m_tab->setCornerWidget(m_first_view_button, Qt::TopLeftCorner);
+	
+	//arrows buttton to go on last view
+	QToolButton *m_end_view_button =new QToolButton;
+	m_end_view_button->setDefaultAction(m_end_view);
+	m_end_view_button->setAutoRaise(true);
+	TopRightCorner_Layout->addWidget(m_end_view_button);
+
+	QWidget *tabwidget=new QWidget(this);
+	tabwidget->setLayout(TopRightCorner_Layout);
+	m_tab -> setCornerWidget(tabwidget, Qt::TopRightCorner);
 
 	fallback_widget_ -> setVisible(false);
 	m_tab -> setVisible(false);
@@ -827,12 +781,13 @@ void ProjectView::initWidgets() {
 /**
 	Initialize layout for this widget.
 */
-void ProjectView::initLayout() {
+void ProjectView::initLayout()
+{
 	QVBoxLayout *fallback_widget_layout_ = new QVBoxLayout(fallback_widget_);
 	fallback_widget_layout_ -> addWidget(fallback_label_);
 
 	layout_ = new QVBoxLayout(this);
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
 	layout_ -> setContentsMargins(0, 8, 0, 0);
 #else
 	layout_ -> setContentsMargins(0, 0, 0, 0);
@@ -844,11 +799,11 @@ void ProjectView::initLayout() {
 
 
 /**
- * @brief ProjectView::loadDiagrams
- * Load diagrams of project.
- * We create a diagram view for each diagram,
- * and add it to the project view.
- */
+	@brief ProjectView::loadDiagrams
+	Load diagrams of project.
+	We create a diagram view for each diagram,
+	and add it to the project view.
+*/
 void ProjectView::loadDiagrams()
 {
 	if (!m_project) return;
@@ -871,27 +826,23 @@ void ProjectView::loadDiagrams()
 			dialog->setDetail(diagram->title());
 			dialog->setProgressBar(dialog->progressBarValue()+1);
 		}
-		
-		DiagramView *sv = new DiagramView(diagram);
-		addDiagram(sv);
+		diagramAdded(diagram);
 	}
 
-	this->currentDiagram()->diagram()->loadElmtFolioSeq();
-	this->currentDiagram()->diagram()->loadCndFolioSeq();
-
-	// If project have the folios list, move it at the beginning of the project
-	if (m_project -> getFolioSheetsQuantity()) {
-		for (int i = 0; i < m_project->getFolioSheetsQuantity(); i++)
-		m_tab -> tabBar() -> moveTab(diagram_views().size()-1, + 1);
-		m_project->setModified(false);
+	if (DiagramView *dv = currentDiagram())
+	{
+		dv->diagram()->loadElmtFolioSeq();
+		dv->diagram()->loadCndFolioSeq();
 	}
+	m_tab->setCurrentWidget(firstDiagram());
 }
 
 /**
- * @brief ProjectView::updateWindowTitle
- * Update the project view title
- */
-void ProjectView::updateWindowTitle() {
+	@brief ProjectView::updateWindowTitle
+	Update the project view title
+*/
+void ProjectView::updateWindowTitle()
+{
 	QString title;
 	if (m_project) {
 		title = m_project -> pathNameTitle();
@@ -905,52 +856,84 @@ void ProjectView::updateWindowTitle() {
 	Effectue les actions necessaires lorsque le projet visualise entre ou sort
 	du mode lecture seule.
 */
-void ProjectView::adjustReadOnlyState() {
+void ProjectView::adjustReadOnlyState()
+{
 	bool editable = !(m_project -> isReadOnly());
 
 	// prevent users from moving existing diagrams
 	m_tab -> setMovable(editable);
 	// prevent users from adding new diagrams
-	add_new_diagram_ -> setEnabled(editable);
+	m_add_new_diagram -> setEnabled(editable);
 
 	// on met a jour le titre du widget, qui reflete l'etat de lecture seule
 	updateWindowTitle();
 }
 
 /**
- * @brief ProjectView::updateTabTitle
- * Update the title of the tab which display the diagram view @diagram_view.
- * @param diagram : The diagram view.
- */
-void ProjectView::updateTabTitle(DiagramView *diagram_view)
+	@brief ProjectView::diagramAdded
+	Slot called when qetproject emit diagramAdded
+	@param diagram
+*/
+void ProjectView::diagramAdded(Diagram *diagram)
 {
-    int diagram_tab_id = m_diagram_ids.key(diagram_view, -1);
-    
-    if (diagram_tab_id != -1)
-    {
-        QSettings settings;
-        QString title;
-        Diagram *diagram = diagram_view->diagram();
-        
-        if (settings.value("genericpanel/folio", false).toBool())
-        {
-            QString formula = diagram->border_and_titleblock.folio();
-            autonum::sequentialNumbers seq;
-            title = autonum::AssignVariables::formulaToLabel(formula, seq, diagram);
-        }
-        else
-            title = QString::number(diagram->folioIndex() + 1);
-        
-        title += " - ";
-        title += diagram->title();
-        m_tab->setTabText(diagram_tab_id ,title);
-    }
+	auto dv = new DiagramView(diagram);
+	auto index = m_project->folioIndex(diagram);
+	m_tab->insertTab(index, dv, QET::Icons::Diagram, dv->title());
+	dv->setFrameStyle(QFrame::Plain | QFrame::NoFrame);
+
+	m_diagram_view_list.insert(index, dv);
+
+	rebuildDiagramsMap();
+	updateAllTabsTitle();
+
+	connect(dv, &DiagramView::showDiagram,         this, QOverload<Diagram*>::of(&ProjectView::showDiagram));
+	connect(dv, &DiagramView::titleChanged,        this, &ProjectView::updateTabTitle);
+	connect(dv, &DiagramView::findElementRequired, this, &ProjectView::findElementRequired);
+	connect(&dv->diagram()->border_and_titleblock , &BorderTitleBlock::titleBlockFolioChanged, [this, dv]() {this->updateTabTitle(dv);});
+
+		// signal diagram view was added
+	emit(diagramAdded(dv));
+	m_project->setModified(true);
+	showDiagram(dv);
 }
 
 /**
- * @brief ProjectView::updateAllTabsTitle
- * Update all tabs title
- */
+	@brief ProjectView::updateTabTitle
+	Update the title of the tab which display the diagram view.
+	@param diagram_view : The diagram view.
+*/
+void ProjectView::updateTabTitle(DiagramView *diagram_view)
+{
+	int diagram_tab_id = m_diagram_ids.key(diagram_view, -1);
+	
+	if (diagram_tab_id != -1)
+	{
+		QSettings settings;
+		QString title;
+		Diagram *diagram = diagram_view->diagram();
+		
+		if (settings.value("genericpanel/folio", false).toBool())
+		{
+			QString formula = diagram->border_and_titleblock.folio();
+			autonum::sequentialNumbers seq;
+			title = autonum::AssignVariables::formulaToLabel(
+						formula,
+						seq,
+						diagram);
+		}
+		else
+			title = QString::number(diagram->folioIndex() + 1);
+		
+		title += " - ";
+		title += diagram->title();
+		m_tab->setTabText(diagram_tab_id ,title);
+	}
+}
+
+/**
+	@brief ProjectView::updateAllTabsTitle
+	Update all tabs title
+*/
 void ProjectView::updateAllTabsTitle()
 {
 	for (DiagramView *dv : m_diagram_ids.values())
@@ -994,7 +977,8 @@ DiagramView *ProjectView::findDiagram(Diagram *diagram) {
 /**
 	Reconstruit la map associant les index des onglets avec les DiagramView
 */
-void ProjectView::rebuildDiagramsMap() {
+void ProjectView::rebuildDiagramsMap()
+{
 	// vide la map
 	m_diagram_ids.clear();
 
@@ -1006,12 +990,12 @@ void ProjectView::rebuildDiagramsMap() {
 }
 
 /**
- * @brief ProjectView::tabChanged
- * Manage the tab change.
- * If tab_id == -1 (there is no diagram opened),
- * we display the fallback widget.
- * @param tab_id
- */
+	@brief ProjectView::tabChanged
+	Manage the tab change.
+	If tab_id == -1 (there is no diagram opened),
+	we display the fallback widget.
+	@param tab_id
+*/
 void ProjectView::tabChanged(int tab_id)
 {
 	if (tab_id == -1)
