@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -17,6 +17,16 @@
 */
 #include "propertiesinterface.h"
 
+/**
+	@brief PropertiesInterface::PropertiesInterface
+*/
 PropertiesInterface::PropertiesInterface()
 {
 }
+/**
+	@brief PropertiesInterface::~PropertiesInterface
+*/
+PropertiesInterface::~PropertiesInterface()
+{
+
+}
