@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -22,9 +22,9 @@ ReportProperties::ReportProperties()
 {}
 
 /**
- * @brief ReportProperties::defaultProperties
- * @return the default properties stored in the setting file
- */
+	@brief ReportProperties::defaultProperties
+	@return the default properties stored in the setting file
+*/
 QString ReportProperties::defaultProperties()
 {
 	QSettings settings;
