@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -20,6 +20,9 @@
 
 #include <QString>
 
+/**
+	@brief The ReportProperties class
+*/
 class ReportProperties
 {
 	public:
