@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -16,14 +16,15 @@
 	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "crossrefitem.h"
-#include "element.h"
-#include "qetapp.h"
-#include "diagramposition.h"
-#include "diagram.h"
-#include "qgraphicsitemutility.h"
-#include "assignvariables.h"
+
+#include "../autoNum/assignvariables.h"
+#include "../diagram.h"
+#include "../diagramposition.h"
+#include "../qetapp.h"
 #include "dynamicelementtextitem.h"
+#include "element.h"
 #include "elementtextitemgroup.h"
+#include "qgraphicsitemutility.h"
 
 //define the height of the header.
 static int header = 5;
@@ -31,19 +32,19 @@ static int header = 5;
 static int cross_min_heigth = 33;
 
 /**
- * @brief CrossRefItem::CrossRefItem
- * @param elmt : element to display the cross ref
- */
+	@brief CrossRefItem::CrossRefItem
+	@param elmt : element to display the cross ref
+*/
 CrossRefItem::CrossRefItem(Element *elmt) :
 	QGraphicsObject(elmt),
 	m_element(elmt)
 {init();}
 
 /**
- * @brief CrossRefItem::CrossRefItem
- * @param elmt : element to display the cross ref
- * @param text : If the Xref must be displayed under a text, the text.
- */
+	@brief CrossRefItem::CrossRefItem
+	@param elmt : element to display the cross ref
+	@param text : If the Xref must be displayed under a text, the text.
+*/
 CrossRefItem::CrossRefItem(Element *elmt, DynamicElementTextItem *text) :
 	QGraphicsObject(text),
 	m_element (elmt),
@@ -51,10 +52,10 @@ CrossRefItem::CrossRefItem(Element *elmt, DynamicElementTextItem *text) :
 {init();}
 
 /**
- * @brief CrossRefItem::CrossRefItem
- * @param elmt : element to display the cross ref
- * @param group : If the Xref must be displayed under a group, the group.
- */
+	@brief CrossRefItem::CrossRefItem
+	@param elmt : element to display the cross ref
+	@param group : If the Xref must be displayed under a group, the group.
+*/
 CrossRefItem::CrossRefItem(Element *elmt, ElementTextItemGroup *group) :
 	QGraphicsObject(group),
 	m_element(elmt),
@@ -62,15 +63,16 @@ CrossRefItem::CrossRefItem(Element *elmt, ElementTextItemGroup *group) :
 {init();}
 
 /**
- * @brief CrossRefItem::~CrossRefItem
- * Default destructor
- */
-CrossRefItem::~CrossRefItem() {}
+	@brief CrossRefItem::~CrossRefItem
+	Default destructor
+*/
+CrossRefItem::~CrossRefItem()
+{}
 
 /**
- * @brief CrossRefItem::init
- * init this Xref
- */
+	@brief CrossRefItem::init
+	init this Xref
+*/
 void CrossRefItem::init()
 {
 	if(!m_element->diagram())
@@ -91,9 +93,9 @@ void CrossRefItem::init()
 }
 
 /**
- * @brief CrossRefItem::setUpConnection
- * Set up several connection to keep up to date the Xref
- */
+	@brief CrossRefItem::setUpConnection
+	Set up several connection to keep up to date the Xref
+*/
 void CrossRefItem::setUpConnection()
 {
 	for(const QMetaObject::Connection& c : m_update_connection)
@@ -107,63 +109,84 @@ void CrossRefItem::setUpConnection()
 		set=true;
 	else if(m_properties.snapTo() == XRefProperties::Bottom && !m_text && !m_group) //Snap to bottom of element and parent is the element itself
 	{
-		m_update_connection << connect(m_element, SIGNAL(yChanged()),        this, SLOT(autoPos()));
-		m_update_connection << connect(m_element, SIGNAL(rotationChanged()), this, SLOT(autoPos()));
+		m_update_connection << connect(m_element, SIGNAL(yChanged()),
+					       this, SLOT(autoPos()));
+		m_update_connection << connect(m_element, SIGNAL(rotationChanged()),
+					       this, SLOT(autoPos()));
 		set=true;
 	}
 
 	if(set)
 	{
-		m_update_connection << connect(project, &QETProject::projectDiagramsOrderChanged, this, &CrossRefItem::updateLabel);
-		m_update_connection << connect(project, &QETProject::diagramRemoved,              this, &CrossRefItem::updateLabel);
-		m_update_connection << connect(m_element, &Element::linkedElementChanged, this, &CrossRefItem::linkedChanged);
+		m_update_connection
+				<< connect(project,
+					       &QETProject::projectDiagramsOrderChanged,
+					       this, &CrossRefItem::updateLabel);
+		m_update_connection << connect(project,
+					       &QETProject::diagramRemoved,
+					       this, &CrossRefItem::updateLabel);
+		m_update_connection << connect(m_element,
+					       &Element::linkedElementChanged,
+					       this, &CrossRefItem::linkedChanged);
 		linkedChanged();
 		updateLabel();
 	}
 }
 
 /**
- * @brief CrossRefItem::boundingRect
- * @return the bounding rect of this item
- */
-QRectF CrossRefItem::boundingRect() const {
+	@brief CrossRefItem::boundingRect
+	@return the bounding rect of this item
+*/
+QRectF CrossRefItem::boundingRect() const
+{
 	return m_bounding_rect;
 }
 
 /**
- * @brief CrossRefItem::shape
- * @return the shape of this item
- */
+	@brief CrossRefItem::shape
+	@return the shape of this item
+*/
 QPainterPath CrossRefItem::shape() const{
 	return m_shape_path;
 }
 
 /**
- * @brief CrossRefItem::elementPositionText
- * @param elmt
- * @return the string corresponding to the position of @elmt in the diagram.
- * if @add_prefix is true, prefix (for power and delay contact) is added to the poistion text.
- */
-QString CrossRefItem::elementPositionText(const Element *elmt, const bool &add_prefix) const
+	@brief CrossRefItem::elementPositionText
+	@param elmt
+	@param add_prefix
+	@return the string corresponding to the position of elmt in the diagram.
+	if add_prefix is true,
+	prefix (for power and delay contact) is added to the poistion text.
+*/
+QString CrossRefItem::elementPositionText(
+		const Element *elmt, const bool &add_prefix) const
 {
-	XRefProperties xrp = m_element->diagram()->project()->defaultXRefProperties(m_element->kindInformations()["type"].toString());
+	XRefProperties xrp =
+			m_element->diagram()->project()->defaultXRefProperties(
+				m_element->kindInformations()["type"].toString());
 	QString formula = xrp.masterLabel();
 	autonum::sequentialNumbers seq;
-	QString txt = autonum::AssignVariables::formulaToLabel(formula, seq, elmt->diagram(), elmt);
+	QString txt = autonum::AssignVariables::formulaToLabel(
+				formula,
+				seq, elmt->diagram(),
+				elmt);
 
 	if (add_prefix)
 	{
-		if      (elmt->kindInformations()["type"].toString() == "power")        txt.prepend(m_properties.prefix("power"));
-		else if (elmt->kindInformations()["type"].toString().contains("delay")) txt.prepend(m_properties.prefix("delay"));
-		else if (elmt->kindInformations()["state"].toString() == "SW")          txt.prepend(m_properties.prefix("switch"));
+		if      (elmt->kindInformations()["type"].toString() == "power")
+			txt.prepend(m_properties.prefix("power"));
+		else if (elmt->kindInformations()["type"].toString().contains("delay"))
+			txt.prepend(m_properties.prefix("delay"));
+		else if (elmt->kindInformations()["state"].toString() == "SW")
+			txt.prepend(m_properties.prefix("switch"));
 	}
 	return txt;
 }
 
 /**
- * @brief CrossRefItem::updateProperties
- * update the curent properties
- */
+	@brief CrossRefItem::updateProperties
+	update the curent properties
+*/
 void CrossRefItem::updateProperties()
 {
 	XRefProperties xrp = m_element->diagram()->project()->defaultXRefProperties(m_element->kindInformations()["type"].toString());
@@ -183,9 +206,9 @@ void CrossRefItem::updateProperties()
 }
 
 /**
- * @brief CrossRefItem::updateLabel
- * Update the content of the item
- */
+	@brief CrossRefItem::updateLabel
+	Update the content of the item
+*/
 void CrossRefItem::updateLabel()
 {
 		//init the shape and bounding rect
@@ -211,9 +234,6 @@ void CrossRefItem::updateLabel()
 		else if (dh == XRefProperties::Contacts)
 			drawAsContacts(qp);
 	}
-
-//	AddExtraInfo(qp, "comment");
-//	AddExtraInfo(qp, "location");
 	qp.end();
 
 	autoPos();
@@ -221,22 +241,32 @@ void CrossRefItem::updateLabel()
 }
 
 /**
- * @brief CrossRefItem::autoPos
- * Calculate and set position automaticaly.
- */
-void CrossRefItem::autoPos() {
-		//We calcul the position according to the @snapTo of the xrefproperties
+	@brief CrossRefItem::autoPos
+	Calculate and set position automaticaly.
+*/
+void CrossRefItem::autoPos()
+{
+	//We calcul the position according to the snapTo of the xrefproperties
 	if (m_properties.snapTo() == XRefProperties::Bottom)
-		centerToBottomDiagram(this, m_element, m_properties.offset() <= 40 ? 5 : m_properties.offset());
+		centerToBottomDiagram(this,
+				      m_element,
+				      m_properties.offset() <= 40
+				      ? 5
+				      : m_properties.offset());
 	else
 		centerToParentBottom(this);
 }
 
+/**
+	@brief CrossRefItem::sceneEvent
+	@param event
+	@return
+*/
 bool CrossRefItem::sceneEvent(QEvent *event)
 {
-		//By default when a QGraphicsItem is a child of a QGraphicsItemGroup
-		//all events are forwarded to group.
-		//We override it, when this Xref is in a group
+	//By default when a QGraphicsItem is a child of a QGraphicsItemGroup
+	//all events are forwarded to group.
+	//We override it, when this Xref is in a group
 	if(m_group)
 	{
 		switch (event->type())
@@ -262,22 +292,26 @@ bool CrossRefItem::sceneEvent(QEvent *event)
 }
 
 /**
- * @brief CrossRefItem::paint
- * Paint this item
- * @param painter
- * @param option
- * @param widget
- */
-void CrossRefItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget) {
-	Q_UNUSED(option);
-	Q_UNUSED(widget);
+	@brief CrossRefItem::paint
+	Paint this item
+	@param painter
+	@param option
+	@param widget
+*/
+void CrossRefItem::paint(
+		QPainter *painter,
+		const QStyleOptionGraphicsItem *option,
+		QWidget *widget)
+{
+	Q_UNUSED(option)
+	Q_UNUSED(widget)
 	m_drawing.play(painter);
 }
 
 /**
- * @brief CrossRefItem::mouseDoubleClickEvent
- * @param event
- */
+	@brief CrossRefItem::mouseDoubleClickEvent
+	@param event
+*/
 void CrossRefItem::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
 {
 	event->accept();
@@ -291,7 +325,8 @@ void CrossRefItem::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
 		m_hovered_contact->setSelected(true);
 
 			//Zoom to the linked slave element
-		foreach(QGraphicsView *view, m_hovered_contact->diagram()->views())
+		foreach(QGraphicsView *view,
+				m_hovered_contact->diagram()->views())
 		{
 			QRectF fit = m_hovered_contact->sceneBoundingRect();
 			fit.adjust(-200, -200, 200, 200);
@@ -300,12 +335,20 @@ void CrossRefItem::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
 	}
 }
 
+/**
+	@brief CrossRefItem::hoverEnterEvent
+	@param event
+*/
 void CrossRefItem::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
 {
 	m_hovered_contact = nullptr;
 		QGraphicsObject::hoverEnterEvent(event);
 }
 
+/**
+	@brief CrossRefItem::hoverMoveEvent
+	@param event
+*/
 void CrossRefItem::hoverMoveEvent(QGraphicsSceneHoverEvent *event)
 {
 	QPointF pos = event->pos();
@@ -314,7 +357,7 @@ void CrossRefItem::hoverMoveEvent(QGraphicsSceneHoverEvent *event)
 	{
 		foreach(QRectF rect, m_hovered_contacts_map.values(m_hovered_contact))
 		{
-				//Mouse hover the same rect than previous hover event
+			//Mouse hover the same rect than previous hover event
 			if (rect.contains(pos))
 			{
 				QGraphicsObject::hoverMoveEvent(event);
@@ -322,7 +365,7 @@ void CrossRefItem::hoverMoveEvent(QGraphicsSceneHoverEvent *event)
 			}
 		}
 
-			//At this point, mouse don't hover previous rect
+		//At this point, mouse don't hover previous rect
 		m_hovered_contact = nullptr;
 
 		foreach (Element *elmt, m_hovered_contacts_map.keys())
@@ -347,7 +390,7 @@ void CrossRefItem::hoverMoveEvent(QGraphicsSceneHoverEvent *event)
 		{
 			foreach(QRectF rect, m_hovered_contacts_map.values(elmt))
 			{
-					//Mouse hover a contact
+				//Mouse hover a contact
 				if (rect.contains(pos))
 				{
 					m_hovered_contact = elmt;
@@ -360,6 +403,10 @@ void CrossRefItem::hoverMoveEvent(QGraphicsSceneHoverEvent *event)
 	}
 }
 
+/**
+	@brief CrossRefItem::hoverLeaveEvent
+	@param event
+*/
 void CrossRefItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
 {
 	m_hovered_contact = nullptr;
@@ -367,30 +414,40 @@ void CrossRefItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
 	QGraphicsObject::hoverLeaveEvent(event);
 }
 
+/**
+	@brief CrossRefItem::linkedChanged
+*/
 void CrossRefItem::linkedChanged()
 {
 	for(const QMetaObject::Connection& c : m_slave_connection)
 		disconnect(c);
-	
+
 	m_slave_connection.clear();
-	
+
 	if(!isVisible())
 		return;
 	
 	for(Element *elmt : m_element->linkedElements())
 	{
-		m_slave_connection << connect(elmt, &Element::xChanged, this, &CrossRefItem::updateLabel);
-		m_slave_connection << connect(elmt, &Element::yChanged, this, &CrossRefItem::updateLabel);
+		m_slave_connection << connect(elmt,
+					      &Element::xChanged,
+					      this,
+					      &CrossRefItem::updateLabel);
+		m_slave_connection << connect(elmt,
+					      &Element::yChanged,
+					      this,
+					      &CrossRefItem::updateLabel);
 	}
-	
+
 	updateLabel();
 }
 
 /**
- * @brief CrossRefItem::buildHeaderContact
- * Draw the QPicture of m_hdr_no_ctc and m_hdr_nc_ctc
- */
-void CrossRefItem::buildHeaderContact() {
+	@brief CrossRefItem::buildHeaderContact
+	Draw the QPicture of m_hdr_no_ctc and m_hdr_nc_ctc
+*/
+void CrossRefItem::buildHeaderContact()
+{
 	if (!m_hdr_no_ctc.isNull() && !m_hdr_nc_ctc.isNull()) return;
 
 	//init the painter
@@ -433,57 +490,62 @@ void CrossRefItem::buildHeaderContact() {
 }
 
 /**
- * @brief CrossRefItem::setUpCrossBoundingRect
- * Get the numbers of slaves elements linked to this parent element,
- * for calculate the size of the cross bounding rect.
- * The cross ref item is drawing according to the size of the cross bounding rect.
- */
+	@brief CrossRefItem::setUpCrossBoundingRect
+	Get the numbers of slaves elements linked to this parent element,
+	for calculate the size of the cross bounding rect.
+	The cross ref item is drawing according to the size of
+	the cross bounding rect.
+	@param painter
+*/
 void CrossRefItem::setUpCrossBoundingRect(QPainter &painter)
 {
-		//No need to calcul if nothing is linked
+	//No need to calcul if nothing is linked
 	if (m_element->isFree()) return;
 
 	QStringList no_str, nc_str;
 
-	foreach (Element *elmt, NOElements())
+	for (auto elmt : NOElements()) {
 		no_str.append(elementPositionText(elmt, true));
-	foreach(Element *elmt, NCElements())
+	}
+	for (auto elmt : NCElements()) {
 		nc_str.append(elementPositionText(elmt, true));
+	}
 
-
-		//There is no string to display, we return now
+	//There is no string to display, we return now
 	if (no_str.isEmpty() && nc_str.isEmpty()) return;
 
-		//this is the default size of cross ref item
+	//this is the default size of cross ref item
 	QRectF default_bounding(0, 0, 40, header + cross_min_heigth);
 
-		//Bounding rect of the NO text
+	//Bounding rect of the NO text
 	QRectF no_bounding;
-	foreach(QString str, no_str)
+	for (auto str : no_str)
 	{
 		QRectF bounding = painter.boundingRect(QRectF (), Qt::AlignCenter, str);
 		no_bounding = no_bounding.united(bounding);
+		no_bounding.setHeight(no_bounding.height() + bounding.height());
 	}
-		//Adjust according to the NO
+	//Adjust according to the NO
 	if (no_bounding.height() > default_bounding.height() - header)
 		default_bounding.setHeight(no_bounding.height() + header); //adjust the height
 	if (no_bounding.width() > default_bounding.width()/2)
-		default_bounding.setWidth(no_bounding.width()*2);			//adjust the width
+		default_bounding.setWidth(no_bounding.width()*2);//adjust the width
 
-		//Bounding rect of the NC text
+	//Bounding rect of the NC text
 	QRectF nc_bounding;
-	foreach(QString str, nc_str)
+	for (auto str : nc_str)
 	{
 		QRectF bounding = painter.boundingRect(QRectF (), Qt::AlignCenter, str);
 		nc_bounding = nc_bounding.united(bounding);
+		nc_bounding.setHeight(nc_bounding.height() + bounding.height());
 	}
-		//Adjust according to the NC
+	//Adjust according to the NC
 	if (nc_bounding.height() > default_bounding.height() - header)
 		default_bounding.setHeight(nc_bounding.height() + header); //adjust the heigth
 	if (nc_bounding.width() > default_bounding.width()/2)
-		default_bounding.setWidth(nc_bounding.width()*2);			//adjust the width
+		default_bounding.setWidth(nc_bounding.width()*2);//adjust the width
 
-		//Minor adjustement for better visual
+	//Minor adjustement for better visual
 	default_bounding.adjust(0, 0, 4, 0);
 	m_shape_path.addRect(default_bounding);
 	prepareGeometryChange();
@@ -491,40 +553,40 @@ void CrossRefItem::setUpCrossBoundingRect(QPainter &painter)
 }
 
 /**
- * @brief CrossRefItem::drawAsCross
- * Draw this crossref with a cross
- * @param painter, painter to use
- */
+	@brief CrossRefItem::drawAsCross
+	Draw this crossref with a cross
+	@param painter: painter to use
+*/
 void CrossRefItem::drawAsCross(QPainter &painter)
 {
-		//calcul the size of the cross
+	//calcul the size of the cross
 	setUpCrossBoundingRect(painter);
 	m_hovered_contacts_map.clear();
 
-		//Bounding rect is empty that mean there's no contact to draw
+	//Bounding rect is empty that mean there's no contact to draw
 	if (boundingRect().isEmpty()) return;
 
-		//draw the cross
+	//draw the cross
 	QRectF br = boundingRect();
 	painter.drawLine(br.width()/2, 0, br.width()/2, br.height());	//vertical line
 	painter.drawLine(0, header, br.width(), header);	//horizontal line
 
-		//Add the symbolic contacts
+	//Add the symbolic contacts
 	buildHeaderContact();
 	QPointF p((m_bounding_rect.width()/4) - (m_hdr_no_ctc.width()/2), 0);
 	painter.drawPicture (p, m_hdr_no_ctc);
 	p.setX((m_bounding_rect.width() * 3/4) - (m_hdr_nc_ctc.width()/2));
 	painter.drawPicture (p, m_hdr_nc_ctc);
 
-		//and fill it
+	//and fill it
 	fillCrossRef(painter);
 }
 
 /**
- * @brief CrossRefItem::drawAsContacts
- * Draw this crossref with symbolic contacts
- * @param painter painter to use
- */
+	@brief CrossRefItem::drawAsContacts
+	Draw this crossref with symbolic contacts
+	@param painter painter to use
+*/
 void CrossRefItem::drawAsContacts(QPainter &painter)
 {
 	if (m_element -> isFree())
@@ -566,13 +628,13 @@ void CrossRefItem::drawAsContacts(QPainter &painter)
 }
 
 /**
- * @brief CrossRefItem::drawContact
- * Draw one contact, the type of contact to draw is define in @flags.
- * @param painter, painter to use
- * @param flags, define how to draw the contact (see enul CONTACTS)
- * @param elmt, the element to display text (the position of the contact)
- * @return The bounding rect of the draw (contact + text)
- */
+	@brief CrossRefItem::drawContact
+	Draw one contact, the type of contact to draw is define in flags.
+	@param painter : painter to use
+	@param flags : define how to draw the contact (see enul CONTACTS)
+	@param elmt : the element to display text (the position of the contact)
+	@return The bounding rect of the draw (contact + text)
+*/
 QRectF CrossRefItem::drawContact(QPainter &painter, int flags, Element *elmt)
 {
 	QString str = elementPositionText(elmt);
@@ -631,27 +693,27 @@ QRectF CrossRefItem::drawContact(QPainter &painter, int flags, Element *elmt)
 				// for delay on contact
 			if (flags &DelayOn) {
 				if (flags &NO) {
-                    painter.drawLine(12, offset+8, 12, offset+11);
-                    QRectF r(9.5, offset+9, 5, 3);
-                    painter.drawArc(r, 180*16, 180*16);
+					painter.drawLine(12, offset+8, 12, offset+11);
+					QRectF r(9.5, offset+9, 5, 3);
+					painter.drawArc(r, 180*16, 180*16);
 				}
-                if (flags &NC) {
-                    painter.drawLine(QPointF(12.5, offset+5), QPointF(12.5, offset+8));
-                    QRectF r(10, offset+6, 5, 3);
-                    painter.drawArc(r, 180*16, 180*16);
+				if (flags &NC) {
+					painter.drawLine(QPointF(12.5, offset+5), QPointF(12.5, offset+8));
+					QRectF r(10, offset+6, 5, 3);
+					painter.drawArc(r, 180*16, 180*16);
 				}
 			}
-				// for delay off contact
+			// for delay off contact
 			else if ( flags &DelayOff){
 				if (flags &NO) {
-                    painter.drawLine(12, offset+8, 12, offset+9.5);
-                    QRectF r(9.5, offset+9.5, 5, 3);
-                    painter.drawArc(r, 0, 180*16);
-                }
+					painter.drawLine(12, offset+8, 12, offset+9.5);
+					QRectF r(9.5, offset+9.5, 5, 3);
+					painter.drawArc(r, 0, 180*16);
+				}
 				if (flags &NC) {
-                    painter.drawLine(QPointF(12.5, offset+5), QPointF(12.5, offset+7));
-                    QRectF r(10, offset+7.5, 5, 3);
-                    painter.drawArc(r, 0, 180*16);
+					painter.drawLine(QPointF(12.5, offset+5), QPointF(12.5, offset+7));
+					QRectF r(10, offset+7.5, 5, 3);
+					painter.drawArc(r, 0, 180*16);
 				}
 
 			}
@@ -680,7 +742,7 @@ QRectF CrossRefItem::drawContact(QPainter &painter, int flags, Element *elmt)
 
 		if (m_hovered_contacts_map.contains(elmt))
 		{
-			m_hovered_contacts_map.insertMulti(elmt, bounding_rect);
+			m_hovered_contacts_map.insert(elmt, bounding_rect);
 		}
 		else
 		{
@@ -734,12 +796,17 @@ QRectF CrossRefItem::drawContact(QPainter &painter, int flags, Element *elmt)
 		}
 
 			//Draw position text
-		QRectF text_rect = painter.boundingRect(QRectF(30, offset+5, 5, 10), Qt::AlignLeft | Qt::AlignVCenter, str);
-		painter.drawText(text_rect, Qt::AlignLeft | Qt::AlignVCenter, str);
+		QRectF text_rect = painter.boundingRect(
+					QRectF(30, offset+5, 5, 10),
+					Qt::AlignLeft | Qt::AlignVCenter,
+					str);
+		painter.drawText(text_rect,
+				 Qt::AlignLeft | Qt::AlignVCenter,
+				 str);
 		bounding_rect = bounding_rect.united(text_rect);
 
 		if (m_hovered_contacts_map.contains(elmt)) {
-			m_hovered_contacts_map.insertMulti(elmt, bounding_rect);
+			m_hovered_contacts_map.insert(elmt, bounding_rect);
 		}
 		else {
 			m_hovered_contacts_map.insert(elmt, bounding_rect);
@@ -753,10 +820,10 @@ QRectF CrossRefItem::drawContact(QPainter &painter, int flags, Element *elmt)
 }
 
 /**
- * @brief CrossRefItem::fillCrossRef
- * Fill the content of the cross ref
- * @param painter painter to use.
- */
+	@brief CrossRefItem::fillCrossRef
+	Fill the content of the cross ref
+	@param painter painter to use.
+*/
 void CrossRefItem::fillCrossRef(QPainter &painter)
 {
 	if (m_element->isFree()) return;
@@ -772,12 +839,16 @@ void CrossRefItem::fillCrossRef(QPainter &painter)
 		painter.setPen(pen);
 
 		QString str = elementPositionText(elmt, true);
-		QRectF bounding = painter.boundingRect(QRectF(no_top_left, QSize(middle_cross, 1)), Qt::AlignLeft, str);
+		QRectF bounding = painter.boundingRect(
+					QRectF(no_top_left,
+					       QSize(middle_cross, 1)),
+					Qt::AlignLeft,
+					str);
 		painter.drawText(bounding, Qt::AlignLeft, str);
 
 		if (m_hovered_contacts_map.contains(elmt))
 		{
-			m_hovered_contacts_map.insertMulti(elmt, bounding);
+			m_hovered_contacts_map.insert(elmt, bounding);
 		}
 		else
 		{
@@ -792,16 +863,21 @@ void CrossRefItem::fillCrossRef(QPainter &painter)
 	foreach(Element *elmt, NCElements())
 	{
 		QPen pen = painter.pen();
-		m_hovered_contact == elmt ? pen.setColor(Qt::blue) :pen.setColor(Qt::black);
+		m_hovered_contact == elmt ? pen.setColor(Qt::blue)
+					  :pen.setColor(Qt::black);
 		painter.setPen(pen);
 
 		QString str = elementPositionText(elmt, true);
-		QRectF bounding = painter.boundingRect(QRectF(nc_top_left, QSize(middle_cross, 1)), Qt::AlignRight, str);
+		QRectF bounding = painter.boundingRect(
+					QRectF(nc_top_left,
+					       QSize(middle_cross, 1)),
+					Qt::AlignRight,
+					str);
 		painter.drawText(bounding, Qt::AlignRight, str);
 
 		if (m_hovered_contacts_map.contains(elmt))
 		{
-			m_hovered_contacts_map.insertMulti(elmt, bounding);
+			m_hovered_contacts_map.insert(elmt, bounding);
 		}
 		else
 		{
@@ -813,14 +889,18 @@ void CrossRefItem::fillCrossRef(QPainter &painter)
 }
 
 /**
- * @brief CrossRefItem::AddExtraInfo
- * Add the comment info of the parent item if needed.
- * @param painter painter to use for draw the text
- * @param type type of Info do be draw e.g. comment, location.
- */
+	@brief CrossRefItem::AddExtraInfo
+	Add the comment info of the parent item if needed.
+	@param painter painter to use for draw the text
+	@param type type of Info do be draw e.g. comment, location.
+*/
 void CrossRefItem::AddExtraInfo(QPainter &painter, const QString& type)
 {
-	QString text = autonum::AssignVariables::formulaToLabel(m_element -> elementInformations()[type].toString(), m_element->rSequenceStruct(), m_element->diagram(), m_element);
+	QString text = autonum::AssignVariables::formulaToLabel(
+				m_element->elementInformations()[type].toString(),
+				m_element->rSequenceStruct(),
+				m_element->diagram(),
+				m_element);
 	bool must_show  = m_element -> elementInformations().keyMustShow(type);
 
 	if (!text.isEmpty() && must_show)
@@ -830,38 +910,51 @@ void CrossRefItem::AddExtraInfo(QPainter &painter, const QString& type)
 
 		QRectF r, text_bounding;
 		qreal center = boundingRect().center().x();
-		qreal width = boundingRect().width() > 70 ? boundingRect().width()/2 : 35;
+		qreal width = boundingRect().width() > 70
+				? boundingRect().width()/2
+				: 35;
 
-		r = QRectF(QPointF(center - width, boundingRect().bottom()),
-				   QPointF(center + width, boundingRect().bottom() + 1));
+		r = QRectF(QPointF(center - width,
+				   boundingRect().bottom()),
+				   QPointF(center + width,
+					   boundingRect().bottom() + 1));
 
-		text_bounding = painter.boundingRect(r, Qt::TextWordWrap | Qt::AlignHCenter, text);
-		painter.drawText(text_bounding, Qt::TextWordWrap | Qt::AlignHCenter, text);
+		text_bounding = painter.boundingRect(
+					r,
+					Qt::TextWordWrap | Qt::AlignHCenter,
+					text);
+		painter.drawText(text_bounding,
+				 Qt::TextWordWrap | Qt::AlignHCenter,
+				 text);
 
 		text_bounding.adjust(-1,0,1,0); //adjust only for better visual
 
 		m_shape_path.addRect(text_bounding);
 		prepareGeometryChange();
 		m_bounding_rect = m_bounding_rect.united(text_bounding);
-		if (type == "comment") painter.drawRoundedRect(text_bounding, 2, 2);
+		if (type == "comment") painter.drawRoundedRect(text_bounding,
+							       2,
+							       2);
 		painter.restore();
 	}
 }
 
 /**
- * @brief CrossRefItem::NOElements
- * @return The linked elements of @m_element wich are open or switch contact.
- * If linked element is a power contact, xref propertie is set to don't show power contact
- * and this cross item must be drawed as cross, the element is not append in the list.
- */
+	@brief CrossRefItem::NOElements
+	@return The linked elements of m_element wich are open or switch contact.
+	If linked element is a power contact,
+	xref propertie is set to don't show power contact
+	and this cross item must be drawed as cross,
+	the element is not append in the list.
+*/
 QList<Element *> CrossRefItem::NOElements() const
 {
 	QList<Element *> no_list;
 
 	foreach (Element *elmt, m_element->linkedElements())
 	{
-			//We continue if element is a power contact and xref propertie
-			//is set to don't show power contact
+		//We continue if element is a power contact and xref propertie
+		//is set to don't show power contact
 		if (m_properties.displayHas() == XRefProperties::Cross &&
 			!m_properties.showPowerContact() &&
 			elmt -> kindInformations()["type"].toString() == "power")
@@ -879,19 +972,22 @@ QList<Element *> CrossRefItem::NOElements() const
 }
 
 /**
- * @brief CrossRefItem::NCElements
- * @return The linked elements of @m_element wich are close or switch contact
- * If linked element is a power contact, xref propertie is set to don't show power contact
- * and this cross item must be drawed as cross, the element is not append in the list.
- */
+	@brief CrossRefItem::NCElements
+	@return The linked elements of m_element wich are close
+	or switch contact
+	If linked element is a power contact,
+	xref propertie is set to don't show power contact
+	and this cross item must be drawed as cross,
+	the element is not append in the list.
+*/
 QList<Element *> CrossRefItem::NCElements() const
 {
 	QList<Element *> nc_list;
 
 	foreach (Element *elmt, m_element->linkedElements())
 	{
-			//We continue if element is a power contact and xref propertie
-			//is set to don't show power contact
+		//We continue if element is a power contact and xref propertie
+		//is set to don't show power contact
 		if (m_properties.displayHas() == XRefProperties::Cross &&
 			!m_properties.showPowerContact() &&
 			elmt -> kindInformations()["type"].toString() == "power")
