@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -16,50 +16,63 @@
 	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "elementtextitemgroup.h"
+
+#include "../QPropertyUndoCommand/qpropertyundocommand.h"
+#include "../diagram.h"
+#include "../qetapp.h"
+#include "../undocommand/addelementtextcommand.h"
+#include "crossrefitem.h"
 #include "dynamicelementtextitem.h"
 #include "element.h"
-#include "diagram.h"
-#include "addelementtextcommand.h"
-#include "QPropertyUndoCommand/qpropertyundocommand.h"
-#include "crossrefitem.h"
-#include "qetapp.h"
 #include "masterelement.h"
 #include "qgraphicsitemutility.h"
 
-#include <QPainter>
 #include <QGraphicsSceneMouseEvent>
+#include <QPainter>
 #include <utility>
 
+/**
+	@brief sorting
+	@param qgia
+	@param qgib
+	@return
+*/
 bool sorting(QGraphicsItem *qgia, QGraphicsItem *qgib)
 {
 	return qgia->pos().y() < qgib->pos().y();
 }
 
 /**
- * @brief ElementTextItemGroup::ElementTextItemGroup
- * @param parent
- */
-ElementTextItemGroup::ElementTextItemGroup(const QString &name, Element *parent) :
+	@brief ElementTextItemGroup::ElementTextItemGroup
+	@param name :
+	@param parent :
+*/
+ElementTextItemGroup::ElementTextItemGroup(const QString &name,
+					   Element *parent) :
 	QGraphicsItemGroup(parent),
 	m_name(name),
 	m_parent_element(parent)
 {
-	setFlags(QGraphicsItem::ItemIsSelectable | QGraphicsItem::ItemIsMovable);
-	connect(parent, &Element::linkedElementChanged, this, &ElementTextItemGroup::updateXref);
+	setFlags(QGraphicsItem::ItemIsSelectable
+		 | QGraphicsItem::ItemIsMovable);
+	connect(parent,
+		&Element::linkedElementChanged,
+		this,
+		&ElementTextItemGroup::updateXref);
 }
 
 ElementTextItemGroup::~ElementTextItemGroup()
 {}
 
 /**
- * @brief ElementTextItemGroup::addToGroup
- * @param item
- */
+	@brief ElementTextItemGroup::addToGroup
+	@param item
+*/
 void ElementTextItemGroup::addToGroup(QGraphicsItem *item)
 {
 	if(item->type() == DynamicElementTextItem::Type)
 	{
-			//Befor add text to this group we must to set the text at the same rotation of this group		
+		//Befor add text to this group we must to set the text at the same rotation of this group
 		if((item->rotation() != rotation()) && !m_block_alignment_update)
 			item->setRotation(rotation());
 		
@@ -67,30 +80,42 @@ void ElementTextItemGroup::addToGroup(QGraphicsItem *item)
 		updateAlignment();
 		
 		DynamicElementTextItem *deti = qgraphicsitem_cast<DynamicElementTextItem *>(item);
-		connect(deti, &DynamicElementTextItem::fontChanged,      this, &ElementTextItemGroup::updateAlignment);
-		connect(deti, &DynamicElementTextItem::textChanged,          this, &ElementTextItemGroup::updateAlignment);
-		connect(deti, &DynamicElementTextItem::textFromChanged,      this, &ElementTextItemGroup::updateAlignment);
-		connect(deti, &DynamicElementTextItem::infoNameChanged,      this, &ElementTextItemGroup::updateAlignment);
-		connect(deti, &DynamicElementTextItem::compositeTextChanged, this, &ElementTextItemGroup::updateAlignment);
-		connect(deti, &DynamicElementTextItem::plainTextChanged,     this, &ElementTextItemGroup::updateAlignment);
-		connect(deti, &DynamicElementTextItem::textWidthChanged,     this, &ElementTextItemGroup::updateAlignment);
+		connect(deti, &DynamicElementTextItem::fontChanged,
+			this, &ElementTextItemGroup::updateAlignment);
+		connect(deti, &DynamicElementTextItem::textChanged,
+			this, &ElementTextItemGroup::updateAlignment);
+		connect(deti, &DynamicElementTextItem::textFromChanged,
+			this, &ElementTextItemGroup::updateAlignment);
+		connect(deti, &DynamicElementTextItem::infoNameChanged,
+			this, &ElementTextItemGroup::updateAlignment);
+		connect(deti, &DynamicElementTextItem::compositeTextChanged,
+			this, &ElementTextItemGroup::updateAlignment);
+		connect(deti, &DynamicElementTextItem::plainTextChanged,
+			this, &ElementTextItemGroup::updateAlignment);
+		connect(deti, &DynamicElementTextItem::textWidthChanged,
+			this, &ElementTextItemGroup::updateAlignment);
 		
-		connect(deti, &DynamicElementTextItem::textFromChanged, this, &ElementTextItemGroup::updateXref);
-		connect(deti, &DynamicElementTextItem::infoNameChanged, this, &ElementTextItemGroup::updateXref);
+		connect(deti, &DynamicElementTextItem::textFromChanged,
+			this, &ElementTextItemGroup::updateXref);
+		connect(deti, &DynamicElementTextItem::infoNameChanged,
+			this, &ElementTextItemGroup::updateXref);
 		
 		updateXref();
 	}
 }
 
 /**
- * @brief ElementTextItemGroup::removeFromGroup
- * @param item
- */
+	@brief ElementTextItemGroup::removeFromGroup
+	@param item
+*/
 void ElementTextItemGroup::removeFromGroup(QGraphicsItem *item)
 {
 	QGraphicsItemGroup::removeFromGroup(item);
-		//the item transformation is not reseted, we must to do it, because for exemple if the group rotation is 45°
-		//When item is removed from group, visually the item is unchanged (so 45°) but if we call item->rotation() the returned value is 0.
+	//the item transformation is not reseted, we must to do it,
+	// because for exemple if the group rotation is 45°
+	//When item is removed from group,
+	// visually the item is unchanged (so 45°)
+	// but if we call item->rotation() the returned value is 0.
 	item->resetTransform();
 	item->setRotation(this->rotation());
 	item->setFlag(QGraphicsItem::ItemIsSelectable, true);
@@ -98,37 +123,46 @@ void ElementTextItemGroup::removeFromGroup(QGraphicsItem *item)
 	
 	if(DynamicElementTextItem *deti = qgraphicsitem_cast<DynamicElementTextItem *>(item))
 	{
-		disconnect(deti, &DynamicElementTextItem::fontChanged,      this, &ElementTextItemGroup::updateAlignment);
-		disconnect(deti, &DynamicElementTextItem::textChanged,          this, &ElementTextItemGroup::updateAlignment);
-		disconnect(deti, &DynamicElementTextItem::textFromChanged,      this, &ElementTextItemGroup::updateAlignment);
-		disconnect(deti, &DynamicElementTextItem::infoNameChanged,      this, &ElementTextItemGroup::updateAlignment);
-		disconnect(deti, &DynamicElementTextItem::compositeTextChanged, this, &ElementTextItemGroup::updateAlignment);
-		disconnect(deti, &DynamicElementTextItem::plainTextChanged,     this, &ElementTextItemGroup::updateAlignment);
-		disconnect(deti, &DynamicElementTextItem::textWidthChanged,     this, &ElementTextItemGroup::updateAlignment);
+		disconnect(deti, &DynamicElementTextItem::fontChanged,
+			   this, &ElementTextItemGroup::updateAlignment);
+		disconnect(deti, &DynamicElementTextItem::textChanged,
+			   this, &ElementTextItemGroup::updateAlignment);
+		disconnect(deti, &DynamicElementTextItem::textFromChanged,
+			   this, &ElementTextItemGroup::updateAlignment);
+		disconnect(deti, &DynamicElementTextItem::infoNameChanged,
+			   this, &ElementTextItemGroup::updateAlignment);
+		disconnect(deti, &DynamicElementTextItem::compositeTextChanged,
+			   this, &ElementTextItemGroup::updateAlignment);
+		disconnect(deti, &DynamicElementTextItem::plainTextChanged,
+			   this, &ElementTextItemGroup::updateAlignment);
+		disconnect(deti, &DynamicElementTextItem::textWidthChanged,
+			   this, &ElementTextItemGroup::updateAlignment);
 		
-		disconnect(deti, &DynamicElementTextItem::textFromChanged, this, &ElementTextItemGroup::updateXref);
-		disconnect(deti, &DynamicElementTextItem::infoNameChanged, this, &ElementTextItemGroup::updateXref);
+		disconnect(deti, &DynamicElementTextItem::textFromChanged,
+			   this, &ElementTextItemGroup::updateXref);
+		disconnect(deti, &DynamicElementTextItem::infoNameChanged,
+			   this, &ElementTextItemGroup::updateXref);
 		
 		updateXref();
 	}
 }
 
 /**
- * @brief ElementTextItemGroup::blockAlignmentUpdate
- * If true, the texts in this group are never aligned, moved, rotated etc...
- * the texts stay as it was, until blockAlignmentUpdate is set to false.
- * @param block
- */
+	@brief ElementTextItemGroup::blockAlignmentUpdate
+	If true, the texts in this group are never aligned, moved, rotated etc...
+	the texts stay as it was, until blockAlignmentUpdate is set to false.
+	@param block
+*/
 void ElementTextItemGroup::blockAlignmentUpdate(bool block)
 {
 	m_block_alignment_update = block;
 }
 
 /**
- * @brief ElementTextItemGroup::setAlignement
- * Set the alignement of this group
- * @param alignement
- */
+	@brief ElementTextItemGroup::setAlignement
+	Set the alignement of this group
+	@param alignement
+*/
 void ElementTextItemGroup::setAlignment(Qt::Alignment alignement)
 {
 	m_alignment = alignement;
@@ -142,11 +176,11 @@ Qt::Alignment ElementTextItemGroup::alignment() const
 }
 
 /**
- * @brief ElementTextItemGroup::setAlignment
- * Update the alignement of the items in this group, according
- * to the current alignement.
- * @param alignement
- */
+	@brief ElementTextItemGroup::setAlignment
+	Update the alignement of the items in this group, according
+	to the current alignement.
+	@param alignement
+*/
 void ElementTextItemGroup::updateAlignment()
 {
 	if(m_block_alignment_update)
@@ -235,11 +269,12 @@ void ElementTextItemGroup::updateAlignment()
 }
 
 /**
- * @brief ElementTextItemGroup::setVerticalAdjustment
- * Set the value of the vertical adjustment to @v.
- * The vertical adjutment is use to adjust the space between the texts of this group.
- * @param v
- */
+	@brief ElementTextItemGroup::setVerticalAdjustment
+	Set the value of the vertical adjustment to v.
+	The vertical adjutment is use to adjust
+	the space between the texts of this group.
+	@param v
+*/
 void ElementTextItemGroup::setVerticalAdjustment(int v)
 {
 	prepareGeometryChange();
@@ -249,9 +284,9 @@ void ElementTextItemGroup::setVerticalAdjustment(int v)
 }
 
 /**
- * @brief ElementTextItemGroup::setName
- * @param name Set the name of this group
- */
+	@brief ElementTextItemGroup::setName
+	@param name Set the name of this group
+*/
 void ElementTextItemGroup::setName(QString name)
 {
 	m_name = std::move(name);
@@ -272,13 +307,28 @@ void ElementTextItemGroup::setHoldToBottomPage(bool hold)
 		connect(m_parent_element, &Element::rotationChanged, this, &ElementTextItemGroup::autoPos);
 		if(m_parent_element->linkType() == Element::Master)
 		{
-				//We use timer to let the time of the parent element xref to be updated, befor update the position of this group
-				//because the position of this group is related to the size of the parent element Xref
-			m_linked_changed_timer = connect(m_parent_element, &Element::linkedElementChanged,
-											 [this]() {QTimer::singleShot(200, this, &ElementTextItemGroup::autoPos);});
+			//We use timer to let the time of the parent element
+			// xref to be updated,
+			// befor update the position of this group
+			//because the position of this group is related
+			// to the size of the parent element Xref
+			m_linked_changed_timer = connect(
+						m_parent_element,
+						&Element::linkedElementChanged,
+						[this]()
+			{QTimer::singleShot(200,
+					    this,
+					    &ElementTextItemGroup::autoPos);}
+			);
 			if(m_parent_element->diagram())
-				m_XrefChanged_timer = connect(m_parent_element->diagram()->project(), &QETProject::XRefPropertiesChanged,
-											  [this]()	{QTimer::singleShot(200, this, &ElementTextItemGroup::autoPos);});
+				m_XrefChanged_timer = connect(
+							m_parent_element->diagram()->project(),
+							&QETProject::XRefPropertiesChanged,
+							[this]()
+				{QTimer::singleShot(200,
+						    this,
+						    &ElementTextItemGroup::autoPos);}
+				);
 		}
 		autoPos();
 	}
@@ -286,8 +336,10 @@ void ElementTextItemGroup::setHoldToBottomPage(bool hold)
 	{
 		setFlag(QGraphicsItem::ItemIsSelectable, true);
 		setFlag(QGraphicsItem::ItemIsMovable, true);
-		disconnect(m_parent_element, &Element::yChanged, this, &ElementTextItemGroup::autoPos);
-		disconnect(m_parent_element, &Element::rotationChanged, this, &ElementTextItemGroup::autoPos);
+		disconnect(m_parent_element, &Element::yChanged,
+			   this, &ElementTextItemGroup::autoPos);
+		disconnect(m_parent_element, &Element::rotationChanged,
+			   this, &ElementTextItemGroup::autoPos);
 		if(m_parent_element->linkType() == Element::Master)
 		{
 			disconnect(m_linked_changed_timer);
@@ -306,14 +358,15 @@ void ElementTextItemGroup::setFrame(const bool frame)
 	emit frameChanged(m_frame);
 }
 
-bool ElementTextItemGroup::frame() const {
+bool ElementTextItemGroup::frame() const
+{
 	return m_frame;
 }
 
 /**
- * @brief ElementTextItemGroup::texts
- * @return Every texts in this group
- */
+	@brief ElementTextItemGroup::texts
+	@return Every texts in this group
+*/
 QList<DynamicElementTextItem *> ElementTextItemGroup::texts() const
 {
 	QList<DynamicElementTextItem *> list;
@@ -326,9 +379,9 @@ QList<DynamicElementTextItem *> ElementTextItemGroup::texts() const
 }
 
 /**
- * @brief ElementTextItemGroup::diagram
- * @return The diagram of this group, or nullptr if this group is not in a diagram
- */
+	@brief ElementTextItemGroup::diagram
+	@return The diagram of this group, or nullptr if this group is not in a diagram
+*/
 Diagram *ElementTextItemGroup::diagram() const
 {
 	if(scene())
@@ -338,9 +391,9 @@ Diagram *ElementTextItemGroup::diagram() const
 }
 
 /**
- * @brief ElementTextItemGroup::parentElement
- * @return The parent element of this group or nullptr
- */
+	@brief ElementTextItemGroup::parentElement
+	@return The parent element of this group or nullptr
+*/
 Element *ElementTextItemGroup::parentElement() const
 {
 	if(parentItem() && parentItem()->type() == Element::Type)
@@ -350,11 +403,11 @@ Element *ElementTextItemGroup::parentElement() const
 }
 
 /**
- * @brief ElementTextItemGroup::toXml
- * Export data of this group to xml
- * @param dom_document
- * @return 
- */
+	@brief ElementTextItemGroup::toXml
+	Export data of this group to xml
+	@param dom_document
+	@return 
+*/
 QDomElement ElementTextItemGroup::toXml(QDomDocument &dom_document) const
 {
 	QDomElement dom_element = dom_document.createElement(this->xmlTaggName());
@@ -370,7 +423,8 @@ QDomElement ElementTextItemGroup::toXml(QDomDocument &dom_document) const
 	dom_element.setAttribute("vertical_adjustment", m_vertical_adjustment);
 	dom_element.setAttribute("frame", m_frame? "true" : "false");
 	
-	dom_element.setAttribute("hold_to_bottom_page", m_hold_to_bottom_of_page == true ? "true" : "false");
+	dom_element.setAttribute("hold_to_bottom_page",
+				 m_hold_to_bottom_of_page == true ? "true" : "false");
 	
 	QDomElement dom_texts = dom_document.createElement("texts");
 	for(DynamicElementTextItem *deti : texts())
@@ -385,10 +439,10 @@ QDomElement ElementTextItemGroup::toXml(QDomDocument &dom_document) const
 }
 
 /**
- * @brief ElementTextItemGroup::fromXml
- * Import data of this group from xml
- * @param dom_element
- */
+	@brief ElementTextItemGroup::fromXml
+	Import data of this group from xml
+	@param dom_element
+*/
 void ElementTextItemGroup::fromXml(QDomElement &dom_element)
 {
 	if (dom_element.tagName() != xmlTaggName()) {
@@ -398,8 +452,17 @@ void ElementTextItemGroup::fromXml(QDomElement &dom_element)
 	
 	setName(dom_element.attribute("name", "no name"));
 	QMetaEnum me = QMetaEnum::fromType<Qt::Alignment>();
-	setAlignment(Qt::Alignment(me.keyToValue(dom_element.attribute("alignment").toStdString().data())));
-	
+	setAlignment(
+				Qt::Alignment(
+					me.keyToValue(
+						dom_element.attribute(
+							"alignment")
+						.toStdString()
+						.data()
+						)
+					)
+				);
+
 	setPos(dom_element.attribute("x", QString::number(0)).toDouble(),
 		   dom_element.attribute("y", QString::number(0)).toDouble());
 	
@@ -430,12 +493,15 @@ void ElementTextItemGroup::fromXml(QDomElement &dom_element)
 }
 
 /**
- * @brief ElementTextItemGroup::paint
- * @param painter
- * @param option
- * @param widget
- */
-void ElementTextItemGroup::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
+	@brief ElementTextItemGroup::paint
+	@param painter
+	@param option
+	@param widget
+*/
+void ElementTextItemGroup::paint(
+		QPainter *painter,
+		const QStyleOptionGraphicsItem *option,
+		QWidget *widget)
 {
 	Q_UNUSED(option);
 	Q_UNUSED(widget);
@@ -447,7 +513,8 @@ void ElementTextItemGroup::paint(QPainter *painter, const QStyleOptionGraphicsIt
 		t.setStyle(Qt::DashDotLine);
 		t.setCosmetic(true);
 		painter->setPen(t);
-		painter->drawRoundRect(boundingRect().adjusted(1, 1, -1, -1), 10, 10);
+		painter->drawRoundedRect(boundingRect().adjusted(1, 1, -1, -1),
+					 10, 10);
 		
 		painter->restore();
 	}
@@ -484,20 +551,21 @@ void ElementTextItemGroup::paint(QPainter *painter, const QStyleOptionGraphicsIt
 }
 
 /**
- * @brief ElementTextItemGroup::boundingRect
- * @return 
- */
+	@brief ElementTextItemGroup::boundingRect
+	@return 
+*/
 QRectF ElementTextItemGroup::boundingRect() const
 {
-		//If we refer to the Qt doc, the bounding rect of a QGraphicsItemGroup,
-		//is the bounding of all childrens in the group
-		//When add an item in the group, the bounding rect is good, but
-		//if we move an item already in the group, the bounding rect of the group stay unchanged.
-		//We reimplement this function to avoid this behavior.
+	//If we refer to the Qt doc, the bounding rect of a QGraphicsItemGroup,
+	//is the bounding of all childrens in the group
+	//When add an item in the group, the bounding rect is good, but
+	//if we move an item already in the group, the bounding rect of the group stay unchanged.
+	//We reimplement this function to avoid this behavior.
 	QRectF rect;
 	for(QGraphicsItem *qgi : texts())
 	{		
-		QRectF r(qgi->pos(), QSize(qgi->boundingRect().width(), qgi->boundingRect().height()));
+		QRectF r(qgi->pos(), QSize(qgi->boundingRect().width(),
+					   qgi->boundingRect().height()));
 		rect = rect.united(r);
 	}
 	return rect;
@@ -530,9 +598,9 @@ void ElementTextItemGroup::setPos(qreal x, qreal y)
 }
 
 /**
- * @brief ElementTextItemGroup::mousePressEvent
- * @param event
- */
+	@brief ElementTextItemGroup::mousePressEvent
+	@param event
+*/
 void ElementTextItemGroup::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {	
 	if(event->button() == Qt::LeftButton)
@@ -546,15 +614,16 @@ void ElementTextItemGroup::mousePressEvent(QGraphicsSceneMouseEvent *event)
 }
 
 /**
- * @brief ElementTextItemGroup::mouseMoveEvent
- * @param event
- */
+	@brief ElementTextItemGroup::mouseMoveEvent
+	@param event
+*/
 void ElementTextItemGroup::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 {
 	if((event->buttons() & Qt::LeftButton) && (flags() & ItemIsMovable))
 	{
 		if(diagram() && m_first_move)
-			diagram()->elementTextsMover().beginMovement(diagram(), this);
+			diagram()->elementTextsMover().beginMovement(diagram(),
+								     this);
 		
 		if(m_first_move)
 		{
@@ -582,9 +651,9 @@ void ElementTextItemGroup::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 }
 
 /**
- * @brief ElementTextItemGroup::mouseReleaseEvent
- * @param event
- */
+	@brief ElementTextItemGroup::mouseReleaseEvent
+	@param event
+*/
 void ElementTextItemGroup::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
 	if(diagram())
@@ -598,7 +667,8 @@ void ElementTextItemGroup::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 		QGraphicsItemGroup::mouseReleaseEvent(event);
 }
 
-void ElementTextItemGroup::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
+void ElementTextItemGroup::mouseDoubleClickEvent(
+		QGraphicsSceneMouseEvent *event)
 {
 	if(m_slave_Xref_item)
 	{
@@ -631,9 +701,9 @@ void ElementTextItemGroup::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event
 }
 
 /**
- * @brief ElementTextItemGroup::keyPressEvent
- * @param event
- */
+	@brief ElementTextItemGroup::keyPressEvent
+	@param event
+*/
 void ElementTextItemGroup::keyPressEvent(QKeyEvent *event)
 {	
  	if(event->modifiers() == Qt::ControlModifier)
