@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -16,25 +16,26 @@
 	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "qetshapeitem.h"
-#include "createdxf.h"
-#include "diagram.h"
-#include "qet.h"
-#include "shapegraphicsitempropertieswidget.h"
-#include "PropertiesEditor/propertieseditordialog.h"
-#include "QPropertyUndoCommand/qpropertyundocommand.h"
-#include "QetGraphicsItemModeler/qetgraphicshandlerutility.h"
-#include "qetxml.h"
-#include "diagramview.h"
-#include "qeticons.h"
+
+#include "../PropertiesEditor/propertieseditordialog.h"
+#include "../QPropertyUndoCommand/qpropertyundocommand.h"
+#include "../QetGraphicsItemModeler/qetgraphicshandlerutility.h"
+#include "../createdxf.h"
+#include "../diagram.h"
+#include "../diagramview.h"
+#include "../qet.h"
+#include "../qeticons.h"
+#include "../qetxml.h"
+#include "../ui/shapegraphicsitempropertieswidget.h"
 
 /**
- * @brief QetShapeItem::QetShapeItem
- * Constructor of shape item. point 1 and 2 must be in scene coordinate
- * @param p1 first point
- * @param p2 second point
- * @param type type of item (line, rectangle, ellipse)
- * @param parent parent item
- */
+	@brief QetShapeItem::QetShapeItem
+	Constructor of shape item. point 1 and 2 must be in scene coordinate
+	@param p1 first point
+	@param p2 second point
+	@param type type of item (line, rectangle, ellipse)
+	@param parent parent item
+*/
 QetShapeItem::QetShapeItem(QPointF p1, QPointF p2, ShapeType type, QGraphicsItem *parent) :
 	QetGraphicsItem(parent),
 	m_shapeType(type),
@@ -52,7 +53,7 @@ QetShapeItem::QetShapeItem(QPointF p1, QPointF p2, ShapeType type, QGraphicsItem
 		for(QetGraphicsHandlerItem *qghi : m_handler_vector)
 			qghi->setZValue(this->zValue()+1);
 	});
-	
+
 	m_insert_point = new QAction(tr("Ajouter un point"), this);
 	m_insert_point->setIcon(QET::Icons::Add);
 	connect(m_insert_point, &QAction::triggered, this, &QetShapeItem::insertPoint);
@@ -64,15 +65,15 @@ QetShapeItem::QetShapeItem(QPointF p1, QPointF p2, ShapeType type, QGraphicsItem
 
 QetShapeItem::~QetShapeItem()
 {
-    if(!m_handler_vector.isEmpty())
-        qDeleteAll(m_handler_vector);
+	if(!m_handler_vector.isEmpty())
+		qDeleteAll(m_handler_vector);
 }
 
 /**
- * @brief QetShapeItem::setPen
- * Set the pen to use for draw the shape
- * @param pen
- */
+	@brief QetShapeItem::setPen
+	Set the pen to use for draw the shape
+	@param pen
+*/
 void QetShapeItem::setPen(const QPen &pen)
 {
 	if (m_pen == pen) return;
@@ -82,10 +83,10 @@ void QetShapeItem::setPen(const QPen &pen)
 }
 
 /**
- * @brief QetShapeItem::setBrush
- * Set the brush to use for the fill the shape
- * @param brush
- */
+	@brief QetShapeItem::setBrush
+	Set the brush to use for the fill the shape
+	@param brush
+*/
 void QetShapeItem::setBrush(const QBrush &brush)
 {
 	if (m_brush == brush) return;
@@ -95,12 +96,12 @@ void QetShapeItem::setBrush(const QBrush &brush)
 }
 
 /**
- * @brief QetShapeItem::setP2
- * Set the second point of this item.
- * If this item is a polyline,
- * the last point of the polyline is replaced by P2.
- * @param P2
- */
+	@brief QetShapeItem::setP2
+	Set the second point of this item.
+	If this item is a polyline,
+	the last point of the polyline is replaced by P2.
+	@param P2
+*/
 void QetShapeItem::setP2(const QPointF &P2)
 {
 	if (m_shapeType == Polygon && m_polygon.last() != P2)
@@ -116,11 +117,11 @@ void QetShapeItem::setP2(const QPointF &P2)
 }
 
 /**
- * @brief QetShapeItem::setLine
- * Set item geometry to line (only available for line shape)
- * @param line
- * @return  : true when shape is a Line, else false
- */
+	@brief QetShapeItem::setLine
+	Set item geometry to line (only available for line shape)
+	@param line
+	@return  : true when shape is a Line, else false
+*/
 bool QetShapeItem::setLine(const QLineF &line)
 {
 	if (Q_UNLIKELY(m_shapeType != Line)) return false;
@@ -132,11 +133,11 @@ bool QetShapeItem::setLine(const QLineF &line)
 }
 
 /**
- * @brief QetShapeItem::setRect
- * Set this item geometry to rect (only available if shape is a rectangle or an ellipse)
- * @param rect : new rect
- * @return  : true when shape is rectangle or ellipse, else false
- */
+	@brief QetShapeItem::setRect
+	Set this item geometry to rect (only available if shape is a rectangle or an ellipse)
+	@param rect : new rect
+	@return  : true when shape is rectangle or ellipse, else false
+*/
 bool QetShapeItem::setRect(const QRectF &rect)
 {
 	if (Q_LIKELY(m_shapeType == Rectangle || m_shapeType == Ellipse))
@@ -152,11 +153,11 @@ bool QetShapeItem::setRect(const QRectF &rect)
 }
 
 /**
- * @brief QetShapeItem::setPolygon
- * Set this item geometry to polygon (only available if shape is a polyline)
- * @param polygon : new polygon
- * @return true if item is polygon, else false
- */
+	@brief QetShapeItem::setPolygon
+	Set this item geometry to polygon (only available if shape is a polyline)
+	@param polygon : new polygon
+	@return true if item is polygon, else false
+*/
 bool QetShapeItem::setPolygon(const QPolygonF &polygon)
 {
 	if (Q_UNLIKELY(m_shapeType != Polygon)) {
@@ -169,10 +170,10 @@ bool QetShapeItem::setPolygon(const QPolygonF &polygon)
 }
 
 /**
- * @brief QetShapeItem::setClosed
- * Close this item, have effect only if this item is a polygon.
- * @param close
- */
+	@brief QetShapeItem::setClosed
+	Close this item, have effect only if this item is a polygon.
+	@param close
+*/
 void QetShapeItem::setClosed(bool close)
 {
 	if (m_shapeType == Polygon && close != m_closed)
@@ -200,18 +201,19 @@ void QetShapeItem::setYRadius(qreal Y)
 }
 
 /**
- * @brief QetShapeItem::pointCount
- * @return the number of point in the polygon
- */
-int QetShapeItem::pointsCount() const {
+	@brief QetShapeItem::pointCount
+	@return the number of point in the polygon
+*/
+int QetShapeItem::pointsCount() const
+{
 	return m_polygon.size();
 }
 
 /**
- * @brief QetShapeItem::setNextPoint
- * Add a new point to the curent polygon
- * @param P the new point.
- */
+	@brief QetShapeItem::setNextPoint
+	Add a new point to the curent polygon
+	@param P the new point.
+*/
 void QetShapeItem::setNextPoint(QPointF P)
 {
 	prepareGeometryChange();
@@ -219,11 +221,12 @@ void QetShapeItem::setNextPoint(QPointF P)
 }
 
 /**
- * @brief QetShapeItem::removePoints
- * Number of point to remove on the polygon
- * If @number is superior to number of polygon points-2,
- * all points of polygon will be removed except the first two (minimum point for the polygon);
- */
+	@brief QetShapeItem::removePoints
+	Number of point to remove on the polygon
+	If number is superior to number of polygon points-2,
+	all points of polygon will be removed except
+	the first two (minimum point for the polygon);
+*/
 void QetShapeItem::removePoints(int number)
 {
 	if (pointsCount() == 2 || number < 1) return;
@@ -242,29 +245,33 @@ void QetShapeItem::removePoints(int number)
 }
 
 /**
- * @brief QetShapeItem::boundingRect
- * @return the bounding rect of this item
- */
-QRectF QetShapeItem::boundingRect() const {
+	@brief QetShapeItem::boundingRect
+	@return the bounding rect of this item
+*/
+QRectF QetShapeItem::boundingRect() const
+{
 	return shape().boundingRect().adjusted(-6, -6, 6, 6);
 }
 
 /**
- * @brief QetShapeItem::shape
- * @return the shape of this item
- */
+	@brief QetShapeItem::shape
+	@return the shape of this item
+*/
 QPainterPath QetShapeItem::shape() const
 {
 	QPainterPath path;
 
 	switch (m_shapeType)
 	{
-		case Line:      
+		case Line:
 			path.moveTo(m_P1);
-			path.lineTo(m_P2);                   
+			path.lineTo(m_P2);
 			break;
-		case Rectangle: 
-			path.addRoundedRect(QRectF(m_P1, m_P2), m_xRadius, m_yRadius);
+		case Rectangle:
+			path.addRoundedRect(
+						QRectF(m_P1, m_P2),
+						m_xRadius,
+						m_yRadius);
 			break;
 		case Ellipse:
 			path.addEllipse(QRectF(m_P1, m_P2));
@@ -275,9 +282,6 @@ QPainterPath QetShapeItem::shape() const
 				path.closeSubpath();
 			}
 			break;
-		default:
-			Q_ASSERT(false);
-			break;
 	}
 
 	QPainterPathStroker pps;
@@ -289,15 +293,19 @@ QPainterPath QetShapeItem::shape() const
 }
 
 /**
- * @brief QetShapeItem::paint
- * Paint this item
- * @param painter
- * @param option
- * @param widget
- */
-void QetShapeItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
+	@brief QetShapeItem::paint
+	Paint this item
+	@param painter
+	@param option
+	@param widget
+*/
+void QetShapeItem::paint(
+		QPainter *painter,
+		const QStyleOptionGraphicsItem *option,
+		QWidget *widget)
 {
-	Q_UNUSED(option); Q_UNUSED(widget);
+	Q_UNUSED(option)
+	Q_UNUSED(widget)
 
 	painter->save();
 	painter->setRenderHint(QPainter::Antialiasing, true);
@@ -315,23 +323,26 @@ void QetShapeItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
 		painter -> drawPath (shape());
 		painter -> restore  ();
 	}
-	
-    switch (m_shapeType)
-    {
-        case Line:      painter->drawLine(QLineF(m_P1, m_P2)); break;
-        case Rectangle: painter->drawRoundedRect(QRectF(m_P1, m_P2), m_xRadius, m_yRadius); break;
-        case Ellipse:   painter->drawEllipse(QRectF(m_P1, m_P2)); break;
-        case Polygon:   m_closed ? painter->drawPolygon(m_polygon) : painter->drawPolyline(m_polygon); break;
-    }
-    
-    painter->restore();
+
+	switch (m_shapeType)
+	{
+	case Line:      painter->drawLine(QLineF(m_P1, m_P2)); break;
+	case Rectangle: painter->drawRoundedRect(QRectF(m_P1, m_P2),
+						 m_xRadius,
+						 m_yRadius); break;
+	case Ellipse:   painter->drawEllipse(QRectF(m_P1, m_P2)); break;
+	case Polygon:   m_closed ? painter->drawPolygon(m_polygon)
+				 : painter->drawPolyline(m_polygon); break;
+	}
+
+	painter->restore();
 }
 
 /**
- * @brief QetShapeItem::hoverEnterEvent
- * Handle hover enter event
- * @param event
- */
+	@brief QetShapeItem::hoverEnterEvent
+	Handle hover enter event
+	@param event
+*/
 void QetShapeItem::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
 {
 	m_hovered = true;
@@ -339,10 +350,10 @@ void QetShapeItem::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
 }
 
 /**
- * @brief QetShapeItem::hoverLeaveEvent
- * Handle hover leave event
- * @param event
- */
+	@brief QetShapeItem::hoverLeaveEvent
+	Handle hover leave event
+	@param event
+*/
 void QetShapeItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
 {
 	m_hovered = false;
@@ -353,7 +364,7 @@ void QetShapeItem::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
 	event->ignore();
 	QetGraphicsItem::mousePressEvent(event);
-	
+
 	if (event->button() == Qt::LeftButton) {
 		switchResizeMode();
 		event->accept();
@@ -361,31 +372,33 @@ void QetShapeItem::mousePressEvent(QGraphicsSceneMouseEvent *event)
 }
 
 /**
- * @brief QetShapeItem::itemChange
- * @param change
- * @param value
- * @return 
- */
-QVariant QetShapeItem::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant &value)
+	@brief QetShapeItem::itemChange
+	@param change
+	@param value
+	@return
+*/
+QVariant QetShapeItem::itemChange(QGraphicsItem::GraphicsItemChange change,
+				  const QVariant &value)
 {
-    if (change == ItemSelectedHasChanged)
-    {
-        if (value.toBool() == true) { //If this is selected, wa add handlers.
+	if (change == ItemSelectedHasChanged)
+	{
+		if (value.toBool() == true) {
+			//If this is selected, wa add handlers.
 			addHandler();
-        }
-        else //Else this is deselected, we remove handlers
-        {
-            if(!m_handler_vector.isEmpty())
-            {
-                qDeleteAll(m_handler_vector);
-                m_handler_vector.clear();
-            }
+		}
+		else //Else this is deselected, we remove handlers
+		{
+			if(!m_handler_vector.isEmpty())
+			{
+				qDeleteAll(m_handler_vector);
+				m_handler_vector.clear();
+			}
 			m_resize_mode = 1;
-        }
-    }
-    else if (change == ItemPositionHasChanged) {
+		}
+	}
+	else if (change == ItemPositionHasChanged) {
 		adjusteHandlerPos();
-    }
+	}
 	else if (change == ItemSceneHasChanged)
 	{
 		if (!scene()) //This is removed from scene, then we deselect this, and so, the handlers is also removed.
@@ -394,22 +407,22 @@ QVariant QetShapeItem::itemChange(QGraphicsItem::GraphicsItemChange change, cons
 		}
 	}
 
-    return QGraphicsItem::itemChange(change, value);
+	return QGraphicsItem::itemChange(change, value);
 }
 
 /**
- * @brief QetShapeItem::sceneEventFilter
- * @param watched
- * @param event
- * @return 
- */
+	@brief QetShapeItem::sceneEventFilter
+	@param watched
+	@param event
+	@return
+*/
 bool QetShapeItem::sceneEventFilter(QGraphicsItem *watched, QEvent *event)
 {
 		//Watched must be an handler
 	if(watched->type() == QetGraphicsHandlerItem::Type)
 	{
 		QetGraphicsHandlerItem *qghi = qgraphicsitem_cast<QetGraphicsHandlerItem *>(watched);
-		
+
 		if(m_handler_vector.contains(qghi)) //Handler must be in m_vector_index, then we can start resize
 		{
 			m_vector_index = m_handler_vector.indexOf(qghi);
@@ -417,40 +430,40 @@ bool QetShapeItem::sceneEventFilter(QGraphicsItem *watched, QEvent *event)
 			{
 				if(event->type() == QEvent::GraphicsSceneMousePress) //Click
 				{
-					handlerMousePressEvent(qghi, static_cast<QGraphicsSceneMouseEvent *>(event));
+					handlerMousePressEvent();
 					return true;
 				}
 				else if(event->type() == QEvent::GraphicsSceneMouseMove) //Move
 				{
-					handlerMouseMoveEvent(qghi, static_cast<QGraphicsSceneMouseEvent *>(event));
+					handlerMouseMoveEvent(static_cast<QGraphicsSceneMouseEvent *>(event));
 					return true;
 				}
 				else if (event->type() == QEvent::GraphicsSceneMouseRelease) //Release
 				{
-					handlerMouseReleaseEvent(qghi, static_cast<QGraphicsSceneMouseEvent *>(event));
+					handlerMouseReleaseEvent();
 					return true;
 				}
 			}
 		}
 	}
-	
+
 	return false;
 }
 
 /**
- * @brief QetShapeItem::contextMenuEvent
- * @param event
- */
+	@brief QetShapeItem::contextMenuEvent
+	@param event
+*/
 void QetShapeItem::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 {
 	m_context_menu_pos = event->pos();
-	
+
 	if (m_shapeType == QetShapeItem::Polygon)
 	{
 		if (diagram()->selectedItems().isEmpty()) {
 			this->setSelected(true);
 		}
-		
+
 		if (isSelected() && scene()->selectedItems().size() == 1)
 		{
 			if (diagram())
@@ -465,12 +478,12 @@ void QetShapeItem::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 							continue;
 					}
 				}
-				
+
 				if (d_view)
 				{
 					QScopedPointer<QMenu> menu(new QMenu());
 					menu.data()->addAction(m_insert_point);
-					
+
 					if (m_handler_vector.count() > 2)
 					{
 						for (QetGraphicsHandlerItem *qghi : m_handler_vector)
@@ -482,7 +495,7 @@ void QetShapeItem::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 							}
 						}
 					}
-					
+
 					menu.data()->addSeparator();
 					menu.data()->addActions(d_view->contextMenuActions());
 					menu.data()->exec(event->screenPos());
@@ -492,13 +505,13 @@ void QetShapeItem::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 			}
 		}
 	}
-	
+
 	QetGraphicsItem::contextMenuEvent(event);
 }
 
 /**
- * @brief QetShapeItem::switchResizeMode
- */
+	@brief QetShapeItem::switchResizeMode
+*/
 void QetShapeItem::switchResizeMode()
 {
 	if (m_shapeType == Ellipse)
@@ -545,7 +558,7 @@ void QetShapeItem::switchResizeMode()
 			for (QetGraphicsHandlerItem *qghi : m_handler_vector) {
 				qghi->setColor(Qt::blue);
 			}
-			
+
 		}
 	}
 }
@@ -575,11 +588,11 @@ void QetShapeItem::addHandler()
 				points_vector = m_polygon;
 				break;
 		}
-		
+
 		if(!points_vector.isEmpty() && scene())
 		{
 			m_handler_vector = QetGraphicsHandlerItem::handlerForPoint(mapToScene(points_vector));
-			
+
 			for(QetGraphicsHandlerItem *handler : m_handler_vector)
 			{
 				handler->setZValue(this->zValue()+1);
@@ -592,15 +605,15 @@ void QetShapeItem::addHandler()
 }
 
 /**
- * @brief QetShapeItem::adjusteHandlerPos
- * Adjust the position of the handler item
- */
+	@brief QetShapeItem::adjusteHandlerPos
+	Adjust the position of the handler item
+*/
 void QetShapeItem::adjusteHandlerPos()
 {
 	if (m_handler_vector.isEmpty()) {
 		return;
 	}
-	
+
 	QVector <QPointF> points_vector;
 	switch (m_shapeType)
 	{
@@ -626,7 +639,7 @@ void QetShapeItem::adjusteHandlerPos()
 			break;
 		}
 	}
-	
+
 	if (m_handler_vector.size() == points_vector.size())
 	{
 		points_vector = mapToScene(points_vector);
@@ -646,7 +659,7 @@ void QetShapeItem::insertPoint()
 	if (m_shapeType == QetShapeItem::Polygon)
 	{
 		QPolygonF new_polygon = QetGraphicsHandlerUtility::polygonForInsertPoint(this->polygon(), m_closed, Diagram::snapToGrid(m_context_menu_pos));
-		
+
 		if(new_polygon != m_polygon)
 		{
 				//Wrap the undo for avoid to merge the undo commands when user add several points.
@@ -662,11 +675,11 @@ void QetShapeItem::removePoint()
 	if (m_shapeType != QetShapeItem::Polygon) {
 		return;
 	}
-	
+
 	if (m_handler_vector.size() == 2) {
 		return;
 	}
-	
+
 	QPointF point = mapToScene(m_context_menu_pos);
 	int index = -1;
 	for (int i=0 ; i<m_handler_vector.size() ; i++)
@@ -682,7 +695,7 @@ void QetShapeItem::removePoint()
 	{
 		QPolygonF polygon = this->polygon();
 		polygon.removeAt(index);
-		
+
 			//Wrap the undo for avoid to merge the undo commands when user add several points.
 		QUndoCommand *undo = new QUndoCommand(tr("Supprimer un point d'un polygone"));
 		new QPropertyUndoCommand(this, "polygon", this->polygon(), polygon, undo);
@@ -691,15 +704,12 @@ void QetShapeItem::removePoint()
 }
 
 /**
- * @brief QetShapeItem::handlerMousePressEvent
- * @param qghi
- * @param event
- */
-void QetShapeItem::handlerMousePressEvent(QetGraphicsHandlerItem *qghi, QGraphicsSceneMouseEvent *event)
+	@brief QetShapeItem::handlerMousePressEvent
+	@param qghi
+	@param event
+*/
+void QetShapeItem::handlerMousePressEvent()
 {
-	Q_UNUSED(qghi);
-	Q_UNUSED(event);
-	
 	m_old_P1 = m_P1;
 	m_old_P2 = m_P2;
 	m_old_polygon = m_polygon;
@@ -711,14 +721,11 @@ void QetShapeItem::handlerMousePressEvent(QetGraphicsHandlerItem *qghi, QGraphic
 }
 
 /**
- * @brief QetShapeItem::handlerMouseMoveEvent
- * @param qghi
- * @param event
- */
-void QetShapeItem::handlerMouseMoveEvent(QetGraphicsHandlerItem *qghi, QGraphicsSceneMouseEvent *event)
+	@brief QetShapeItem::handlerMouseMoveEvent
+	@param event
+*/
+void QetShapeItem::handlerMouseMoveEvent(QGraphicsSceneMouseEvent *event)
 {
-	Q_UNUSED(qghi);
-	
 	QPointF new_pos = event->scenePos();
 	if (event->modifiers() != Qt::ControlModifier)
 		new_pos = Diagram::snapToGrid(event->scenePos());
@@ -775,17 +782,14 @@ void QetShapeItem::handlerMouseMoveEvent(QetGraphicsHandlerItem *qghi, QGraphics
 }
 
 /**
- * @brief QetShapeItem::handlerMouseReleaseEvent
- * @param qghi
- * @param event
- */
-void QetShapeItem::handlerMouseReleaseEvent(QetGraphicsHandlerItem *qghi, QGraphicsSceneMouseEvent *event)
+	@brief QetShapeItem::handlerMouseReleaseEvent
+	@param qghi
+	@param event
+*/
+void QetShapeItem::handlerMouseReleaseEvent()
 {
-	Q_UNUSED(qghi);
-	Q_UNUSED(event);
-	
 	m_modifie_radius_equaly = false;
-	
+
 	if (diagram())
 	{
 		QPropertyUndoCommand *undo = nullptr;
@@ -823,7 +827,7 @@ void QetShapeItem::handlerMouseReleaseEvent(QetGraphicsHandlerItem *qghi, QGraph
 		}
 		else if (m_shapeType == Polygon && (m_polygon != m_old_polygon))
 			undo = new QPropertyUndoCommand(this, "polygon", m_old_polygon, m_polygon);
-		
+
 		if(undo)
 		{
 			undo->setText(tr("Modifier %1").arg(name()));
@@ -833,11 +837,11 @@ void QetShapeItem::handlerMouseReleaseEvent(QetGraphicsHandlerItem *qghi, QGraph
 }
 
 /**
- * @brief QetShapeItem::fromXml
- * Build this item from the xml description
- * @param e element where is stored this item
- * @return true if load success
- */
+	@brief QetShapeItem::fromXml
+	Build this item from the xml description
+	@param e element where is stored this item
+	@return true if load success
+*/
 bool QetShapeItem::fromXml(const QDomElement &e)
 {
 	if (e.tagName() != "shape") return (false);
@@ -848,6 +852,9 @@ bool QetShapeItem::fromXml(const QDomElement &e)
 	m_brush = QETXML::brushFromXml(e.firstChildElement("brush"));
 
 	QString type = e.attribute("type");
+#if TODO_LIST
+#pragma message("@TODO Compatibility for version older than N°4075, shape type was stored with an int")
+#endif
 		//@TODO Compatibility for version older than N°4075, shape type was stored with an int
 	if (type.size() == 1)
 	{
@@ -872,7 +879,7 @@ bool QetShapeItem::fromXml(const QDomElement &e)
 		m_P1.setY(e.attribute("y1", nullptr).toDouble());
 		m_P2.setX(e.attribute("x2", nullptr).toDouble());
 		m_P2.setY(e.attribute("y2", nullptr).toDouble());
-		
+
 		if (m_shapeType == Rectangle)
 		{
 			setXRadius(e.attribute("rx", "0").toDouble());
@@ -890,11 +897,11 @@ bool QetShapeItem::fromXml(const QDomElement &e)
 }
 
 /**
- * @brief QetShapeItem::toXml
- * Save this item to xml element
- * @param document parent document xml
- * @return element xml where is write this item
- */
+	@brief QetShapeItem::toXml
+	Save this item to xml element
+	@param document parent document xml
+	@return element xml where is write this item
+*/
 QDomElement QetShapeItem::toXml(QDomDocument &document) const
 {
 	QDomElement result = document.createElement("shape");
@@ -913,7 +920,7 @@ QDomElement QetShapeItem::toXml(QDomDocument &document) const
 		result.setAttribute("y1", QString::number(mapToScene(m_P1).y()));
 		result.setAttribute("x2", QString::number(mapToScene(m_P2).x()));
 		result.setAttribute("y2", QString::number(mapToScene(m_P2).y()));
-		
+
 		if (m_shapeType == Rectangle)
 		{
 			QRectF rect(m_P1, m_P2);
@@ -926,7 +933,7 @@ QDomElement QetShapeItem::toXml(QDomDocument &document) const
 			if (y > rect.height()/2) {
 				y = rect.height()/2;
 			}
-			
+
 			result.setAttribute("rx", QString::number(m_xRadius));
 			result.setAttribute("ry", QString::number(m_yRadius));
 		}
@@ -950,27 +957,47 @@ QDomElement QetShapeItem::toXml(QDomDocument &document) const
 }
 
 /**
- * @brief QetShapeItem::toDXF
- * Draw this element to the dxf document
- * @param filepath file path of the the dxf document
- * @return true if draw success
- */
+	@brief QetShapeItem::toDXF
+	Draw this element to the dxf document
+	@param filepath file path of the the dxf document
+	@param pen
+	@return true if draw success
+*/
 bool QetShapeItem::toDXF(const QString &filepath,const QPen &pen)
 {
 
-    switch (m_shapeType)
+	switch (m_shapeType)
 	{
-        case Line:      Createdxf::drawLine     (filepath, QLineF(mapToScene(m_P1), mapToScene(m_P2)), Createdxf::getcolorCode(pen.color().red(),pen.color().green(),pen.color().blue()));              return true;
-        case Rectangle: Createdxf::drawRectangle(filepath, QRectF(mapToScene(m_P1), mapToScene(m_P2)).normalized(), Createdxf::getcolorCode(pen.color().red(),pen.color().green(),pen.color().blue())); return true;
-        case Ellipse:   Createdxf::drawEllipse  (filepath, QRectF(mapToScene(m_P1), mapToScene(m_P2)).normalized(), Createdxf::getcolorCode(pen.color().red(),pen.color().green(),pen.color().blue())); return true;
-		default: return false;
+		case Line:
+	    Createdxf::drawLine(filepath,
+			QLineF( mapToScene(m_P1),
+				mapToScene(m_P2)),
+				Createdxf::dxfColor(pen));
+	    return true;
+		case Rectangle:
+	    Createdxf::drawRectangle(filepath,
+			 QRectF(mapToScene(m_P1),
+				mapToScene(m_P2)).normalized(),
+				Createdxf::dxfColor(pen));
+	    return true;
+		case Ellipse:
+	    Createdxf::drawEllipse(filepath,
+			 QRectF(mapToScene(m_P1),
+				mapToScene(m_P2)).normalized(),
+				Createdxf::dxfColor(pen));
+	    return true;
+	case Polygon:
+	    Createdxf::drawPolygon(filepath,m_polygon,Createdxf::dxfColor(pen));
+	    return true;
+	default:
+	    return false;
 	}
 }
 
 /**
- * @brief QetShapeItem::editProperty
- * Edit the property of this item
- */
+	@brief QetShapeItem::editProperty
+	Edit the property of this item
+*/
 void QetShapeItem::editProperty()
 {
 	if (diagram() -> isReadOnly()) return;
@@ -980,10 +1007,11 @@ void QetShapeItem::editProperty()
 }
 
 /**
- * @brief QetShapeItem::name
- * @return the name of the curent shape.
- */
-QString QetShapeItem::name() const {
+	@brief QetShapeItem::name
+	@return the name of the curent shape.
+*/
+QString QetShapeItem::name() const
+{
 	switch (m_shapeType) {
 		case Line:	    return tr("une ligne");
 		case Rectangle:	return tr("un rectangle");
