@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -16,30 +16,34 @@
 	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "simpleelement.h"
-#include "diagram.h"
+
+#include "../diagram.h"
 
 /**
- * @brief SimpleElement::SimpleElement
- * @param location
- * @param qgi
- * @param s
- * @param state
- */
-SimpleElement::SimpleElement(const ElementsLocation &location, QGraphicsItem *qgi, int *state) :
+	@brief SimpleElement::SimpleElement
+	@param location
+	@param qgi
+	@param state
+*/
+SimpleElement::SimpleElement(
+		const ElementsLocation &location,
+		QGraphicsItem *qgi,
+		int *state) :
 	Element(location, qgi, state, Element::Simple)
 {}
 
 /**
- * @brief SimpleElement::~SimpleElement
- */
-SimpleElement::~SimpleElement() {}
+	@brief SimpleElement::~SimpleElement
+*/
+SimpleElement::~SimpleElement()
+{}
 
 /**
- * @brief SimpleElement::initLink
- * @param project
- * Call init Link from custom element and after
- * call update label for setup it.
- */
+	@brief SimpleElement::initLink
+	@param project
+	Call init Link from custom element and after
+	call update label for setup it.
+*/
 void SimpleElement::initLink(QETProject *project) {
 	Element::initLink(project);
 }
