@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -18,23 +18,24 @@
 #include "terminalelement.h"
 
 /**
- * @brief TerminalElement::TerminalElement
- * Default constructor
- * @param location location of xml definition
- * @param qgi parent QGraphicItem
- * @param s parent diagram
- * @param state int used to know if the creation of element have error
- */
-TerminalElement::TerminalElement(const ElementsLocation &location, QGraphicsItem *qgi, int *state) :
+	@brief TerminalElement::TerminalElement
+	Default constructor
+	@param location location of xml definition
+	@param qgi parent QGraphicItem
+	@param state int used to know if the creation of element have error
+*/
+TerminalElement::TerminalElement(const ElementsLocation &location,
+				 QGraphicsItem *qgi, int *state) :
 	Element(location, qgi, state, Element::Terminale)
 {}
 
-TerminalElement::~TerminalElement() {}
+TerminalElement::~TerminalElement()
+{}
 
 /**
- * @brief TerminalElement::initLink
- * @param project
- */
+	@brief TerminalElement::initLink
+	@param project
+*/
 void TerminalElement::initLink(QETProject *project) {
 	Element::initLink(project);
 }
