@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -18,15 +18,16 @@
 #ifndef ABSTRACTELEMENTPROPERTIESEDITORWIDGET_H
 #define ABSTRACTELEMENTPROPERTIESEDITORWIDGET_H
 
-#include "PropertiesEditor/propertieseditorwidget.h"
+#include "../PropertiesEditor/propertieseditorwidget.h"
+
 #include <QPointer>
 
 class Element;
 
 /**
- * @brief The AbstractElementPropertiesEditorWidget class
- * This class provide common method for all widget used to edit some properties of an element
- */
+	@brief The AbstractElementPropertiesEditorWidget class
+	This class provide common method for all widget used to edit some properties of an element
+*/
 class AbstractElementPropertiesEditorWidget : public PropertiesEditorWidget
 {
 		Q_OBJECT
