@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -18,17 +18,18 @@
 #ifndef BORDERPROPERTIESWIDGET_H
 #define BORDERPROPERTIESWIDGET_H
 
+#include "../borderproperties.h"
+
 #include <QWidget>
-#include "borderproperties.h"
 
 namespace Ui {
 	class BorderPropertiesWidget;
 }
 
 /**
- * @brief The BorderPropertiesWidget class
- * this widget edit the properties of a border
- */
+	@brief The BorderPropertiesWidget class
+	this widget edit the properties of a border
+*/
 class BorderPropertiesWidget : public QWidget
 {
 		Q_OBJECT
