@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -24,9 +24,9 @@ class Diagram;
 class ConductorPropertiesWidget;
 
 /**
- * @brief The DiagramPropertiesDialog class
- * This dialog open a windows for edit properties of a diagram.
- */
+	@brief The DiagramPropertiesDialog class
+	This dialog open a windows for edit properties of a diagram.
+*/
 class DiagramPropertiesDialog : public QDialog {
 		Q_OBJECT
 
@@ -37,10 +37,10 @@ class DiagramPropertiesDialog : public QDialog {
 
 	public slots:
 		void editAutonum ();
-        void editAutoFolioNum ();
+		void editAutoFolioNum ();
 
 	private:
-		Diagram               *m_diagram;
+		Diagram *m_diagram;
 		ConductorPropertiesWidget *m_cpw;
 };
 
