@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -18,8 +18,9 @@
 #ifndef IMPORTELEMENTDIALOG_H
 #define IMPORTELEMENTDIALOG_H
 
+#include "../qet.h"
+
 #include <QDialog>
-#include "qet.h"
 
 namespace Ui {
 	class ImportElementDialog;
