@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -24,9 +24,9 @@ class QWidget;
 class ConfigDialog;
 
 /**
- * @brief The ProjectPropertiesDialog class
- * this class builds a dialog to edit whole properties of a project
- */
+	@brief The ProjectPropertiesDialog class
+	this class builds a dialog to edit whole properties of a project
+*/
 class ProjectPropertiesDialog : public QObject {
 	public:
 		enum Page {
@@ -39,7 +39,7 @@ class ProjectPropertiesDialog : public QObject {
 		~ProjectPropertiesDialog() override;
 		void exec();
 		void setCurrentPage(ProjectPropertiesDialog::Page);
-        void changeToFolio();
+		void changeToFolio();
 
 	private:
 		ConfigDialog *m_properties_dialog;
