@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2019 The QElectroTech Team
+	Copyright 2006-2021 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -18,15 +18,15 @@
 #ifndef CHANGETITLEBLOCKCOMMAND_H
 #define CHANGETITLEBLOCKCOMMAND_H
 
-#include <QUndoCommand>
+#include "../titleblockproperties.h"
 
-#include "titleblockproperties.h"
+#include <QUndoCommand>
 
 class Diagram;
 /**
- * @brief The ChangeTitleBlockCommand class
- * This command changes the title block properties for a particular diagram.
- */
+	@brief The ChangeTitleBlockCommand class
+	This command changes the title block properties for a particular diagram.
+*/
 class ChangeTitleBlockCommand : public QUndoCommand
 {
 	public:
